@@ -827,12 +827,11 @@ static unsigned short APGD[40] = {
 
 int airy(double x,double* ai,double* aip,double* bi,double* bip )
 {
-double z, zz, t, f, g, uf, ug, k, zeta, theta;
+double z, zz, t, f, g, uf, ug, k, zeta_, theta;
 int domflg;
 
 domflg = 0;
-if( x > MAXAIRY )
-	{
+if( x > MAXAIRY ) {
 	*ai = 0;
 	*aip = 0;
 	*bi = MAXNUM;
@@ -844,14 +843,14 @@ if( x < -2.09 )
 	{
 	domflg = 15;
 	t = sqrt(-x);
-	zeta = -2.0 * x * t / 3.0;
+	zeta_ = -2.0 * x * t / 3.0;
 	t = sqrt(t);
 	k = sqpii / t;
-	z = 1.0/zeta;
+	z = 1.0/zeta_;
 	zz = z * z;
 	uf = 1.0 + zz * polevl( zz, AFN, 8 ) / p1evl( zz, AFD, 9 );
 	ug = z * polevl( zz, AGN, 10 ) / p1evl( zz, AGD, 10 );
-	theta = zeta + 0.25 * PI;
+	theta = zeta_ + 0.25 * PI;
 	f = sin( theta );
 	g = cos( theta );
 	*ai = k * (f * uf - g * ug);
@@ -868,18 +867,18 @@ if( x >= 2.09 )	/* cbrt(9) */
 	{
 	domflg = 5;
 	t = sqrt(x);
-	zeta = 2.0 * x * t / 3.0;
-	g = exp( zeta );
+	zeta_ = 2.0 * x * t / 3.0;
+	g = exp( zeta_ );
 	t = sqrt(t);
 	k = 2.0 * t * g;
-	z = 1.0/zeta;
+	z = 1.0/zeta_;
 	f = polevl( z, AN, 7 ) / polevl( z, AD, 7 );
 	*ai = sqpii * f / k;
 	k = -0.5 * sqpii * t / g;
 	f = polevl( z, APN, 7 ) / polevl( z, APD, 7 );
 	*aip = f * k;
 
-	if( x > 8.3203353 )	/* zeta > 16 */
+	if( x > 8.3203353 )	/* zeta_ > 16 */
 		{
 		f = z * polevl( z, BN16, 4 ) / p1evl( z, BD16, 5 );
 		k = sqpii * g;
