@@ -6,20 +6,24 @@
 #include <qcolor.h>
 #include <qpainter.h>
 #include <qstringlist.h>
+#include <qdom.h>
 #include "Point.h"
 
 class Arrow
 {
 public:
-	Arrow(bool l=0,bool e=false,double le=0.1,double a=30,bool f=true,
+	Arrow(bool l=0,bool e=false,double le=0.3,double a=30,bool f=true,
 		QColor fc=QColor("blue"));
 	QStringList Info();
 	void save(QTextStream *t);
 	void open(QTextStream *t,int version);
+	QDomElement saveXML(QDomDocument doc,QString id="Arrow");
+	void openXML(QDomNode node);
 	bool Location() { return location; }
 	void setLocation(bool l) { location=l; }
 	bool Enabled() { return enabled; }
-	void setEnabled(bool b=true) { enabled=b; }
+	void Enable(bool b=true) { enabled=b; }
+	void setEnabled(bool b=true) { Enable(b); }
 	double Length() { return length; }
 	void setLength(double l) { length=l; }
 	double Angle() { return angle; }
