@@ -9,6 +9,8 @@ AverageListDialog::AverageListDialog(MainWin *mw, const char *name)
 	: ListDialog(mw, name)
 {
 	setCaption(i18n("Average Dialog"));
+	KConfig *config = mw->Config();
+	config->setGroup( "Average" );
 
 	QTabWidget *tw = new QTabWidget(vbox);
 	QVBox *tab1 = new QVBox(tw);
@@ -16,8 +18,8 @@ AverageListDialog::AverageListDialog(MainWin *mw, const char *name)
 	new QLabel(i18n(" Average every n points :"),tab1);
 	QHBox *hb = new QHBox(tab1);
 	new QLabel(QString(" n = "),hb);
-	nle = new KLineEdit(QString("3"),hb);
-	nle->setValidator(new QIntValidator(nle));
+	nni = new KIntNumInput(config->readNumEntry("N",3),hb);
+	nni->setRange(1,10000000,1,false);
 
 	Style *style=0;
 	Symbol *symbol=0;
@@ -32,14 +34,21 @@ AverageListDialog::AverageListDialog(MainWin *mw, const char *name)
 
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
         QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	QObject::connect(save,SIGNAL(clicked()),SLOT(saveSettings()));
 	
 	setMinimumWidth(vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
 	resize(minimumSize());
 }
  
- int AverageListDialog::apply_clicked() {
-	int n = (nle->text()).toInt();
+void AverageListDialog::saveSettings() {
+	KConfig *config = mw->Config();
+	config->setGroup( "Average" );
+	config->writeEntry("N", nni->value());
+}
+
+int AverageListDialog::apply_clicked() {
+	int n = nni->value();
 	
 	// spreadsheet
 	if(s) {
@@ -52,11 +61,10 @@ AverageListDialog::AverageListDialog(MainWin *mw, const char *name)
 		}
 		
 		// add column if needed
-		bool empty=true;
-		for(int i=0;i<table->numRows();i++) {
-			if(table->text(i,table->numCols()-1).length()>0) {
-				empty =false;
-			}
+		bool empty = true;
+		for(int i = 0; i < table->numRows(); i++) {
+			if(!table->text(i, table->numCols()-1).isEmpty())
+				empty = false;
 		}
 		if (!empty)
 			s->addColumn();
@@ -88,8 +96,11 @@ AverageListDialog::AverageListDialog(MainWin *mw, const char *name)
 	Symbol *symbol=0;
 	if(st != GRAPHM) {
 		style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
-			widthle->text().toInt(),pencb->currentItem(),brushcb->currentItem());
-		symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->text().toInt(),
+			width->value(),pencb->currentItem(),brushcb->currentItem());
+		style->setBoxWidth(boxwidth->value());
+		style->setAutoBoxWidth(autobox->isChecked());
+		style->setPointsSorting(sortpointscb->isChecked());
+		symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->value(),
 			(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());
 	}
 
@@ -124,7 +135,7 @@ AverageListDialog::AverageListDialog(MainWin *mw, const char *name)
 		range[0] = LRange(xmin,xmax);
 		range[1] = LRange(ymin,ymax);
 
-		QString fun = QString(i18n("average (")+QString::number(n)+i18n(") of ")+g->Label());
+		QString fun = QString(i18n("average (")+QString::number(n)+i18n(") of ")+g->getLabel()->simpleTitle());
 
 		Graph2D *ng = new Graph2D(fun,fun,range,SSPREADSHEET,P2D,style,symbol,ptr,g->Number()/n);
 		mw->addGraph2D(ng,sheetcb->currentItem());
@@ -176,7 +187,7 @@ AverageListDialog::AverageListDialog(MainWin *mw, const char *name)
 		range[1] = LRange(ymin,ymax);
 		range[2] = LRange(zmin,zmax);
 		
-		QString fun = QString(i18n("average (")+QString::number(n)+i18n(") of ")+g->Label());
+		QString fun = QString(i18n("average (")+QString::number(n)+i18n(") of ")+g->getLabel()->simpleTitle());
 		
 		Graph3D *ng = new Graph3D(fun,fun,range,SSPREADSHEET,type,style,symbol,ptr,g->Number()/n,1);
 		ng->setNumberX((int)(g->NX()/n));
@@ -223,7 +234,7 @@ AverageListDialog::AverageListDialog(MainWin *mw, const char *name)
 		range[2] = LRange(zmin,zmax);
 		range[3] = LRange(tmin,tmax);
 		
-		QString fun = QString(i18n("average (")+QString::number(n)+i18n(") of ")+g->Label());
+		QString fun = QString(i18n("average (")+QString::number(n)+i18n(") of ")+g->getLabel()->simpleTitle());
 		
 		Graph4D *ng = new Graph4D(fun,fun,range,SSPREADSHEET,type,style,symbol,ptr,g->Number()/n,gtype);
 		mw->addGraph4D(ng,sheetcb->currentItem());
@@ -274,7 +285,7 @@ AverageListDialog::AverageListDialog(MainWin *mw, const char *name)
 		range[1] = LRange(1,ny);
 		range[2] = LRange(zmin,zmax);
 		
-		QString fun = QString(i18n("average (")+QString::number(n)+i18n(") of ")+g->Label());
+		QString fun = QString(i18n("average (")+QString::number(n)+i18n(") of ")+g->getLabel()->simpleTitle());
 
 		GraphM *ng = new GraphM(fun,fun,range,SSPREADSHEET,type,style,symbol,ptr,nx/n,ny/n);
 		mw->addGraphM(ng,sheetcb->currentItem());	// type??
