@@ -17,6 +17,7 @@
 #include <kcombobox.h>
 #include <klineedit.h>
 #include "ConfigureDialog.h"
+#include "WorksheetDialog.h"
 #include "Dialog.h"
 
 using namespace std;
@@ -37,41 +38,46 @@ ConfigureDialog::ConfigureDialog(MainWin *mw, KConfig *config)
 	QVBoxLayout *genLayout = new QVBoxLayout(general);
 
 	QVButtonGroup *fsbg = new QVButtonGroup(general);
-	new QLabel(i18n("Open worksheets as .. "),fsbg);
-	QHButtonGroup *bg = new QHButtonGroup(fsbg);
-	fullscreen = new QRadioButton(i18n("Fullscreen"), bg );
-	fullscreen->setChecked(true);
-	cascade = new QRadioButton(i18n("Cascade"), bg );
-	if (config->readBoolEntry("Cascade",false))
-		cascade->setChecked(true);
+	QHBox *hb = new QHBox(fsbg);
+	asksheet = new QCheckBox(hb, "AskCloseSheet");
+	asksheet->setText(i18n("Ask before closing a sheet"));
+	asksheet->setChecked(config->readBoolEntry("AskCloseSheet",true));
+	hb = new QHBox(fsbg);
+	new QLabel(i18n("Number of Recent Files : "),hb);
+	recentnr = new KIntNumInput(config->readNumEntry("NrRecentFiles",10),hb);
+        recentnr->setRange(0, 100, 1, false);
+
 	// autosave
 	QVButtonGroup *asbg = new QVButtonGroup(general);
-	autosave = new QCheckBox(asbg, "Autosave");
+	hb = new QHBox(asbg);
+	autosave = new QCheckBox(hb, "Autosave");
 	autosave->setText(i18n("Auto&save"));
+	autosave->setChecked(config->readBoolEntry("Autosave",true));
+	auto_original = new QCheckBox(hb, "AutoOriginal");
+	auto_original->setText(i18n("Use orginal project for autosave"));
+	auto_original->setChecked(config->readBoolEntry("AutoOriginal",true));
 
-	QHBox *hb = new QHBox(asbg);
+	hb = new QHBox(asbg);
 	QLabel *lb = new QLabel(i18n("Interval &time in minutes (1 - 9999) : "),hb);
-	asIntervalInput = new KIntNumInput(hb,"asIntervalInput");
+	asIntervalInput = new KIntNumInput(config->readLongNumEntry("AutosaveInterval",600000)/60000,hb);
         asIntervalInput->setRange(1, 9999, 1, false);
 	lb->setBuddy(asIntervalInput);
-	autosave->setChecked(config->readBoolEntry("Autosave",true));
-	asIntervalInput->setValue(config->readLongNumEntry("AutosaveInterval",600000)/60000);
 
 	// speedmode
 	speedmode = new QCheckBox(asbg, "SpeedMode");
 	speedmode->setText(i18n("Speed Mode"));
 	speedmode->setChecked(config->readBoolEntry("SpeedMode",false));
 	hb = new QHBox(asbg);
-	new QLabel(i18n("Speed Mode Number"),hb);
-	speedmodevalue = new KLineEdit(QString::number(config->readLongNumEntry("SpeedModeValue",1000)),hb);
-	speedmodevalue->setValidator(new QIntValidator(speedmodevalue));
+	new QLabel(i18n("Speed Mode Number : "),hb);
+	speedmodevalue = new KIntNumInput(config->readNumEntry("SpeedModeValue",1000),hb);
+        speedmodevalue->setRange(1, 100000, 100, false);
 
 	// keyboard datamode
 	hb = new QHBox(asbg);
 	keydatamode = new QCheckBox(asbg, "KeyboardDataMode");
 	keydatamode->setText(i18n("Use Keyboard for Data Mode"));
 	keydatamode->setChecked(config->readBoolEntry("KeyboardDataMode",false));
-	
+
 	// default font for label
 	QVButtonGroup *fontbg = new QVButtonGroup(general);
 	new QLabel(i18n("Default Font : "),fontbg);
@@ -85,11 +91,11 @@ ConfigureDialog::ConfigureDialog(MainWin *mw, KConfig *config)
 	genLayout->addWidget(asbg);
 	genLayout->addWidget(fontbg);
 
-	// printer settings
+	// Printer Settings
 	config->setGroup("KPrinter Settings" );
 	QFrame* pp = addPage(i18n("Print Preview"),i18n("Print Preview"), BarIcon(QString("printer"), KIcon::SizeMedium));
 	QVBoxLayout *printLayout = new QVBoxLayout(pp);
-	
+
 	QVButtonGroup *printbg = new QVButtonGroup(i18n("Printer settings"),pp);
 	color = new QRadioButton(i18n("Print in color if available") , printbg);
 	color->setChecked(true);
@@ -98,9 +104,21 @@ ConfigureDialog::ConfigureDialog(MainWin *mw, KConfig *config)
 		grayscale->setChecked(true);
 
 	printLayout->addWidget(printbg);
-	
+
 	QVButtonGroup *paperbg = new QVButtonGroup(i18n("Paper Format"),pp);
-	
+
+	originalsize = new QCheckBox(paperbg, "UseOriginalSize");
+	originalsize->setText(i18n("Keep original size"));
+	originalsize->setChecked(config->readBoolEntry("UseOriginalSize",true));
+
+	ps2eps = new QCheckBox(paperbg, "UsePS2EPS");
+	ps2eps->setText(i18n("Use ps2eps for exporting EPS"));
+	ps2eps->setChecked(config->readBoolEntry("UsePS2EPS",true));
+
+	ps2pdf = new QCheckBox(paperbg, "UsePS2PDF");
+	ps2pdf->setText(i18n("Use ps2pdf for exporting PDF"));
+	ps2pdf->setChecked(config->readBoolEntry("UsePS2PDF",true));
+
 	orientation = new KComboBox(paperbg);
 	QStringList olst;
 	olst += i18n("Portrait");
@@ -121,43 +139,27 @@ ConfigureDialog::ConfigureDialog(MainWin *mw, KConfig *config)
 	QFrame* pss = addPage(i18n("Simple Plot"),i18n("Simple Plot Style"), BarIcon(QString("LabPlot"), KIcon::SizeLarge));
 	QVBoxLayout *plotsimpleLayout = new QVBoxLayout(pss);
 
+	// bad
+	resize(650,550);
+
 	QTabWidget *tw1 = new QTabWidget(pss);
 	Style *style=0;
 	Symbol *symbol=0;
 	dialog = new Dialog(mw,0);
 	QVBox *styletab1 = dialog->simpleStyle(tw1, style, symbol);
 	styletab1->reparent((QWidget *)pss,0,QPoint(0,0));
-	styletab1->resize(this->size());
+	styletab1->resize(this->size()-QSize(170,100));
 	plotsimpleLayout->addWidget(tw1);
 
-	// simple plot style tab
+	// surface plot style tab
 	QFrame* pus = addPage(i18n("Surface Plot"),i18n("Surface Plot Style"), BarIcon(QString("LabPlot"), KIcon::SizeLarge));
 	QVBoxLayout *plotsurfaceLayout = new QVBoxLayout(pus);
 
 	QTabWidget *tw2 = new QTabWidget(pus);
 	QVBox *styletab2 = dialog->surfaceStyle(tw2,true);
 	styletab2->reparent((QWidget *)pus,0,QPoint(0,0));
-	styletab2->resize(this->size());
+	styletab2->resize(this->size()-QSize(170,100));
 	plotsurfaceLayout->addWidget(tw2);
-	
-	//TODO : axis settings
-/*	
-	QFrame* pas = addPage(i18n("Axis Settings"),i18n("Axis"), BarIcon(QString("axis"), KIcon::SizeLarge));
-	QVBoxLayout *axisLayout = new QVBoxLayout(pas);
-	
-	QTabWidget *tw3 = new QTabWidget(pas);
-//?	QVBox *styletab3 = dialog->axisStyle(tw3,true);
-	styletab3->reparent((QWidget *)pas,0,QPoint(0,0));
-	styletab3->resize(this->size());
-	axisLayout->addWidget(tw3);
-*/
-	// TODO : graph settings
-	// TODO : worksheet settings
-	// TODO : plot settings
-	// ...
-	
-	// bad
-	resize(750,450);
 
 	QObject::connect(this,SIGNAL(okClicked()),SLOT(ok_clicked()));
         QObject::connect(this,SIGNAL(applyClicked()),SLOT(apply_clicked()));
@@ -175,19 +177,24 @@ void ConfigureDialog::selectFont() {
 void ConfigureDialog::apply_clicked() {
 	config->setGroup("KPrinter Settings" );
 	config->writeEntry("ColorMode",color->isChecked());
-	config->writeEntry("Landscape",orientation->currentItem());
+	config->writeEntry("Orientation",orientation->currentItem());
 	config->writeEntry("PageSize",pagesize->currentItem());
+	config->writeEntry("UseOriginalSize",originalsize->isChecked());
+	config->writeEntry("UsePS2EPS",ps2eps->isChecked());
+	config->writeEntry("UsePS2PDF",ps2pdf->isChecked());
 
 	config->setGroup( "General Options" );
-	config->writeEntry("Cascade",cascade->isChecked());
+	config->writeEntry("AskCloseSheet",asksheet->isChecked());
+	config->writeEntry("NrRecentFiles",recentnr->value());
 	config->writeEntry("Autosave",autosave->isChecked());
+	config->writeEntry("AutoOriginal",auto_original->isChecked());
 	config->writeEntry("AutosaveInterval",asIntervalInput->value()*60000);
 	config->writeEntry("SpeedMode",speedmode->isChecked());
-	config->writeEntry("SpeedModeValue",speedmodevalue->text().toInt());
+	config->writeEntry("SpeedModeValue",speedmodevalue->value());
 	config->writeEntry("KeyboardDataMode",keydatamode->isChecked());
 	config->writeEntry("DefaultFont",defaultfont);
 	mw->setDefaultFont(defaultfont);
-	
+
 	dialog->saveSimpleStyle();
 	dialog->saveSurfaceStyle();
 }
