@@ -24,11 +24,12 @@ private:
 	Dialog *dialog;
 	KConfig *config;
 	QRadioButton *fullscreen, *cascade;
+	QCheckBox *asksheet, *originalsize, *ps2eps, *ps2pdf;
+	KIntNumInput *recentnr;
 	QRadioButton *color, *grayscale;
 	KComboBox *pagesize, *orientation;
-	QCheckBox *autosave, *speedmode, *keydatamode;
-	KIntNumInput *asIntervalInput;
-	KLineEdit *speedmodevalue;
+	QCheckBox *autosave, *auto_original, *speedmode, *keydatamode;
+	KIntNumInput *asIntervalInput, *speedmodevalue;
 	QFont defaultfont;	// local var for default font
 	KLineEdit *fontle;
 };
