@@ -1,5 +1,6 @@
 //LabPlot : ConvolutionListDialog.cc
 
+#include <math.h>
 #include "ConvolutionListDialog.h"
 
 #ifdef HAVE_GSL
@@ -7,29 +8,31 @@
 #include <gsl/gsl_fft_halfcomplex.h>
 #endif
 
-inline int MAX(int x,int y) {if (x>y) return x; else return y;}
-
 ConvolutionListDialog::ConvolutionListDialog(MainWin *mw, const char *name)
 	: ListDialog(mw, name)
 {
 	setCaption(i18n("Convolution Dialog"));
+	KConfig *config = mw->Config();
+	config->setGroup( "Convolution" );
 
 	QTabWidget *tw = new QTabWidget(vbox);
 	QVBox *tab1 = new QVBox(tw);
-	
+
 	QHBox *hb = new QHBox(tab1);
-	
+
 	type = new KComboBox(hb);
 	QStringList tlist;
 	tlist << i18n("convolute") << i18n("deconvolute");
 	type->insertStringList(tlist);
-	type->setCurrentItem(0);
-	
+	type->setCurrentItem(config->readNumEntry("Type",0));
+
 	hb = new QHBox(tab1);
 	new QLabel(i18n("set "),hb);
-	set1le = new KLineEdit(QString("1"),hb);
+	set1ni = new KIntNumInput(config->readNumEntry("Set1",1),hb);
+	set1ni->setRange(1,1000,1,false);
 	new QLabel(i18n("with set "),hb);
-	set2le = new KLineEdit(QString("2"),hb);
+	set2ni = new KIntNumInput(config->readNumEntry("Set2",2),hb);
+	set2ni->setRange(1,1000,1,false);
 	
 	// TODO : select gsl or fftw
 
@@ -39,7 +42,7 @@ ConvolutionListDialog::ConvolutionListDialog(MainWin *mw, const char *name)
 	QStringList vlist;
 	vlist << i18n("index") << i18n("signal");
 	xvalue->insertStringList(vlist);
-	xvalue->setCurrentItem(0);
+	xvalue->setCurrentItem(config->readNumEntry("Xvalue",0));
 	
 	Style *style=0;
 	Symbol *symbol=0;
@@ -54,12 +57,23 @@ ConvolutionListDialog::ConvolutionListDialog(MainWin *mw, const char *name)
 	
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
         QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	QObject::connect(save,SIGNAL(clicked()),SLOT(saveSettings()));
 
 	setMinimumWidth(vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
 	resize(minimumSize());
 }
 
+void ConvolutionListDialog::saveSettings() {
+	KConfig *config = mw->Config();
+	config->setGroup( "Convolution" );
+
+	config->writeEntry("Type", type->currentItem());
+	config->writeEntry("Set1", set1ni->value());
+	config->writeEntry("Set2", set2ni->value());
+	config->writeEntry("Xvalue", xvalue->currentItem());
+}
+
 int ConvolutionListDialog::apply_clicked() {
 	GraphList *gl = p->getPlot(p->API())->getGraphList();
 	if(gl->Number()==0) {
@@ -67,8 +81,8 @@ int ConvolutionListDialog::apply_clicked() {
 		return -2;
 	}
 
-	unsigned int item1 = set1le->text().toInt()-1;
-	unsigned int item2 = set2le->text().toInt()-1;
+	unsigned int item1 = set1ni->value()-1;
+	unsigned int item2 = set2ni->value()-1;
 
 	if (item1 > gl->Number() || item2 > gl->Number()) {
 		KMessageBox::error(this, i18n("Sorry. Can not find selected data sets!"));
@@ -83,8 +97,11 @@ int ConvolutionListDialog::apply_clicked() {
 	
 	if(s1 != GRAPHM && s2 != GRAPHM) {
 		style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
-			widthle->text().toInt(),pencb->currentItem(),brushcb->currentItem());
-		symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->text().toInt(),
+			width->value(),pencb->currentItem(),brushcb->currentItem());
+		style->setBoxWidth(boxwidth->value());
+		style->setAutoBoxWidth(autobox->isChecked());
+		style->setPointsSorting(sortpointscb->isChecked());
+		symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->value(),
 			(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());
 	}
 
@@ -96,15 +113,15 @@ int ConvolutionListDialog::apply_clicked() {
 		int nr1=0, nr2=0;
 		QString label1, label2;
 		switch(s1) {
-		case GRAPH2D: g1 = gl->getGraph2D(item1); nr1 = g1->Number(); label1 = g1->Label(); break;
-		case GRAPH3D: g31 = gl->getGraph3D(item1); nr1 = g31->Number(); label1 = g31->Label(); break;
-		case GRAPH4D: g41 = gl->getGraph4D(item1); nr1 = g41->Number(); label1 = g41->Label(); break;
+		case GRAPH2D: g1 = gl->getGraph2D(item1); nr1 = g1->Number(); label1 = g1->getLabel()->simpleTitle(); break;
+		case GRAPH3D: g31 = gl->getGraph3D(item1); nr1 = g31->Number(); label1 = g31->getLabel()->simpleTitle(); break;
+		case GRAPH4D: g41 = gl->getGraph4D(item1); nr1 = g41->Number(); label1 = g41->getLabel()->simpleTitle(); break;
 		default : break;
 		}
 		switch(s2) {
-		case GRAPH2D: g2 = gl->getGraph2D(item2); nr2 = g2->Number(); label2 = g2->Label(); break;
-		case GRAPH3D: g32 = gl->getGraph3D(item2); nr2 = g32->Number(); label2 = g32->Label(); break;
-		case GRAPH4D: g42 = gl->getGraph4D(item2); nr2 = g42->Number(); label2 = g42->Label(); break;
+		case GRAPH2D: g2 = gl->getGraph2D(item2); nr2 = g2->Number(); label2 = g2->getLabel()->simpleTitle(); break;
+		case GRAPH3D: g32 = gl->getGraph3D(item2); nr2 = g32->Number(); label2 = g32->getLabel()->simpleTitle(); break;
+		case GRAPH4D: g42 = gl->getGraph4D(item2); nr2 = g42->Number(); label2 = g42->getLabel()->simpleTitle(); break;
 		default : break;
 		}
 
