@@ -5,7 +5,7 @@
 #include <math.h>
 #include <iostream>
 
-#ifdef USE_SOLARIS
+#ifdef HAVE_SOLARIS
 #include <ieeefp.h>
 #endif
 
@@ -27,6 +27,7 @@
 #include "DataDialog.h"
 #include "Plot2DSurface.h"
 #include "PlotQWT3D.h"
+#include "LTableItem.h"
 #include "FilterMAGICK.h"
 #include "formatlist.h"
 #include "inputitems.h"
@@ -45,7 +46,10 @@ DataDialog::DataDialog(MainWin *mw, const char *name, ListDialog *l,int item, PT
 	kdDebug()<<"DataDialog()"<<endl;
 	
 	GraphList *graphlist=0;
-	QString dat=mw->last_filename;
+	KConfig *config = mw->Config();
+	config->setGroup( "Import" );
+
+	QString dat = config->readEntry("Filename","1.dat");
 
 	kdDebug()<<"DataDialog "<<endl;
 	kdDebug()<<"new type = "<<newtype<<endl;
@@ -78,7 +82,7 @@ DataDialog::DataDialog(MainWin *mw, const char *name, ListDialog *l,int item, PT
 	Style *style=0;
 	Symbol *symbol=0;
 
-	if (item == -1) {		// new graph
+	if (item == -1) {	// new graph
 		graph = 0;
 	}
 	else {			// change graph
@@ -88,17 +92,18 @@ DataDialog::DataDialog(MainWin *mw, const char *name, ListDialog *l,int item, PT
 		symbol = graph->getSymbol();
 	}
 
-	
 	QTabWidget *tw = new QTabWidget(vbox);
 	QVBox *tab1 = new QVBox(tw);
 
 	if (graph != 0) dat = graph->Name();
-	importWidget(tab1,dat,FUSER);
+	importWidget(tab1,dat,(InputFilter)config->readNumEntry("Filter",(int)FUSER));
 	
+	config->setGroup( "Data" );
+	QString entry = QString("PlotType %1 ").arg(type);
 	QHBox *hb = new QHBox(tab1);
 	if (graph !=0) {
 		reread = new QCheckBox(i18n("Reread Datafile"),hb);
-		reread->setChecked(0);
+		reread->setChecked(config->readBoolEntry(entry+"Reread",false));
 	}
 	else
 		reread=0;
@@ -106,6 +111,8 @@ DataDialog::DataDialog(MainWin *mw, const char *name, ListDialog *l,int item, PT
 	KPushButton *checkpb = new KPushButton(i18n("Check data"),hb);
 	checkpb->setMaximumWidth(150);
 	QObject::connect(checkpb,SIGNAL(clicked()),SLOT(checkData()));
+	KPushButton *setLabelpb = new KPushButton(i18n("Update Label"),hb);
+	QObject::connect(setLabelpb,SIGNAL(clicked()),SLOT(updateLabel()));
 
 	hb = new QHBox(tab1);
 	QLabel *tmp = new QLabel(i18n("Read as : "),hb);
@@ -125,7 +132,7 @@ DataDialog::DataDialog(MainWin *mw, const char *name, ListDialog *l,int item, PT
 	if(graph != 0)
 		cbi->setCurrentItem(graph->ReadAs());
 	else
-		cbi->setCurrentItem(mw->last_readas);
+		cbi->setCurrentItem(config->readNumEntry(entry+"ReadAs",0));
 
 	QObject::connect(cbi,SIGNAL(activated(int)),SLOT(updateRead()));
 
@@ -144,32 +151,35 @@ DataDialog::DataDialog(MainWin *mw, const char *name, ListDialog *l,int item, PT
 	readtle = new KLineEdit("4",hb);
 	
 	hb = new QHBox(tab1);
-//	QStringList interpretlist;
-//	interpretlist << i18n("double")<< i18n("time")<< i18n("date");
 	i=0;
 	interpretxcb = new KComboBox(hb);
 	while(formatList[i] != 0) interpretxcb->insertItem(i18n(formatList[i++]));
+	interpretxcb->setCurrentItem(config->readNumEntry("XFormat",0));
 	i=0;
 	interpretycb = new KComboBox(hb);
 	while(formatList[i] != 0) interpretycb->insertItem(i18n(formatList[i++]));
+	interpretycb->setCurrentItem(config->readNumEntry("YFormat",0));
 	i=0;
 	interpretzcb = new KComboBox(hb);
 	while(formatList[i] != 0) interpretzcb->insertItem(i18n(formatList[i++]));
+	interpretzcb->setCurrentItem(config->readNumEntry("ZFormat",0));
 	i=0;
 	interprettcb = new KComboBox(hb);
 	while(formatList[i] != 0) interprettcb->insertItem(i18n(formatList[i++]));
+	interprettcb->setCurrentItem(config->readNumEntry("TFormat",0));
 
 	updateRead();
 
-	QString label=dat;
-	if (graph != 0) label = graph->Label();
-	new QLabel(i18n("Label : "),tab1);
-	hb = new QHBox(tab1);
-	labelle = new KLineEdit(label,hb);
-	KPushButton *setLabelpb = new KPushButton(i18n("Set Label"),hb);
-	QObject::connect(setLabelpb,SIGNAL(clicked()),SLOT(setLabel()));
-
+	QVBox *tab2 = new QVBox(tw);
+	Label* label = new Label(dat);
+	if (graph != 0)
+		label = graph->getLabel();
+	else 
+		label->readSettings(config,entry);
+	rtw = new RichTextWidget((QWidget *)tab2,label,0);
+	
 	tw->addTab(tab1,i18n("Parameter"));
+	tw->addTab(tab2,i18n("Label"));
 
 	// 3d style -> NoCurve
 	if(type == P3D) {
@@ -203,10 +213,11 @@ DataDialog::DataDialog(MainWin *mw, const char *name, ListDialog *l,int item, PT
 		wlist << list.at(i)->caption();
 	wlist<<i18n("new Worksheet")<<i18n("new Spreadsheet");
 	sheetcb->insertStringList(wlist);
-	sheetcb->setCurrentItem(0);	
+	sheetcb->setCurrentItem(mw->activeSheetIndex());	
 	
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
 	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	QObject::connect(save,SIGNAL(clicked()),SLOT(saveSettings()));
 	QObject::connect(cancel,SIGNAL(clicked()),SLOT(accept()));
 
 	setMinimumWidth(vbox->minimumSizeHint().width());
@@ -214,6 +225,33 @@ DataDialog::DataDialog(MainWin *mw, const char *name, ListDialog *l,int item, PT
 	resize(minimumSize());
 }
 
+void DataDialog::saveSettings() {
+	KConfig *config = mw->Config();
+
+	QString entry = QString("PlotType %1 ").arg(type);
+	
+	saveImportSettings();
+	config->setGroup( "Data" );
+	config->writeEntry(entry+"Reread",reread->isChecked());
+	config->writeEntry(entry+"ReadAs",cbi->currentItem());
+	config->writeEntry(entry+"XColumn",readxle->text().toInt());
+	config->writeEntry(entry+"YColumn",readyle->text().toInt());
+	config->writeEntry(entry+"ZColumn",readzle->text().toInt());
+	config->writeEntry(entry+"TColumn",readtle->text().toInt());
+	config->writeEntry(entry+"XFormat",interpretxcb->currentItem());
+	config->writeEntry(entry+"YFormat",interpretycb->currentItem());
+	config->writeEntry(entry+"ZFormat",interpretzcb->currentItem());
+	config->writeEntry(entry+"TFormat",interprettcb->currentItem());
+
+	rtw->getLabel()->saveSettings(config,entry);
+
+	if(type != PQWT3D && type != PSURFACE) {
+		config->writeEntry(entry+"Annotate Type",typecb->currentItem());
+		config->writeEntry(entry+"Annotate Position",positioncb->currentItem());
+		config->writeEntry(entry+"Annotate Distance",distance->value());
+	}
+}
+
 //! update readline and label when changing "read as"
 void DataDialog::updateRead() {
 	kdDebug()<<"DataDialog::updateRead()"<<endl;
@@ -543,7 +581,7 @@ void DataDialog::checkData() {
 								line = line.simplifyWhiteSpace();
 	
 							// ignore comment lines
-							if(line.find(QRegExp(commcb->currentText()))==0)
+							if(line.startsWith(commcb->currentText()) == true)
 								continue;
 	
 							QString sep = sccb->currentText();
@@ -585,13 +623,16 @@ void DataDialog::checkData() {
 				
 				int k=0;
 				for ( QStringList::Iterator it2 = oneline.begin(); it2 != oneline.end(); ++it2 ) {
+					LTableItem *item = new LTableItem( table, QTableItem::OnTyping,*it2);
+					
 					if (type == P2D && cbi->currentItem() == 4) {
-						//table->setText(k,0,QString::number(k+1));
-						table->setText(j,k,*it2);
+						// OLD : table->setText(j,k,*it2);
+						table->setItem(j, k, item);
 						k++;
 					}
 					else
-						table->setText(j,k++,*it2);
+						// OLD : table->setText(j,k++,*it2);
+						table->setItem(j, k++, item);
 				}
 				j++;
 			}
@@ -604,7 +645,7 @@ void DataDialog::checkData() {
 void DataDialog::applyStyle() {
 	kdDebug()<<"DataDialog:applyStyle()"<<endl;
 	if(p == 0) return;
-
+	
 	if(type == PSURFACE) {
 		Plot2DSurface *plot = (Plot2DSurface *)p->getPlot(p->API());
 
@@ -612,7 +653,7 @@ void DataDialog::applyStyle() {
 			plot->enableDensity(dcb->isChecked());
 			plot->enableContour(ccb->isChecked());
 			plot->setNumber(numberle->text().toInt());
-			plot->setPalette(pcb->currentItem());
+			// plot->setPalette(pcb->currentItem());
 			plot->setContourColor(contourcolor->color());
 			plot->setColoredContour(coloredcb->isChecked());
 			plot->setMesh(meshcb->isChecked());
@@ -622,11 +663,14 @@ void DataDialog::applyStyle() {
 		}
 	}
 	else {
-		Style *style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),widthle->text().toInt(),
+		Style *style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),width->value(),
 			pencb->currentItem(),brushcb->currentItem());
-		Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->text().toInt(),
+		style->setBoxWidth(boxwidth->value());
+		style->setAutoBoxWidth(autobox->isChecked());
+		style->setPointsSorting(sortpointscb->isChecked());
+		Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->value(),
 			(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());
-		AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distancele->text().toInt());
+		AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distance->value());
 
 		if (graph != 0) {
 			graph->setStyle(style);
@@ -636,12 +680,12 @@ void DataDialog::applyStyle() {
 		}
 	}
 
-	QString label = labelle->text();
-	kdDebug()<<"Label : "<<label<<endl;
+	Label *label = rtw->label();
 	if (graph)
 		graph->setLabel(label);
 
 	if(p) p->updatePixmap();
+	kdDebug()<<"DataDialog:applyStyle() OK"<<endl;
 }
 
 // equal to FunctionDialog::findPlot()
@@ -684,9 +728,6 @@ int DataDialog::apply_clicked() {
 			return status;
 	}
 	
-	// update "last" values
-	mw->last_readas = cbi->currentItem();
-
 	applyStyle();
 
 	return 0;
@@ -694,14 +735,14 @@ int DataDialog::apply_clicked() {
 
 // called from addData if image x-y is selected
 int DataDialog::addDataIMAGEXY(QImage image, QString filename) {
-	int width = image.width();
-	int height = image.height();
-	Point *ptr = new Point[width*height];
+	int iwidth = image.width();
+	int iheight = image.height();
+	Point *ptr = new Point[iwidth*iheight];
 	
 	double ymin=0, ymax=1;
-	for (int i=0;i<width;i++) {
-		for (int j=0;j<height;j++) {
-			double x = j+i*height;
+	for (int i=0;i<iwidth;i++) {
+		for (int j=0;j<iheight;j++) {
+			double x = j+i*iheight;
 			double y = (double) qGray(image.pixel(i,j));
 
 			if (i == 0 && j == 0) {
@@ -711,21 +752,25 @@ int DataDialog::addDataIMAGEXY(QImage image, QString filename) {
 				y<ymin?ymin=y:0;
 				y>ymax?ymax=y:0;
 			}
-			ptr[j+i*height].setPoint(x,y);
-			ptr[j+i*height].setMasked(false);
+			ptr[j+i*iheight].setPoint(x,y);
+			ptr[j+i*iheight].setMasked(false);
 		}
 	}
 	LRange range[2];
-	range[0] = LRange(0,width*height);
+	range[0] = LRange(0,iwidth*iheight);
 	range[1] = LRange(ymin,ymax);
 
 	Style *style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
-		widthle->text().toInt(),pencb->currentItem(),brushcb->currentItem());
-	Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->text().toInt(),
+		width->value(),pencb->currentItem(),brushcb->currentItem());
+	style->setBoxWidth(boxwidth->value());
+	style->setAutoBoxWidth(autobox->isChecked());
+	style->setPointsSorting(sortpointscb->isChecked());
+	Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->value(),
 		(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());
-	Graph2D *g = new Graph2D(filename.latin1(),labelle->text(),range,SDATA,type,style,symbol,ptr,width*height);
+	Graph2D *g = new Graph2D(filename.latin1(),rtw->getLabel()->Title(),range,SDATA,type,style,symbol,ptr,iwidth*iheight);
+	g->setLabel(rtw->getLabel());
 
-	AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distancele->text().toInt());
+	AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distance->value());
 	g->setAnnotateValues(av);	
 	g->setReadAs(cbi->currentItem());
 
@@ -736,13 +781,14 @@ int DataDialog::addDataIMAGEXY(QImage image, QString filename) {
 
 // called from addData if image x-y-z is selected
 int DataDialog::addDataIMAGEXYZ(QImage image, QString filename) {
-	int width = image.width();
-	int height = image.height();
+	kdDebug()<<"addDataIMAGEXYZ()"<<endl;
+	int iwidth = image.width();
+	int iheight = image.height();
 	int number = INC_VALUE;
 	Point3D *ptr = (Point3D *) malloc(number*sizeof(Point3D));
 	double xmin=0, xmax=1, ymin=0, ymax=1, zmin=0, zmax=1;
-	for (int i=0;i<width;i++) {
-		for (int j=0;j<height;j++) {
+	for (int i=0;i<iwidth;i++) {
+		for (int j=0;j<iheight;j++) {
 			double x = i, y = j, z = (double) qGray(image.pixel(i,j));
 
 			if (i == 0 && j == 0) {
@@ -753,12 +799,12 @@ int DataDialog::addDataIMAGEXYZ(QImage image, QString filename) {
 				z>zmax?zmax=z:0;
 			}
 			
-			if(j+i*height>=number) {
+			if(j+i*iheight>=number) {
 				number += INC_VALUE;
 				ptr = (Point3D *) realloc(ptr,number*sizeof(Point3D));
 			}
-			ptr[j+i*height].setPoint(x,y,z);
-			ptr[j+i*height].setMasked(false);
+			ptr[j+i*iheight].setPoint(x,y,z);
+			ptr[j+i*iheight].setMasked(false);
 		}
 	}
 
@@ -768,12 +814,16 @@ int DataDialog::addDataIMAGEXYZ(QImage image, QString filename) {
 	range[2] = LRange(zmin,zmax);
 
 	Style *style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),
-		fcolor->color(),widthle->text().toInt(),pencb->currentItem(),brushcb->currentItem());
-	Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->text().toInt(),
+		fcolor->color(),width->value(),pencb->currentItem(),brushcb->currentItem());
+	style->setBoxWidth(boxwidth->value());
+	style->setAutoBoxWidth(autobox->isChecked());
+	style->setPointsSorting(sortpointscb->isChecked());
+	Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->value(),
 		(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());
 
-	Graph3D *g = new Graph3D(filename.latin1(),labelle->text(),range,SDATA,type,style,symbol,ptr,width*height,1);
-	AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distancele->text().toInt());
+	Graph3D *g = new Graph3D(filename.latin1(),rtw->getLabel()->Title(),range,SDATA,type,style,symbol,ptr,iwidth*iheight,1);
+	g->setLabel(rtw->getLabel());
+	AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distance->value());
 	g->setAnnotateValues(av);
 	g->setReadAs(cbi->currentItem());
 	mw->addGraph3D(g,sheetcb->currentItem());
@@ -783,12 +833,14 @@ int DataDialog::addDataIMAGEXYZ(QImage image, QString filename) {
 
 // called from addData if image matrix is selected
 int DataDialog::addDataIMAGEMATRIX(QImage image, QString filename) {
-	int width = image.width();
-	int height = image.height();
-	double *ptr=new double[width*height];
+	kdDebug()<<"addDataIMAGEMATRIX()"<<endl;
+	int iwidth = image.width();
+	int iheight = image.height();
+//	kdDebug()<<"IMAGE WIDTH/HEIGHT : "<<iwidth<<' '<<iheight<<endl;
+	double *ptr = new double[iwidth*iheight];
 	double zmin=0,zmax=1;
-	for (int i=0;i<height;i++) {
-		for (int j=0;j<width;j++) {
+	for (int i=0;i<iheight;i++) {
+		for (int j=0;j<iwidth;j++) {
 			double z = (double) qGray(image.pixel(j,i));
 
 			if (i == 0 && j == 0) {
@@ -798,13 +850,13 @@ int DataDialog::addDataIMAGEMATRIX(QImage image, QString filename) {
 				z<zmin?zmin=z:0;
 				z>zmax?zmax=z:0;
 			}
-			ptr[j+i*width] = z;
+			ptr[j+i*iwidth] = z;
 		}
 	}
 
 	LRange range[3];
-	range[0] = LRange(0,width);
-	range[1] = LRange(0,height);
+	range[0] = LRange(0,iwidth);
+	range[1] = LRange(0,iheight);
 	range[2] = LRange(zmin,zmax);
 
 	GraphM *g;
@@ -812,17 +864,21 @@ int DataDialog::addDataIMAGEMATRIX(QImage image, QString filename) {
 	if (type == PSURFACE) {
 		Style *style = new Style(0);
 		Symbol *symbol = new Symbol(SNONE);
-		g = new GraphM(filename.latin1(),labelle->text(),range,SDATA,type,style,symbol,ptr,width,height);
+		g = new GraphM(filename.latin1(),rtw->getLabel()->Title(),range,SDATA,type,style,symbol,ptr,iwidth,iheight);
 	}
 	else {
 		Style *style =new Style(cb2->currentItem(),color->color(), filled->isChecked(), fcolor->color(), 
-			widthle->text().toInt(), pencb->currentItem(),brushcb->currentItem());
+			width->value(), pencb->currentItem(),brushcb->currentItem());
+		style->setBoxWidth(boxwidth->value());
+		style->setAutoBoxWidth(autobox->isChecked());
+		style->setPointsSorting(sortpointscb->isChecked());
 		Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),
-			ssize->text().toInt(),(FType)symbolfillcb->currentItem(),sfcolor->color(),
+			ssize->value(),(FType)symbolfillcb->currentItem(),sfcolor->color(),
 			sbrushcb->currentItem());
-		g = new GraphM(filename.latin1(),labelle->text(),range,SDATA,type,style,symbol,ptr,width,height);
+		g = new GraphM(filename.latin1(),rtw->getLabel()->Title(),range,SDATA,type,style,symbol,ptr,iwidth,iheight);
 	}
 	g->setReadAs(cbi->currentItem());
+	g->setLabel(rtw->getLabel());
 	mw->addGraphM(g,sheetcb->currentItem(),type);
 
 	return 0;
@@ -830,6 +886,7 @@ int DataDialog::addDataIMAGEMATRIX(QImage image, QString filename) {
 
 // called from addData if image image is selected
 int DataDialog::addDataIMAGEIMAGE(QImage image, QPixmap pm, QString filename) {
+	kdDebug()<<"addDataIMAGEIMAGE()"<<endl;
 	int width = image.width();
 	int height = image.height();
 	// create GRAPHIMAGE
@@ -840,12 +897,13 @@ int DataDialog::addDataIMAGEIMAGE(QImage image, QPixmap pm, QString filename) {
 	range[0] = LRange(0,width);
 	range[1] = LRange(0,height);
 	range[2] = LRange(0,1);		// TODO
-	GraphIMAGE *g = new GraphIMAGE(filename.latin1(),labelle->text(),range,SDATA,type,style,symbol,pm,width,height);
+	GraphIMAGE *g = new GraphIMAGE(filename.latin1(),rtw->getLabel()->Title(),range,SDATA,type,style,symbol,pm,width,height);
+	g->setLabel(rtw->getLabel());
 	g->setReadAs(cbi->currentItem());
 	mw->addGraphIMAGE(g,sheetcb->currentItem());
 	// TODO : is that correct ?
-	Plot *plot = p->getPlot(p->API());
-	plot->getLegend()->enable(false);	// disable legend
+	//Plot *plot = p->getPlot(p->API());
+	//plot->getLegend()->enable(false);	// disable legend
 	// occupy space of legend for drawing area (bad hack :-\)
 	//int xmax = (int)(p->width()*(plot->getSize().X()*plot->getP2().X()+plot->getPosition().X()));
 	//plot->setXMax(xmax+(int)(120*plot->getSize().X()),p->width());
@@ -1015,7 +1073,7 @@ int DataDialog::addDataXY(QIODevice *file,QTextStream *t, QDataStream *d, QStrin
 			if(simplifycb->isChecked())
 				line = line.simplifyWhiteSpace();
 			// ignore comment lines	
-			if(line.find(QRegExp(commcb->currentText()))==0)
+			if(line.startsWith(commcb->currentText()) == true)
 				return 2;
 			
 			QString sep = sccb->currentText();
@@ -1119,7 +1177,7 @@ int DataDialog::addDataXY(QIODevice *file,QTextStream *t, QDataStream *d, QStrin
 					if(simplifycb->isChecked())
 						line = line.simplifyWhiteSpace();
 					// ignore comment lines	
-					if(line.find(QRegExp(commcb->currentText()))==0)
+					if(line.startsWith(commcb->currentText()) == true)
 						continue;
 
 					QString sep = sccb->currentText();
@@ -1178,13 +1236,17 @@ int DataDialog::addDataXY(QIODevice *file,QTextStream *t, QDataStream *d, QStrin
 	range[0] = LRange(xmin,xmax);
 	range[1] = LRange(ymin,ymax);
 
-	Style *style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),widthle->text().toInt(),
+	Style *style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),width->value(),
 		pencb->currentItem(),brushcb->currentItem());
-	Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->text().toInt(),
+	style->setBoxWidth(boxwidth->value());
+	style->setAutoBoxWidth(autobox->isChecked());
+	style->setPointsSorting(sortpointscb->isChecked());
+	Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->value(),
 		(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());
-	Graph2D *g = new Graph2D(filename.latin1(),labelle->text(),range,SDATA,type,style,symbol,ptr,i-startRow);
+	Graph2D *g = new Graph2D(filename.latin1(),rtw->getLabel()->Title(),range,SDATA,type,style,symbol,ptr,i-startRow);
+	g->setLabel(rtw->getLabel());
 	
-	AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distancele->text().toInt());
+	AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distance->value());
 	g->setAnnotateValues(av);
 	g->setReadAs(cbi->currentItem());
 	mw->addGraph2D(g,sheetcb->currentItem(),(PType) type);
@@ -1439,7 +1501,7 @@ int DataDialog::addDataXYZ(QIODevice *file,QTextStream *t, QDataStream *d, QStri
 				if(simplifycb->isChecked())
 					line = line.simplifyWhiteSpace();
 				// ignore comment lines
-				if(line.find(QRegExp(commcb->currentText()))==0)
+				if(line.startsWith(commcb->currentText()) == true)
 					continue;
 				
 				QString sep = sccb->currentText();
@@ -1499,7 +1561,7 @@ int DataDialog::addDataXYZ(QIODevice *file,QTextStream *t, QDataStream *d, QStri
 					z>zmax?zmax=z:0;
 				}
 
-				//kdDebug()<<"X/Y/Z = "<<x<<' '<<y<<' '<<z<<endl;
+				kdDebug()<<"X/Y/Z = "<<x<<' '<<y<<' '<<z<<endl;
 
 				if(i-startRow>=number) {
 					number += INC_VALUE;
@@ -1526,8 +1588,11 @@ int DataDialog::addDataXYZ(QIODevice *file,QTextStream *t, QDataStream *d, QStri
 	int rows=i-startRow, cols=1;
 	if(type == P2D) {
 		style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
-			widthle->text().toInt(),pencb->currentItem(),brushcb->currentItem());
-		symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->text().toInt(),
+			width->value(),pencb->currentItem(),brushcb->currentItem());
+		style->setBoxWidth(boxwidth->value());
+		style->setAutoBoxWidth(autobox->isChecked());
+		style->setPointsSorting(sortpointscb->isChecked());
+		symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->value(),
 			(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());	
 	}
 	else if (type == PSURFACE || type == PQWT3D || type == P3D) {
@@ -1557,9 +1622,10 @@ int DataDialog::addDataXYZ(QIODevice *file,QTextStream *t, QDataStream *d, QStri
 	}
 	kdDebug()<<"	rows/cols = "<<rows<<'/'<<cols<<endl;
 
-	Graph3D *g = new Graph3D(filename.latin1(),labelle->text(),range,SDATA,type,style,symbol,ptr,rows,cols);
+	Graph3D *g = new Graph3D(filename.latin1(),rtw->getLabel()->Title(),range,SDATA,type,style,symbol,ptr,rows,cols);
+	g->setLabel(rtw->getLabel());
 	if(type != PSURFACE) {
-		AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distancele->text().toInt());
+		AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distance->value());
 		g->setAnnotateValues(av);
 	}
 	g->setReadAs(cbi->currentItem());
@@ -1819,7 +1885,7 @@ int DataDialog::addDataXYZT(QIODevice *file,QTextStream *t, QDataStream *d, QStr
 				if(simplifycb->isChecked())
 					line = line.simplifyWhiteSpace();
 				// ignore comment lines
-				if(line.find(QRegExp(commcb->currentText()))==0)
+				if(line.startsWith(commcb->currentText()) == true)
 					continue;
 				
 				QString sep = sccb->currentText();
@@ -1898,12 +1964,16 @@ int DataDialog::addDataXYZT(QIODevice *file,QTextStream *t, QDataStream *d, QStr
 	range[3] = LRange(tmin,tmax);
 
 	Style *style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
-		widthle->text().toInt(),pencb->currentItem(),brushcb->currentItem());
-	Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->text().toInt(),
+		width->value(),pencb->currentItem(),brushcb->currentItem());
+	style->setBoxWidth(boxwidth->value());
+	style->setAutoBoxWidth(autobox->isChecked());
+	style->setPointsSorting(sortpointscb->isChecked());
+	Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->value(),
 		(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());
 
-	Graph4D *g = new Graph4D(filename.latin1(),labelle->text(),range, SDATA,
+	Graph4D *g = new Graph4D(filename.latin1(),rtw->getLabel()->Title(),range, SDATA,
 		type,style,symbol,ptr,i-startRow,cbi->currentItem()-2);
+	g->setLabel(rtw->getLabel());
 	g->setReadAs(cbi->currentItem());
 	mw->addGraph4D(g,sheetcb->currentItem());
 
@@ -2017,7 +2087,7 @@ int DataDialog::addDataMATRIX(QIODevice *file,QTextStream *t, QDataStream *d, QS
 				if(simplifycb->isChecked())
 					line = line.simplifyWhiteSpace();
 				// ignore comment lines
-				if(line.find(QRegExp(commcb->currentText()))==0)
+				if(line.startsWith(commcb->currentText()) == true)
 					continue;
 				
 				QString sep = sccb->currentText();
@@ -2075,16 +2145,20 @@ int DataDialog::addDataMATRIX(QIODevice *file,QTextStream *t, QDataStream *d, QS
 	if (type == PSURFACE) {
 		Style *style = new Style(0);
 		Symbol *symbol = new Symbol(SNONE);
-		g = new GraphM(filename.latin1(),labelle->text(),range, SDATA, type,style,symbol,ptr,numberx,i);
+		g = new GraphM(filename.latin1(),rtw->getLabel()->Title(),range, SDATA, type,style,symbol,ptr,numberx,i);
 	}
 	else {
 		Style *style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
-			widthle->text().toInt(),pencb->currentItem(),brushcb->currentItem());
+			width->value(),pencb->currentItem(),brushcb->currentItem());
+		style->setBoxWidth(boxwidth->value());
+		style->setAutoBoxWidth(autobox->isChecked());
+		style->setPointsSorting(sortpointscb->isChecked());
 		Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),
-			ssize->text().toInt(),(FType)symbolfillcb->currentItem(),sfcolor->color(),
+			ssize->value(),(FType)symbolfillcb->currentItem(),sfcolor->color(),
 			sbrushcb->currentItem());
-		g = new GraphM(filename.latin1(),labelle->text(),range, SDATA, type,style,symbol,ptr,numberx,i);
+		g = new GraphM(filename.latin1(),rtw->getLabel()->Title(),range, SDATA, type,style,symbol,ptr,numberx,i);
 	}
+	g->setLabel(rtw->getLabel());
 	g->setReadAs(cbi->currentItem());
 	mw->addGraphM(g,sheetcb->currentItem(),type);
 
@@ -2097,10 +2171,9 @@ int DataDialog::addData() {
 	if(graph != 0)
 		p->getPlot(p->API())->getGraphList()->delGraph(item);
 
-	QString label = labelle->text();
+	QString label = rtw->getLabel()->Title();
 	int mode = cbi->currentItem();
 	
-	mw->last_filename=filele->text();
 	QStringList fns = QStringList::split(";",filele->text());
 	 for ( QStringList::Iterator it = fns.begin(); it != fns.end(); ++it ) {
 		QString filename = *it;
@@ -2121,15 +2194,16 @@ int DataDialog::addData() {
 #endif
 				QPixmap pm;
 #ifdef HAVE_MAGICK
+// makes problems
 				if(mf.fileOK())
 					pm = mf.Pixmap();
 				else
 #endif
 					pm.load(filename);
-	
+
 				QImage image = pm.convertToImage();
-				//kdDebug() <<" Width/Height : "<<width<<' '<<height<<endl;
-				//kdDebug() <<" Depth : "<<image.depth()<<endl;
+				kdDebug() <<" Format : "<<format<<endl;
+				kdDebug() <<" Depth : "<<image.depth()<<endl;
 	
 				int res;
 				if (type == P2D || type == PPIE || type == PPOLAR ) {
@@ -2204,14 +2278,10 @@ int DataDialog::addData() {
 double DataDialog::getValue(FilterAUDIOFILE auf, int var, int i, double *data, int startRow) {
 	int index=0;
 	switch (var) {
-	case 1:	// x
-		index = readxle->text().toInt();break;
-	case 2:	// y
-		index = readyle->text().toInt();break;
-	case 3:	// z
-		index = readzle->text().toInt();break;
-	case 4:	// t
-		index = readtle->text().toInt();break;
+	case 1:	index = readxle->text().toInt();break;
+	case 2:	index = readyle->text().toInt();break;
+	case 3:	index = readzle->text().toInt();break;
+	case 4:	index = readtle->text().toInt();break;
 	}
 	
 	double value=0;
