@@ -13,7 +13,9 @@
 
 #include "Dialog.h"
 #include "Plot2DSurface.h"
+#include "PlotQWT3D.h"
 #include "FileInfoDialog.h"
+#include "ColormapReader.h"
 #include "importitems.h"
 #include "filteritems.h"
 #include "defs.h"
@@ -28,6 +30,7 @@ Dialog::Dialog(MainWin *mw, const char *name)
 
 	ok = new KPushButton(i18n("OK"),gbox);
 	apply = new KPushButton(i18n("Apply"),gbox);
+	save = new KPushButton(i18n("Save"),gbox);
 	cancel = new KPushButton(i18n("Cancel"),gbox);
 	QObject::connect(cancel,SIGNAL(clicked()),SLOT(reject()));
 }
@@ -40,6 +43,83 @@ void Dialog::resizeEvent(QResizeEvent *e) {
 	vbox->setGeometry(0,0,s.width(),s.height()-50);
 }
 
+void Dialog::selectColormap() {
+	ColorMapPreview *colormap = new ColorMapPreview;
+	// modal. otherwise problems occur in configure dialog
+	QFileDialog *datacolor = new QFileDialog(this,0,true);
+
+	QString cmdir = locate("data","LabPlot/colormaps/");
+	datacolor->setDir(cmdir);
+	datacolor->setFilter("Colormap files (*.map;*.MAP)");
+	datacolor->setContentsPreviewEnabled( true );
+	datacolor->setContentsPreview( colormap, colormap);
+	datacolor->setPreviewMode( QFileDialog::Contents );
+
+	connect(datacolor, SIGNAL(fileHighlighted(const QString&)), this, SLOT(adaptDataColors(const QString&)));
+	datacolor->show();
+}
+
+void Dialog::adaptDataColors(const QString& fn) {
+#ifdef HAVE_GL
+	if (!openColorMap(fn))
+		return;
+
+	KConfig *config = mw->Config();
+	config->setGroup( "Plot Surface Style" );
+	config->writeEntry("Colorscale",fn);
+
+	if(p == 0)
+		return;
+	Plot *plot = p->getPlot(p->API());
+	if(plot == 0)
+		return;
+	switch(plot->Type()) {
+	case PQWT3D: {	
+		Qwt3D::StandardColor *col = new Qwt3D::StandardColor((PlotQWT3D *)plot);
+		col->setColorVector(cv);
+	
+		((PlotQWT3D *) plot)->setColorVector(cv);
+		}; break;
+	case PSURFACE:
+		((Plot2DSurface *) plot)->setColorVector(cv);
+		break;
+	default:
+		kdDebug()<<" ERROR setting colormap"<<endl;
+		break;
+	}
+#endif
+}
+
+bool Dialog::openColorMap(QString fn) {
+#ifdef HAVE_GL
+	kdDebug()<<"openColorMap("<<fn<<")"<<endl;
+	ifstream file((const char*)fn.local8Bit());
+
+	if (!file) return false;
+
+	Qwt3D::RGBA rgb;
+	cv.clear();
+
+	while ( file ) {
+		file >> rgb.r >> rgb.g >> rgb.b;
+		file.ignore(1000,'\n');
+		if (!file.good())
+			break;
+		else {
+			rgb.a = 1;
+			rgb.r /= 255;
+			rgb.g /= 255;
+			rgb.b /= 255;
+			cv.push_back(rgb);
+		}
+	}
+
+	return true;
+#else
+	return false;
+#endif
+}
+
 //! used from dialogs for surface plots
 QVBox* Dialog::surfaceStyle(QTabWidget *tw, bool fresh) {
 	kdDebug()<<"Dialog::surfaceStyle()"<<endl;
@@ -102,32 +182,21 @@ QVBox* Dialog::surfaceStyle(QTabWidget *tw, bool fresh) {
 	hb = new QHBox(styletab);
 	new QLabel(i18n(" Color Palette : "),hb);
 	//palabel->setAlignment(Qt::AlignHCenter);
-	pcb = new KComboBox(hb);
-	for (int j=0;j<21;j++) {		// all palettes
-		QPainter pa;
-		QPixmap pm(255,25);
-		pa.begin(&pm);
-		pm.fill(Qt::white);
 
-		for (int i=0;i<255;i++) {
-			pa.setPen(plot->Color(i,j));
-			pa.drawLine(i,0,i,25);
-		}
-
-		pa.end();
-		pcb->insertItem(pm);
-	}
-	pcb->setCurrentItem(fresh?config->readNumEntry("Palette",0):plot->Palette());
+	// use QWT colorscale
+	KPushButton *colormap = new KPushButton(i18n("Colormap"),hb);
+	QObject::connect(colormap,SIGNAL(clicked()),SLOT(selectColormap()));
 
 	return styletab;
 }
 
 void Dialog::setStyle(Style *s) {
 	cb2->setCurrentItem(s->Type());
-	boxwidthle->setText(QString::number(s->BoxWidth()));
+	sortpointscb->setChecked(s->PointsSortingEnabled());
+	boxwidth->setValue(s->BoxWidth());
 	autobox->setChecked(s->AutoBoxWidth());
 	color->setColor(s->Color());
-	widthle->setText(QString::number(s->Width()));
+	width->setValue(s->Width());
 	pencb->setCurrentItem(s->PenStyle());
 	filled->setChecked(s->isFilled());
 	fcolor->setColor(s->FillColor());
@@ -137,7 +206,7 @@ void Dialog::setStyle(Style *s) {
 void Dialog::setSymbol(Symbol *s) {
 	symbolcb->setCurrentItem(s->Type());
 	scolor->setColor(s->Color());
-	ssize->setText(QString::number(s->Size()));
+	ssize->setValue(s->Size());
 	symbolfillcb->setCurrentItem(s->Fill());
 	sfcolor->setColor(s->FillColor());
 	sbrushcb->setCurrentItem(s->Brush());
@@ -149,29 +218,32 @@ QVBox* Dialog::simpleStyle(QTabWidget *tw, Style *style, Symbol *symbol) {
 	KConfig *config = mw->Config();
 	config->setGroup( "Plot Simple Style" );
 
-	QHBox *hb = new QHBox(styletab);
-	new QLabel(i18n("Graph Style : "),hb);
+	QGroupBox *stylegb = new QGroupBox(1,QGroupBox::Horizontal,i18n("Style"),styletab);
+	QHBox *hb = new QHBox(stylegb);
+	new QLabel(i18n(" Type : "),hb);
 	cb2 = new KComboBox(hb);
 	QStringList stylelist;
 	stylelist<<i18n("Lines")<<i18n("NoCurve")<<i18n("Steps")<<i18n("Boxes")<<i18n("Impulses")<<i18n("Y Boxes");
 	cb2->insertStringList(stylelist);
 	cb2->setCurrentItem(style==0?config->readNumEntry("Graph Style",0):style->Type());
+	sortpointscb = new QCheckBox(i18n("sort points"),hb);
+	sortpointscb->setChecked(style==0?config->readBoolEntry("Sort Points",true):style->PointsSortingEnabled());
 
-	hb = new QHBox(styletab);
+	hb = new QHBox(stylegb);
 	new QLabel(i18n(" Box width : "),hb);
-	boxwidthle = new KLineEdit(QString::number(style==0?config->readNumEntry("Box Width",10):style->BoxWidth()),hb);
-	boxwidthle->setValidator(new QIntValidator(1,1000,boxwidthle));
-	autobox = new QCheckBox(i18n("auto box width "),hb);
+	boxwidth = new KIntNumInput(style==0?config->readNumEntry("Box Width",10):style->BoxWidth(),hb);
+	boxwidth->setRange(1,1000,1,false);
+	autobox = new QCheckBox(i18n("auto box width"),hb);
 	autobox->setChecked(style==0?config->readBoolEntry("Auto Box Width",false):style->AutoBoxWidth());
 	
-	hb = new QHBox(styletab);
+	hb = new QHBox(stylegb);
 	new QLabel(i18n("   Color : "),hb);
 	color = new KColorButton(style==0?config->readColorEntry("Style Color",&Qt::blue):style->Color(),hb);
 	QObject::connect(color,SIGNAL(changed(const QColor &)),this,SLOT(styleChanged()));
-	hb = new QHBox(styletab);
+	hb = new QHBox(stylegb);
 	new QLabel(i18n(" Line Width : "),hb);
-	widthle = new KLineEdit(QString::number(style==0?config->readNumEntry("Style Width",1):style->Width()),hb);
-	widthle->setValidator(new QIntValidator(widthle));
+	width = new KIntNumInput(style==0?config->readNumEntry("Style Width",1):style->Width(),hb);
+	width->setMinValue(0);
 	new QLabel(i18n(" Style : "),hb);
 	pencb = new KComboBox(hb);
 	pencb->clear();
@@ -189,13 +261,13 @@ QVBox* Dialog::simpleStyle(QTabWidget *tw, Style *style, Symbol *symbol) {
 	}
 	pencb->setCurrentItem(style==0?config->readNumEntry("Pen Style",1):style->PenStyle());
 
-	hb = new QHBox(styletab);
+	hb = new QHBox(stylegb);
 	filled = new QCheckBox(i18n("Filled "),hb);
 	filled->setChecked(style==0?config->readBoolEntry("Filled",false):style->isFilled());
 	fcolor = new KColorButton(style==0?config->readColorEntry("Fill Color",&Qt::green):style->FillColor(),hb);
 	QObject::connect(fcolor,SIGNAL(changed(const QColor &)),this,SLOT(styleChanged()));
 
-	hb = new QHBox(styletab);
+	hb = new QHBox(stylegb);
 	new QLabel(i18n("    Brush : "),hb);
 	brushcb = new KComboBox(hb);
 	fillBrushBox(brushcb,SRECT,Qt::blue,FFULL,fcolor->color());
@@ -209,34 +281,34 @@ QVBox* Dialog::simpleStyle(QTabWidget *tw, Style *style, Symbol *symbol) {
 	int sysize = (symbol==0?config->readNumEntry("Symbol Size",5):symbol->Size());
 	int sbrush = (symbol==0?config->readNumEntry("Symbol Brush",1):symbol->Brush());
 	
-	hb = new QHBox(styletab);
-	new QLabel(i18n("Graph Symbol : "),hb);
+	QGroupBox *symbolgb = new QGroupBox(1,QGroupBox::Horizontal,i18n("Symbol"),styletab);
+	hb = new QHBox(symbolgb);
+	new QLabel(i18n(" Type : "),hb);
 	symbolcb = new KComboBox(hb);
 	fillSymbolBox(sycolor,sfill,syfillcolor,sbrush);
 	symbolcb->setCurrentItem(stype);
 	QObject::connect(symbolcb,SIGNAL(activated(int)),this,SLOT(symbolChanged()));
-	hb = new QHBox(styletab);
-	new QLabel(i18n("    Color : "),hb);
 	scolor = new KColorButton(sycolor,hb);
 	QObject::connect(scolor,SIGNAL(changed(const QColor &)),this,SLOT(symbolChanged()));
 	
-	hb = new QHBox(styletab);
+	hb = new QHBox(symbolgb);
 	new QLabel(i18n("    Size : "),hb);
-	ssize = new KLineEdit(QString::number(sysize),hb);
-	ssize->setValidator(new QIntValidator(1,20,ssize));
+	ssize = new KIntNumInput(sysize,hb);
+	ssize->setRange(1,30);
 	
-	hb = new QHBox(styletab);
+	hb = new QHBox(symbolgb);
 	new QLabel(i18n("    Fill : "),hb);
 	symbolfillcb = new KComboBox(hb);
 	fillSymbolFillBox(stype,sycolor,syfillcolor,sbrush);
 	symbolfillcb->setCurrentItem(sfill);
 	QObject::connect(symbolfillcb,SIGNAL(activated(int)),this,SLOT(symbolChanged()));
-		
-	ssize->setText(QString::number(sysize));
+
+	// needed ???
+	ssize->setValue(sysize);
 	sfcolor = new KColorButton(syfillcolor,hb);
 	QObject::connect(sfcolor,SIGNAL(changed(const QColor &)),this,SLOT(symbolChanged()));
 
-	hb = new QHBox(styletab);
+	hb = new QHBox(symbolgb);
 	new QLabel(i18n("    Brush : "),hb);
 	sbrushcb = new KComboBox(hb);
 	fillBrushBox(sbrushcb,stype,sycolor,sfill,syfillcolor);
@@ -251,16 +323,18 @@ void Dialog::saveSimpleStyle() {
 	KConfig *config = mw->Config();
 	config->setGroup( "Plot Simple Style" );
 	config->writeEntry("Graph Style",cb2->currentItem());
-	config->writeEntry("Box Width",boxwidthle->text().toInt());
+	config->writeEntry("Sort Points",sortpointscb->isChecked());
+	config->writeEntry("Box Width",boxwidth->value());
 	config->writeEntry("Auto Box Width",autobox->isChecked());
 	config->writeEntry("Style Color",color->color());
-	config->writeEntry("Style Width",widthle->text().toInt());
+	config->writeEntry("Style Width",width->value());
 	config->writeEntry("Pen Style",pencb->currentItem());
 	config->writeEntry("Filled",filled->isChecked());
 	config->writeEntry("Fill Color",fcolor->color());
 	config->writeEntry("Brush",brushcb->currentItem());
 	
 	config->writeEntry("Symbol Type",symbolcb->currentItem());
+	config->writeEntry("Symbol Size",ssize->value());
 	config->writeEntry("Symbol Color",scolor->color());
 	config->writeEntry("Symbol Fill",symbolfillcb->currentItem());
 	config->writeEntry("Symbol Fill Color",sfcolor->color());
@@ -281,7 +355,6 @@ void Dialog::saveSurfaceStyle() {
 	config->writeEntry("Show Mesh",meshcb->isChecked());
 	config->writeEntry("Relative Colorscale",relativecb->isChecked());
 	config->writeEntry("Threshold",thresholdle->text().toDouble());
-	config->writeEntry("Palette",pcb->currentItem());
 }
 
 //! any style properties changed
@@ -314,16 +387,13 @@ QVBox* Dialog::annotateValuesTab(QTabWidget *tw, Graph *graph) {
 	list.clear();
 	list<<i18n("top")<<i18n("bottom")<<i18n("left")<<i18n("right");
 	positioncb->insertStringList(list);
-	if (graph)
+	if (graph != 0)
 		positioncb->setCurrentItem(graph->getAnnotateValues().Position());
 
 	hb = new QHBox(annotatetab);
 	new QLabel(i18n("Distance : "),hb);
-	QString distance("10");
-	if (graph)
-		distance=QString::number(graph->getAnnotateValues().Distance());
-	distancele = new KLineEdit(distance,hb);
-	distancele->setValidator(new QIntValidator(0,100,ssize));
+	distance = new KIntNumInput(graph!=0?graph->getAnnotateValues().Distance():10,hb);
+	distance->setRange(0,100);
 	
 	return annotatetab;
 }
@@ -402,7 +472,7 @@ void Dialog::fileInfo() {
 }
 
 void Dialog::selectFile() {
-	QStringList f = QFileDialog::getOpenFileNames(QString(""),QString(""), this );
+	QStringList f = QFileDialog::getOpenFileNames(QString::null,QString::null, this );
 	if (! f.isEmpty() )
 		filele->setText(f.join(";"));
 }
@@ -411,6 +481,9 @@ void Dialog::selectFile() {
 void Dialog::importWidget(QVBox *vb, QString filename, InputFilter filter) {
 	QGroupBox *gb = new QGroupBox(1,QGroupBox::Horizontal,i18n("Data Import"),vb);
 	
+	KConfig *config = mw->Config();
+	config->setGroup( "Import" );
+
 	QHBox *hb = new QHBox(gb);
 	
 	filele = new KLineEdit(filename,hb);
@@ -436,12 +509,14 @@ void Dialog::importWidget(QVBox *vb, QString filename, InputFilter filter) {
 	
 	hb = new QHBox(gb);
 	simplifycb = new QCheckBox(i18n("simplify whitespaces"),hb);
-	simplifycb->setChecked(true);
+	simplifycb->setChecked(config->readBoolEntry("SimplifyWhitespace",true));
 	emptycb = new QCheckBox(i18n("allow empty entries"),hb);
-	emptycb->setChecked(false);
+	emptycb->setChecked(config->readBoolEntry("EmptyEntries",false));
 	hb = new QHBox(gb);
 	headercb = new QCheckBox(i18n("import header"),hb);
-	headercb->setChecked(false);
+	headercb->setChecked(config->readBoolEntry("ImportHeader",false));
+	samexcb = new QCheckBox(i18n("x column from first file only"),hb);
+	samexcb->setChecked(config->readBoolEntry("SameXColumn",false));
 
 	hb = new QHBox(gb);
 	seplabel = new QLabel(i18n("separating character : "),hb);
@@ -449,6 +524,7 @@ void Dialog::importWidget(QVBox *vb, QString filename, InputFilter filter) {
 	sccb->setEditable(true);
 	sccb->insertStrList(separatoritems);
 	sccb->setMaximumWidth(100);
+	sccb->setCurrentText(config->readEntry("SeparatingCharacter","auto"));
 
 	hb = new QHBox(gb);
 	commlabel = new QLabel(i18n("comment character : "),hb);
@@ -456,17 +532,21 @@ void Dialog::importWidget(QVBox *vb, QString filename, InputFilter filter) {
 	commcb->setEditable(true);
 	commcb->insertStrList(commentitems);
 	commcb->setMaximumWidth(100);
+	commcb->setCurrentText(config->readEntry("CommentCharacter","#"));
 	hb = new QHBox(gb);
 	startlabel = new QLabel(i18n("Start Row : "),hb);
-	startle = new KLineEdit("1",hb);
+	startle = new KLineEdit(QString::number(config->readNumEntry("StartRow",1)),hb);
 	startle->setValidator(new QIntValidator(startle));
 	endlabel = new QLabel(i18n(" End Row : "),hb);
-	endle = new KLineEdit(i18n("END"),hb);
+	QString end = QString::number(config->readNumEntry("EndRow",-1));
+	if(end == "-1")
+		end = i18n("END");
+	endle = new KLineEdit(end,hb);
 
 	// only for binary data
 	hb = new QHBox(gb);
 	varlabel = new QLabel(i18n("variables : "),hb);
-	varle =  new KLineEdit("2",hb);
+	varle =  new KLineEdit(QString::number(config->readNumEntry("BinaryVariables",2)),hb);
 	varle->setValidator(new QIntValidator(1,INF,varle));
 	varlabel->hide();
 	varle->hide();
@@ -479,7 +559,30 @@ void Dialog::importWidget(QVBox *vb, QString filename, InputFilter filter) {
 	blist<<QString("double")<<QString("float")<<QString("long");
 	blist<<QString("int (8 Bit)")<<QString("int (16 Bit)")<<QString("int (32 Bit)")<<QString("int (64 Bit)");
 	binarytypecb->insertStringList(blist);
-	binarytypecb->setCurrentItem(0);
+	binarytypecb->setCurrentItem(config->readNumEntry("BinaryFormat",0));
+}
+
+void Dialog::saveImportSettings() {
+	KConfig *config = mw->Config();
+	config->setGroup( "Import" );
+
+	config->writeEntry("Filename",filele->text());
+	config->writeEntry("Filter",filtercb->currentItem());
+	config->writeEntry("SimplifyWhitespace",simplifycb->isChecked());
+	config->writeEntry("EmptyEntries",emptycb->isChecked());
+	config->writeEntry("ImportHeader",headercb->isChecked());
+	config->writeEntry("SameXColumn",samexcb->isChecked());
+	config->writeEntry("SeparatingCharacter",sccb->currentText());
+	config->writeEntry("CommentCharacter",commcb->currentText());
+	config->writeEntry("StartRow",startle->text().toInt());
+	int end=endle->text().toInt();
+	if(endle->text() == i18n("END"))
+		end=-1;
+	config->writeEntry("EndRow",end);
+
+	// binary stuff
+	config->writeEntry("BinaryVariables",varle->text().toInt());
+	config->writeEntry("BinaryFormat",binarytypecb->currentItem());
 }
 
 // update import settings when changing filter
@@ -556,7 +659,8 @@ void Dialog::updateFilter(int item) {
 }
 
 // split a line when reading data
-QStringList Dialog::splitLine(QString line,QString sep, bool empty) {
+QStringList Dialog::splitLine(QString line, QString sep, bool empty) {
+//	kdDebug()<<"Dialog::splitLine() : sep="<<sep<<endl;
 	QStringList oneline;
 	
 	if (sep == QString("auto"))
@@ -565,7 +669,7 @@ QStringList Dialog::splitLine(QString line,QString sep, bool empty) {
 		oneline = QStringList::split(QRegExp(QString("\t")), line, empty );
 	else
 		oneline = QStringList::split(sep.at(0), line, empty );
-
+	
 	return oneline;
 }
 
