@@ -20,6 +20,8 @@ FFTListDialog::FFTListDialog(MainWin *mw, const char *name)
 	: ListDialog(mw, name)
 {
 	setCaption(i18n("FFT Dialog"));
+	KConfig *config = mw->Config();
+	config->setGroup( "FFT" );
 
 	QTabWidget *tw = new QTabWidget(vbox);
 	QVBox *tab1 = new QVBox(tw);
@@ -35,7 +37,7 @@ FFTListDialog::FFTListDialog(MainWin *mw, const char *name)
 	llist << i18n("gsl");
 #endif
 	library->insertStringList(llist);
-	library->setCurrentItem(0);
+	library->setCurrentItem(config->readNumEntry("Library",0));
 
 	hb = new QHBox(tab1);
 	new QLabel(i18n("Transform : "),hb);
@@ -43,7 +45,7 @@ FFTListDialog::FFTListDialog(MainWin *mw, const char *name)
 	QStringList tlist;
 	tlist << i18n("forward") << i18n("backward");
 	transform->insertStringList(tlist);
-	transform->setCurrentItem(0);
+	transform->setCurrentItem(config->readNumEntry("Transformation",0));
 
 	hb = new QHBox(tab1);
 	new QLabel(i18n("x-values : "),hb);
@@ -51,7 +53,7 @@ FFTListDialog::FFTListDialog(MainWin *mw, const char *name)
 	QStringList vlist;
 	vlist << i18n("index")<< i18n("frequency") << i18n("period");
 	xvalues->insertStringList(vlist);
-	xvalues->setCurrentItem(0);
+	xvalues->setCurrentItem(config->readNumEntry("XValues",0));
 
 	hb = new QHBox(tab1);
 	new QLabel(i18n("y-values : "),hb);
@@ -59,14 +61,14 @@ FFTListDialog::FFTListDialog(MainWin *mw, const char *name)
 	QStringList ylist;
 	ylist << i18n("magnitude") << i18n("real") << i18n("imag") << i18n("phase");
 	yvalues->insertStringList(ylist);
-	yvalues->setCurrentItem(0);
+	yvalues->setCurrentItem(config->readNumEntry("YValues",0));
 
 	hb = new QHBox(tab1);
 	new QLabel(i18n("number of threads : "),hb);
-   	threadsle = new KLineEdit(QString("1"),hb);
-	threadsle->setValidator(new QIntValidator(1,INF,threadsle));
+	threadsni = new KIntNumInput(config->readNumEntry("Threads",1),hb);
+	threadsni->setRange(1,INF,1,false);
 #if ! defined(HAVE_FFTW3_THREADS)
-	threadsle->hide();
+	threadsni->hide();
 #endif
 
 	Style *style=0;
@@ -82,12 +84,24 @@ FFTListDialog::FFTListDialog(MainWin *mw, const char *name)
 
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
         QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	QObject::connect(save,SIGNAL(clicked()),SLOT(saveSettings()));
 
 	setMinimumWidth(vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
 	resize(minimumSize());
 }
 
+void FFTListDialog::saveSettings() {
+	KConfig *config = mw->Config();
+	config->setGroup( "FFT" );
+
+	config->writeEntry("Library", library->currentItem());
+	config->writeEntry("Transformation", transform->currentItem());
+	config->writeEntry("XValues", xvalues->currentItem());
+	config->writeEntry("YValues", yvalues->currentItem());
+	config->writeEntry("Threads", threadsni->value());
+}
+
 int FFTListDialog::apply_clicked() {
 	kdDebug()<<"	FFTListDialog::apply()"<<endl;
 	
@@ -110,8 +124,11 @@ int FFTListDialog::apply_clicked() {
 	Symbol *symbol=0;
 	if(st != GRAPHM) {
 		style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
-			widthle->text().toInt(),pencb->currentItem(),brushcb->currentItem());
-		symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->text().toInt(),
+			width->value(),pencb->currentItem(),brushcb->currentItem());
+		style->setBoxWidth(boxwidth->value());
+		style->setAutoBoxWidth(autobox->isChecked());
+		style->setPointsSorting(sortpointscb->isChecked());
+		symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->value(),
 			(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());
 	}
 	
@@ -135,7 +152,7 @@ int FFTListDialog::apply_clicked() {
 
 #if defined(HAVE_FFTW3_THREADS)
 	fftw_init_threads();
-	fftw_plan_with_nthreads(threadsle->text().toInt());
+	fftw_plan_with_nthreads(threadsni->value());
 #endif
 	
 	int nx=0,ny=0;
@@ -149,7 +166,7 @@ int FFTListDialog::apply_clicked() {
 		 if(st == GRAPH2D) {
 			Graph2D *g = gl->getGraph2D(item);
 			xrange = g->Range(0);
-			label = g->Label();
+			label = g->getLabel()->simpleTitle();
 			nx = g->Number();
 			Point *a = g->Data();
 			tmp = (double *) malloc(nx*sizeof(double));	
@@ -160,7 +177,7 @@ int FFTListDialog::apply_clicked() {
 		else if (st == GRAPH3D) {
 			Graph3D *g = gl->getGraph3D(item);
 			xrange = g->Range(0);
-			label = g->Label();
+			label = g->getLabel()->simpleTitle();
 			nx = g->Number();
 			Point3D *a = g->Data();
 			tmp = (double *) malloc(nx*sizeof(double));	
@@ -171,7 +188,7 @@ int FFTListDialog::apply_clicked() {
 		else if (st == GRAPH4D) {
 			Graph4D *g = gl->getGraph4D(item);
 			xrange = g->Range(0);
-			label = g->Label();
+			label = g->getLabel()->simpleTitle();
 			nx = g->Number();
 			Point4D *a = g->Data();
 			tmp = (double *) malloc(nx*sizeof(double));	
@@ -248,11 +265,19 @@ int FFTListDialog::apply_clicked() {
 			gsl_fft_complex_workspace *workspace = gsl_fft_complex_workspace_alloc(nx);
 			gsl_fft_complex_wavetable *wavetable = gsl_fft_complex_wavetable_alloc(nx);
 
+#ifdef HAVE_GSL17
+			gsl_fft_direction sign = gsl_fft_forward;
+			switch(trans) {
+			case 0:	sign = gsl_fft_forward; break;
+			case 1:	sign = gsl_fft_backward; break;
+			}
+#else
 			gsl_fft_direction sign = forward;
 			switch(trans) {
 			case 0:	sign = forward; break;
 			case 1:	sign = backward; break;
 			}
+#endif
 
 		 	gsl_fft_complex_transform (data,1,nx,wavetable,workspace,sign);
 			gsl_fft_complex_wavetable_free(wavetable);
@@ -358,7 +383,7 @@ int FFTListDialog::apply_clicked() {
 			Graph3D *g = gl->getGraph3D(item);
 			xrange = g->Range(0);
 			yrange = g->Range(1);
-			label = g->Label();
+			label = g->getLabel()->simpleTitle();
 			nx = g->NX();
 			ny = g->NY();
 			tmp = (double *) malloc(nx*ny*sizeof(double));
@@ -372,7 +397,7 @@ int FFTListDialog::apply_clicked() {
 			GraphM *g = gl->getGraphM(item);
 			xrange = g->Range(0);
 			yrange = g->Range(1);
-			label = g->Label();
+			label = g->getLabel()->simpleTitle();
 			nx = g->NX();
 			ny = g->NY();
 			tmp = (double *) malloc(nx*ny*sizeof(double));
