@@ -11,12 +11,13 @@
 #include "FilterNETCDF.h"
 #include "FilterAUDIOFILE.h"
 #include "FilterCDF.h"
+#include "FilterMAGICK.h"
 
 class FileInfoDialog: public Dialog
 {
 	Q_OBJECT
 public:
-	FileInfoDialog(const char *name, QString filename);
+	FileInfoDialog(MainWin *mw, const char *name, QString filename);
 private slots:
 	void updateVarListBox();
 private:
@@ -25,6 +26,7 @@ private:
 	FilterNETCDF ncf;			// filter for netcdf files
 	FilterAUDIOFILE auf;		// filter for audiofile files
 	FilterCDF cdf;				// filter for cdf files
+	FilterMAGICK mf;			// filter for Magick images
 };
 
 #endif //FILEINFODIALOG_H
