@@ -10,7 +10,7 @@
 FilterAUDIOFILE::FilterAUDIOFILE(QString filename)
 	: filename(filename)
 {
-	if(filename.length()>0) {
+	if(!filename.isEmpty()) {
 		file = afOpenFile(filename, "r", NULL);
 	
 		if (file == AF_NULL_FILEHANDLE)		// not an audio file or not readable
