@@ -10,7 +10,7 @@ FilterCDF::FilterCDF(QString filename)
 {
 #ifdef HAVE_CDF
 	// TODO : write CDF file ?
-	if (filename.length()>0) {
+	if (!filename.isEmpty()) {
 		CDFstatus status = CDFopen(filename.latin1(), &id);
 		if (status != CDF_OK)		// not a cdf file or not readable
 			fileok=false;
