@@ -9,7 +9,7 @@ FilterMAGICK::FilterMAGICK(QString filename)
 	: filename(filename)
 {
 #ifdef HAVE_MAGICK
-	if(filename.length()>0) {
+	if(!filename.isEmpty()) {
 		try {
 			fileok=true;
 			image.read(filename.latin1());
@@ -17,7 +17,9 @@ FilterMAGICK::FilterMAGICK(QString filename)
 		catch (Exception &e) {
 			fileok=false;
 			kdDebug() << "Image read : Caught exception: "<<endl;
+#ifdef HAVE_EXCEPTIONS
 			kdDebug() << e.what() << endl;
+#endif
 		}
 		try {
 			kdDebug()<<" FORMAT : "<<image.format().c_str()<<endl;
@@ -27,7 +29,9 @@ FilterMAGICK::FilterMAGICK(QString filename)
 		}
 		catch (Exception &e) {
 			fileok=false;
+#ifdef HAVE_EXCEPTIONS
 			kdDebug() << "Image format : Caught exception: " << e.what() << endl;
+#endif
 		}
 	}
 #else
@@ -43,13 +47,22 @@ QPixmap FilterMAGICK::Pixmap() {
 	QString tmpname = tmpfile->name();
 
 	// save image as bmp (tmp file)
-	image.magick( "BMP" );
+	image.magick( "XPM" );
 	image.write(tmpname.latin1());
 	
 	// read tmp file into pixmap
 	QPixmap pm(width(),height());
-	pm.load(tmpname);
+	pm.fill(Qt::white);
+	bool res = pm.load(tmpname.latin1(),"XPM");
 	
+	// load() sometimes does not work. Why?
+	if(res==TRUE)
+		kdDebug()<<"ImageMagick Loading was successful"<<endl;
+	else {
+		kdDebug()<<"ImageMagick Loading error"<<endl;
+		return 0;
+	}
+
 	return pm;
 }
 #endif
