@@ -5,7 +5,7 @@
 #include <math.h>
 #include <iostream>
 
-#ifdef USE_SOLARIS
+#ifdef HAVE_SOLARIS
 #include <ieeefp.h>
 #endif
 
@@ -26,6 +26,11 @@
 #include <gsl/gsl_math.h>
 #endif
 
+#include "parser_struct.h"
+extern "C" con constants[];
+extern "C" init arith_fncts[];
+#include "parser_extern.h"
+
 using namespace std;
 
 /*! newtype -> new 3D Plot type*/
@@ -34,14 +39,9 @@ FunctionDialog::FunctionDialog(MainWin *mw, const char *name, ListDialog *l, int
 {
 	kdDebug()<<"FunctionDialog()"<<endl;
 	Plot *plot=0;
-	if(p!=0)
+	if(p != 0)
 	 	plot = p->getPlot(p->API());
-	// why's that ?
-/*	if (plot != 0)
-		type = plot->Type();
-	else
-*/
-		type = newtype;
+	type = newtype;
 
 	kdDebug()<<"FunctionDialog : plot type = "<<type<<endl;
 
@@ -81,7 +81,7 @@ FunctionDialog::FunctionDialog(MainWin *mw, const char *name, ListDialog *l, int
 
 		style = graph->getStyle();
 		symbol = graph->getSymbol();
-		kdDebug()<<"Struct : "<<s<<endl;
+		kdDebug()<<"Struct : "<<st<<endl;
 
 		if (st == GRAPH2D) {
 			Graph2D *g = gl->getGraph2D(item);
@@ -108,38 +108,78 @@ FunctionDialog::FunctionDialog(MainWin *mw, const char *name, ListDialog *l, int
 	QTabWidget *tw = new QTabWidget(vbox);
 	QVBox *tab1 = new QVBox(tw);
 
-	QString fun=mw->last_2dfunction;
+	// constants/function comboboxes
+	QHBox *hb = new QHBox(tab1);
+	QLabel *conlabel = new QLabel(i18n("Constants :"),hb);
+	concb = new KComboBox(hb);
+	int f=0;
+	QString tmp=0;
+	while(true){
+		tmp = constants[f++].name;
+		if(tmp.isEmpty())
+			break;
+		concb->insertItem(tmp);
+	};
+	QObject::connect(concb,SIGNAL(activated(int)),SLOT(insertConstant(int)));
+
+	hb = new QHBox(tab1);
+	QLabel *sellabel = new QLabel(i18n("Functions :"),hb);
+	selcb = new KComboBox(hb);
+	f=0;
+	while(true){
+		tmp = arith_fncts[f++].fname;
+		if(tmp.isEmpty())
+			break;
+		selcb->insertItem(tmp+"()");
+	}
+	QObject::connect(selcb,SIGNAL(activated(int)),SLOT(insertFunction(int)));
+	
+	KConfig *config = mw->Config();
+	config->setGroup( "Function" );
+
+	QString entry = QString("PlotType %1 ").arg(type);
+	
+	// hide them; shown later if necessary
+	concb->hide();
+	conlabel->hide();
+	selcb->hide();
+	sellabel->hide();
+
+	// function
+	QString fun("sin(x)");
 	if (type == P3D || type == PSURFACE || type == PQWT3D)
-		fun = mw->last_3dfunction;
+		fun = QString("sin(x+y)");
 	if (graph != 0) fun = graph->Name();
+	else fun = config->readEntry(entry+"Function",fun);
+
 	new QLabel(i18n("Function :"),tab1);
 	funle = new KLineEdit(fun,tab1);
+	if (graph != 0 && graph->Source() == SSPREADSHEET)
+		funle->setReadOnly(true);
 
-	QHBox *hb = new QHBox(tab1);
+	hb = new QHBox(tab1);
 	reread = new QCheckBox(i18n("Recreate Function"),hb);
 	reread->hide();
-	if (graph !=0) {	//change
-		if(graph->Source() == SFUNCTION) {
-			reread->show();
-			reread->setChecked(true);
-		}
-	} 
-	else				//new function
+	if (graph == 0 || (graph != 0 && graph->Source() == SFUNCTION)) {
+		conlabel->show();
+		concb->show();
+		sellabel->show();
+		selcb->show();
+		reread->show();
 		reread->setChecked(true);
+	} 
+	if (graph == 0) {		//new function
+		reread->hide();
+	}
 
-	QString label = fun;
-	if (graph != 0) label = graph->Label();
-	new QLabel(i18n("Label :"),tab1);
-	hb = new QHBox(tab1);
-	labelle = new KLineEdit(label,hb);
 	KPushButton *setLabel = new KPushButton(i18n("Update Label"),hb);
 	QObject::connect(setLabel,SIGNAL(clicked()),SLOT(updateLabel()));
-
-	new QLabel(i18n("Range :"),tab1);
+	
 	hb = new QHBox(tab1);
-	new QLabel(QString("x = "),hb);
+	new QLabel(i18n("Range : "),hb);
 
-	double x1 = mw->last_xmin, x2 = mw->last_xmax;
+	double x1 = config->readDoubleNumEntry(entry+"XMin",0);
+	double x2 = config->readDoubleNumEntry(entry+"XMax",1);
 	if (graph != 0) {
 		x1 = rx.rMin();
 		x2 = rx.rMax();
@@ -147,10 +187,12 @@ FunctionDialog::FunctionDialog(MainWin *mw, const char *name, ListDialog *l, int
 	xmin = new KLineEdit(QString::number(x1),hb);
 	new QLabel(QString(" .. "),hb);
 	xmax = new KLineEdit(QString::number(x2),hb);
+	ymin=ymax=0;
 	if (type == P3D || type == PSURFACE || type == PQWT3D) {
 		new QLabel(QString(" y = "),hb);
 
-		double y1 = mw->last_ymin, y2 = mw->last_ymax;
+		double y1 = config->readDoubleNumEntry(entry+"YMin",0);
+		double y2 = config->readDoubleNumEntry(entry+"YMax",1);
 		if (graph != 0) {
 			x1 = rx.rMin();
 			x2 = rx.rMax();
@@ -161,38 +203,48 @@ FunctionDialog::FunctionDialog(MainWin *mw, const char *name, ListDialog *l, int
 		new QLabel(QString(" .. "),hb);
 		ymax = new KLineEdit(QString::number(y2),hb);
 	}
-	new QLabel(i18n("Number of Points :"),tab1);
 	hb = new QHBox(tab1);
-	new QLabel(QString("NX = "),hb);
+	new QLabel(i18n("Number of Points :"),hb);
+	nx=0;		// needed for spreadsheet graph later
+	ny=0;
 	if(type == P2D || type == PPOLAR) {
-		if (graph == 0) nrx = mw->last_nrpointsx;
-		nx = new KLineEdit(QString::number(nrx),hb);
-		nx->setValidator(new QIntValidator(nx));
+		if (graph == 0) nrx = config->readNumEntry("NX",100);
+		nx = new KIntNumInput(nrx,hb);
+		nx->setMinValue(1);
 	}
 	else if (type == P3D || type == PSURFACE || type == PQWT3D){
 		if (graph == 0) {
-			nrx = mw->last_nrpointsx;
-			nry = mw->last_nrpointsy;
+			nrx = config->readNumEntry("NX",100);
+			nry = config->readNumEntry("NY",100);
 		}
-		nx = new KLineEdit(QString::number(nrx),hb);
-		nx->setValidator(new QIntValidator(nx));
+		nx = new KIntNumInput(nrx,hb);
+		nx->setMinValue(1);
 		new QLabel(QString("NY = "),hb);
-		ny = new KLineEdit(QString::number(nry),hb);
-		ny->setValidator(new QIntValidator(ny));
+		ny = new KIntNumInput(nry,hb);
+		ny->setMinValue(1);
+	}
+	
+	if (graph != 0 && graph->Source() == SSPREADSHEET) {
+		xmin->setEnabled(false);
+		xmax->setEnabled(false);
+		if(nx) nx->setEnabled(false);
+		if(ny) ny->setEnabled(false);
 	}
 
+	QVBox *tab2 = new QVBox(tw);
+	Label* label = new Label(config->readEntry(entry+"Function",fun));
+	if (graph != 0) label = graph->getLabel();
+	rtw = new RichTextWidget((QWidget *)tab2,label,0);
+	
 	tw->addTab(tab1,i18n("Parameter"));
+	tw->addTab(tab2,i18n("Label"));
 
-	kdDebug()<<"build style tab"<<endl;
 	QVBox *styletab, *annotatetab;
-	if(type == PQWT3D) {
-		// TODO
-	}
 	if (type == PSURFACE) {
 		styletab = surfaceStyle(tw,item==-1?true:false);
 		tw->addTab(styletab,i18n("Style"));
 	}
-	else {
+	else if (type != PQWT3D) {
 		styletab = simpleStyle(tw, style, symbol);
 		annotatetab = annotateValuesTab(tw,graph);
 		tw->addTab(styletab,i18n("Style"));
@@ -210,18 +262,67 @@ FunctionDialog::FunctionDialog(MainWin *mw, const char *name, ListDialog *l, int
 		wlist << list.at(i)->caption();
 	wlist<<i18n("new Worksheet")<<i18n("new Spreadsheet");
 	sheetcb->insertStringList(wlist);
-	sheetcb->setCurrentItem(0);
+	sheetcb->setCurrentItem(mw->activeSheetIndex());
 	
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
 	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	QObject::connect(save,SIGNAL(clicked()),SLOT(saveSettings()));
 
 	setMinimumWidth(vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
-	resize((int)(1.5*minimumSize().width()),minimumSize().height());
+	resize((int)(1.0*minimumSize().width()),minimumSize().height());
 	
 	kdDebug()<<"FunctionDialog() DONE"<<endl;
 }
 
+void FunctionDialog::saveSettings(bool pressed) {
+	KConfig *config = mw->Config();
+	config->setGroup( "Function" );
+
+	QString entry = QString("PlotType %1 ").arg(type);
+
+	config->writeEntry(entry+"Function",funle->text());
+	// not used config->writeEntry(entry+"Reread",reread->isChecked());
+	config->writeEntry(entry+"XMin",xmin->text().toDouble());
+	config->writeEntry(entry+"XMax",xmax->text().toDouble());
+	if(ymin != 0 && ymax != 0) {
+		config->writeEntry(entry+"YMin",ymin->text().toDouble());
+		config->writeEntry(entry+"YMax",ymax->text().toDouble());
+	}
+	config->writeEntry(entry+"NX",nx->value());
+	if(ny != 0)
+		config->writeEntry(entry+"NY",ny->value());
+
+	if(! pressed)
+		return;
+	
+	rtw->getLabel()->saveSettings(config,entry);
+
+	if(type != PQWT3D) {
+		config->writeEntry(entry+"Annotate Type",typecb->currentItem());
+		config->writeEntry(entry+"Annotate Position",positioncb->currentItem());
+		config->writeEntry(entry+"Annotate Distance",distance->value());
+	}
+}
+
+void FunctionDialog::insertConstant(int i) {
+	QString text = funle->text();
+	int pos = funle->cursorPosition();
+	QString c = constants[i].name;
+	text.insert(pos,c);
+	funle->setText(text);
+	funle->setCursorPosition(pos+c.length());
+}
+
+void FunctionDialog::insertFunction(int i) {
+	QString text = funle->text();
+	int pos = funle->cursorPosition();
+	QString c = arith_fncts[i].fname;
+	text.insert(pos,c+"()");
+	funle->setText(text);
+	funle->setCursorPosition(pos+c.length()+2);
+}
+
 // search for a usable plot; add worksheet if necessary
 void FunctionDialog::findPlot() {
 	kdDebug()<<"FunctionDialog::findPlot()"<<endl;
@@ -241,12 +342,17 @@ void FunctionDialog::findPlot() {
 	Plot *plot=0;
 	if(p)
 		plot = p->getPlot(p->API());
-
+		
 	if(plot && plot->Type() == PQWT3D || type == PQWT3D) {	// new worksheet if plot is qwt3d or type = qwt3d
-		p = mw->newWorksheet();
-		p->newPlot(type);
-		plot = p->getPlot(p->API());
-		sheetcb->setCurrentItem(count-2);		// set item to new worksheet
+		kdDebug()<<"	QWT Plot found! type = "<<type<<endl;
+		if(plot && plot->getGraphList()->Number() > 0 ) {
+			p = mw->newWorksheet();
+			p->newPlot(type);
+			plot = p->getPlot(p->API());
+			sheetcb->setCurrentItem(count-2);		// set item to new worksheet
+		}
+		else
+			p->newPlot(type);
 	}
 	else if(item < count-2 && plot && plot->Type() != type)		// new plot if choosen of other type.
 		p->newPlot(type);					// not if already new sheet selected
@@ -258,7 +364,8 @@ int FunctionDialog::apply_clicked() {
 	findPlot();
 	
 	// add function
-	QString label = labelle->text();
+	// TODO : use richtext label
+//	QString label = labelle->text();
 	int status=0;
 	if (reread->isChecked())
 		status = addFunction();
@@ -271,7 +378,7 @@ int FunctionDialog::apply_clicked() {
 					plot->enableDensity(dcb->isChecked());
 					plot->enableContour(ccb->isChecked());
 					plot->setNumber(numberle->text().toInt());
-					plot->setPalette(pcb->currentItem());
+					// OLD : plot->setPalette(pcb->currentItem());
 					plot->setContourColor(contourcolor->color());
 					plot->setColoredContour(coloredcb->isChecked());
 					plot->setMesh(meshcb->isChecked());
@@ -283,18 +390,19 @@ int FunctionDialog::apply_clicked() {
 		}
 		else {
 			Style *style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),
-				fcolor->color(),widthle->text().toInt(),
+				fcolor->color(),width->value(),
 				pencb->currentItem(),brushcb->currentItem());
-			style->setBoxWidth(boxwidthle->text().toInt());
+			style->setBoxWidth(boxwidth->value());
 			style->setAutoBoxWidth(autobox->isChecked());
-			Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->text().toInt(),
+			style->setPointsSorting(sortpointscb->isChecked());
+			Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->value(),
 					(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());
-			AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distancele->text().toInt());
+			AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distance->value());
 			graph->setStyle(style);
 			graph->setSymbol(symbol);
 			graph->setAnnotateValues(av);
 		}
-		graph->setLabel(label);
+		graph->setLabel(rtw->label());
 	}
 
 	if(l) l->updateList();
@@ -306,25 +414,23 @@ int FunctionDialog::apply_clicked() {
 int FunctionDialog::addFunction() {
 	kdDebug()<<"FunctionDialog::addFunction()"<<endl;
 	QString fun = funle->text().lower();
-	
-	// save "last" values
-	mw->last_nrpointsx = nx->text().toInt();
-	mw->last_xmin = xmin->text().toDouble();
-	mw->last_xmax = xmax->text().toDouble();
-	if (type == P3D || type == PSURFACE || type == PQWT3D) {
-		mw->last_3dfunction = fun;
-		mw->last_nrpointsy = ny->text().toInt();
-		mw->last_ymin = ymin->text().toDouble();
-		mw->last_ymax = ymax->text().toDouble();
-	}
-	else
-		mw->last_2dfunction = fun;
 
-	QString label = labelle->text();
-	int NX = (nx->text()).toInt();
+	fun.remove(QRegExp(".*="));		// remove any "xyz =" before expression
+
+	// save "last" values
+	saveSettings(false);
+
+	KConfig *config = mw->Config();
+	config->setGroup( "Function" );
+
+	QString entry = QString("PlotType %1 ").arg(type);
+
+	Label *label = rtw->getLabel();
+	QString title = label->Title();
+	int NX = nx->value();
 	int NY = 0;
 	if (type == P3D || type == PSURFACE || type == PQWT3D)
-		NY = (ny->text()).toInt();
+		NY = ny->value();
 
 	QProgressDialog progress( i18n("Creating function ..."), i18n("Cancel"), NX,this, "progress", true );
 	progress.setMinimumDuration(2000);
@@ -332,23 +438,23 @@ int FunctionDialog::addFunction() {
 		Point *ptr = new Point[NX];
 
 		double ymin=0, ymax=1;
-		double xmi = parse((char *) (xmin->text()).latin1());
-		double xma = parse((char *) (xmax->text()).latin1());
+		double xmi = parse((char *) xmin->text().latin1());
+		double xma = parse((char *) xmax->text().latin1());
+		init_table();
+
 		for(int i = 0;i < NX;i++) {
 			if(i%100 == 0) progress.setProgress( i );
     			qApp->processEvents();
 
 			double x = (xma-xmi)*i/(double)(NX-1)+xmi;
-			QString tmp(fun);
-			if (tmp.length()==1) tmp += " ";		// "x"
-
-			tmp = mw->parseExpression(tmp, x, 23);	// "x"
-			
-			double y = parse((char *) tmp.latin1());
+			char var[]="x";
+			assign_variable(var,x);
+			double y = parse((char *) fun.latin1());
 
 			if(parse_errors()>0) {
 				progress.cancel();
 				KMessageBox::error(mw, i18n("Parse Error!\n Please check the given function."));
+        			delete_table();
 				return 1;
 			}
 
@@ -360,9 +466,13 @@ int FunctionDialog::addFunction() {
 			y>ymax?ymax=y:0;
 
 			ptr[i].setPoint(x,y);
-			if ( progress.wasCancelled() )
-        			return 1;
+			if ( progress.wasCancelled() ) {
+        			delete_table();
+				return 1;
+			}
 		}
+		delete_table();
+		
 		if(p!=0 && graph != 0)
 			p->getPlot(p->API())->getGraphList()->delGraph(item);
 
@@ -380,21 +490,23 @@ int FunctionDialog::addFunction() {
 		range[0] = LRange(xmi,xma);
 		range[1] = LRange(ymin,ymax);
 		Style *style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),
-			fcolor->color(),widthle->text().toInt(),
+			fcolor->color(),width->value(),
 			pencb->currentItem(),brushcb->currentItem());
-		style->setBoxWidth(boxwidthle->text().toInt());
+		style->setBoxWidth(boxwidth->value());
 		style->setAutoBoxWidth(autobox->isChecked());
-		Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->text().toInt(),
+		style->setPointsSorting(sortpointscb->isChecked());
+		Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->value(),
 			(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());
 
 		kdDebug()<<"	range[0]="<<range[0].rMin()<<","<<range[0].rMax()<<endl;
 		kdDebug()<<"	range[1]="<<range[1].rMin()<<","<<range[1].rMax()<<endl;
 
-		Graph2D *g = new Graph2D(fun,label,range,SFUNCTION,type,style,symbol,ptr,NX);
-		
-		AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distancele->text().toInt());
+		Graph2D *g = new Graph2D(fun,title,range,SFUNCTION,type,style,symbol,ptr,NX);
+		g->setLabel(label);
+
+		AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distance->value());
 		g->setAnnotateValues(av);
-		mw->addGraph2D(g,sheetcb->currentItem());
+		mw->addGraph2D(g,sheetcb->currentItem(),type);
 	}
 	else if (type == PSURFACE || type == PQWT3D) {
 		kdDebug()<<"	\"surface\" or \" qwt 3d \" selected"<<endl;
@@ -407,23 +519,24 @@ int FunctionDialog::addFunction() {
 		xma = parse((char *) (xmax->text()).latin1());
 		ymi = parse((char *) (ymin->text()).latin1());
 		yma = parse((char *) (ymax->text()).latin1());
+		init_table();
 			
 		for (int i=0;i<NY;i++) {
 			if(i%10==0)progress.setProgress( i );
     			qApp->processEvents();
-			QString tmp(fun);
-			if (tmp.length()==1) tmp += " ";
-			
-			tmp = mw->parseExpression(tmp,(yma-ymi)*i/(double)(NY-1)+ymi,24);
-			
+			char var[]="y";
+			assign_variable(var,(yma-ymi)*i/(double)(NY-1)+ymi);
+
 			for (int j=0;j<NX;j++) {
-				QString tmp2 = mw->parseExpression(tmp,(xma-xmi)*j/(double)(NX-1)+xmi,23);
+				var[0]='x';
+				assign_variable(var,(xma-xmi)*j/(double)(NX-1)+xmi);
 				
-				double z = parse((char *) tmp2.latin1());
+				double z = parse((char *) fun.latin1());
 			
 				if(parse_errors()>0) {
 					progress.cancel();
 					KMessageBox::error(mw, i18n("Parse Error!\n Please check the given function."));
+					delete_table();
 					return 1;
 				}
 
@@ -441,9 +554,12 @@ int FunctionDialog::addFunction() {
 				
 				a[j+NX*i] = z;
 			}
-			if ( progress.wasCancelled() )
-        			return 1;
+			if ( progress.wasCancelled() ) {
+        			delete_table();
+				return 1;
+			}
 		}
+		delete_table();
 
 		if(p!=0 && type == PSURFACE) {
 			Plot2DSurface *plot = (Plot2DSurface *)p->getPlot(p->API());
@@ -456,7 +572,7 @@ int FunctionDialog::addFunction() {
 				plot->enableDensity(dcb->isChecked());
 				plot->enableContour(ccb->isChecked());
 				plot->setNumber(numberle->text().toInt());
-				plot->setPalette(pcb->currentItem());
+				// OLD : plot->setPalette(pcb->currentItem());
 				plot->setContourColor(contourcolor->color());
 				plot->setColoredContour(coloredcb->isChecked());
 				plot->setMesh(meshcb->isChecked());
@@ -496,7 +612,8 @@ int FunctionDialog::addFunction() {
 
 		Style *style = new Style(0);
 		Symbol *symbol = new Symbol(SNONE);
-		GraphM *g = new GraphM(fun,label,range,SFUNCTION,type,style,symbol,a,NX,NY);
+		GraphM *g = new GraphM(fun,title,range,SFUNCTION,type,style,symbol,a,NX,NY);
+		g->setLabel(label);
 		mw->addGraphM(g,sheetcb->currentItem(),type);
 	}
 	else if (type == P3D) {
@@ -504,28 +621,30 @@ int FunctionDialog::addFunction() {
 
 		Point3D *ptr = new Point3D[NX*NY];
 
-		double xmi=(xmin->text()).toDouble(), xma=(xmax->text()).toDouble();
+		double xmi = xmin->text().toDouble(), xma = xmax->text().toDouble();
 		double ymi=(ymin->text()).toDouble(), yma=(ymax->text()).toDouble();
 		double zmin=0, zmax=1;
+		init_table();
+
 		for(int i = 0;i < NY;i++) {
 			if(i%100==0)progress.setProgress( i );
     			qApp->processEvents();
 
-			QString tmp(fun);
-			if (tmp.length()==1) tmp += " ";
-			
 			double y = (yma-ymi)*i/(double)(NY-1)+ymi;
-			tmp = mw->parseExpression(tmp,y,24);
+			char var[]="y";
+			assign_variable(var,y);
 			
 			for (int j = 0;j < NX;j++) {
 				double x = (xma-xmi)*j/(double)(NX-1)+xmi;
-				QString tmp2 = mw->parseExpression(tmp,x,23);
+				var[0]='x';
+				assign_variable(var,x);
 				
-				double z = parse((char *) tmp2.latin1());
+				double z = parse((char *) fun.latin1());
 			
 				if(parse_errors()>0) {
 					progress.cancel();
 					KMessageBox::error(mw, i18n("Parse Error!\n Please check the given function."));
+					delete_table();
 					return 1;
 				}
 
@@ -539,9 +658,12 @@ int FunctionDialog::addFunction() {
 
 				ptr[i*NX+j].setPoint(x,y,z);
 			}
-			if ( progress.wasCancelled() )
+			if ( progress.wasCancelled() ) {
+				delete_table();
         			return 1;
+			}
 		}
+		delete_table();
 
 		if(graph != 0)
 			p->getPlot(p->API())->getGraphList()->delGraph(item);
@@ -558,19 +680,25 @@ int FunctionDialog::addFunction() {
 
 		kdDebug()<<"Z RANGE = "<<zmin<<' '<<zmax<<endl;
 
-		Style *style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),widthle->text().toInt(),
+		Style *style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),width->value(),
 			pencb->currentItem(),brushcb->currentItem());
-		style->setBoxWidth(boxwidthle->text().toInt());
+		style->setBoxWidth(boxwidth->value());
 		style->setAutoBoxWidth(autobox->isChecked());
-		Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->text().toInt(),
+		style->setPointsSorting(sortpointscb->isChecked());
+		Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->value(),
 				(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());
 
-		Graph3D *g = new Graph3D(fun,label,range,SFUNCTION,P3D,style,symbol,ptr,NX,NY);
-		AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distancele->text().toInt());
+		Graph3D *g = new Graph3D(fun,title,range,SFUNCTION,P3D,style,symbol,ptr,NX,NY);
+		g->setLabel(label);
+		AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distance->value());
 		g->setAnnotateValues(av);
 		mw->addGraph3D(g,sheetcb->currentItem());
 	}
 
+	// create new label
+	Label* nlabel = new Label(*label);
+	rtw->setLabel(nlabel);
+
 	kdDebug()<<"FunctionDialog::apply_clicked() : DONE"<<endl;
 	
 	return 0;
