@@ -15,15 +15,19 @@ class Graph2D: public Graph
 public:
 	Graph2D(QString n="", QString l="",LRange r[2]=0, LSource src=SFUNCTION, PType t=P2D, Style *st=0, 
 		Symbol *sy=0, Point *p=0, int nr=0, bool b=true);
+	Graph2D *Clone();		// clone this graph
 	LRange Range(int i) { return range[i]; }
-	void setRange(LRange *r) { range[0]=r[0];range[1]=r[1]; }
+	void setRange(LRange r[2]) { range[0]=r[0]; range[1]=r[1]; }
 	Point *Data() { return ptr; }
+	void setData(Point *data) { ptr = data; }
 	QStringList Info();	
 	void save(QTextStream *t, QProgressDialog *progress);
 	void open(QTextStream *t, int version, QProgressDialog *progress);
+	void saveXML(QDomDocument doc, QDomElement graphtag);
+	void openXML(QDomNode node);
 private:
 	Point *ptr;
-	LRange *range;
+	LRange range[2];
 };
 
 #endif // GRAPH2D_H
