@@ -10,7 +10,6 @@ Graph4D::Graph4D(QString n, QString l, LRange r[4], LSource src, PType t, Style
 		Symbol *sy, Point4D *p, int nr,bool ty, bool s)
 	: Graph(n,l,src,t,st,sy,nr,s)
 {
-	range = new LRange[4];
 	if(r) {
 		for(int i=0;i<4;i++) {
 			range[i]=r[i];
@@ -24,6 +23,54 @@ Graph4D::Graph4D(QString n, QString l, LRange r[4], LSource src, PType t, Style
 	gtype = ty;
 }
 
+Graph4D *Graph4D::Clone() {
+	Graph4D *newg = new Graph4D(*this);
+	Label *l = new Label();
+	*l = *(label);
+	newg->setLabel(l);	// set label
+	Point4D *data = new Point4D[number];
+	for(int i=0;i<number;i++)
+		data[i] = ptr[i];
+	newg->setData(data);	// set data
+
+	LRange nrange[4];
+	nrange[0] = range[0];
+	nrange[1] = range[1];
+	nrange[2] = range[2];
+	nrange[3] = range[3];
+	newg->setRange(nrange);
+
+	return newg;
+}
+
+void Graph4D::saveXML(QDomDocument doc, QDomElement graphtag) {
+	QDomElement tag = doc.createElement( "Range" );
+	tag.setAttribute("xmin",QString::number(range[0].rMin()));
+	tag.setAttribute("xmax",QString::number(range[0].rMax()));
+	tag.setAttribute("ymin",QString::number(range[1].rMin()));
+	tag.setAttribute("ymax",QString::number(range[1].rMax()));
+	tag.setAttribute("zmin",QString::number(range[2].rMin()));
+	tag.setAttribute("zmax",QString::number(range[2].rMax()));
+	tag.setAttribute("tmin",QString::number(range[3].rMin()));
+	tag.setAttribute("tmax",QString::number(range[3].rMax()));
+    	graphtag.appendChild( tag );
+
+	tag = doc.createElement( "GraphType" );
+   	graphtag.appendChild( tag );
+  	QDomText t = doc.createTextNode( QString::number(gtype) );
+    	tag.appendChild( t );
+	
+	for (int i=0;i< number;i++) {
+		tag = doc.createElement( "Data" );
+		tag.setAttribute("x",QString::number(ptr[i].X()));
+		tag.setAttribute("y",QString::number(ptr[i].Y()));
+		tag.setAttribute("z",QString::number(ptr[i].Z()));
+		tag.setAttribute("t",QString::number(ptr[i].T()));
+		tag.setAttribute("masked",QString::number(ptr[i].Masked()));
+    		graphtag.appendChild( tag );
+	}
+}
+
 void Graph4D::save(QTextStream *t, QProgressDialog *progress) {
 	saveGraph(t);
 	*t<<number<<endl;
@@ -49,8 +96,11 @@ void Graph4D::open(QTextStream *t, int version, QProgressDialog *progress) {
 	
 	if (version > 2)
 		*t>>number;
-	else if (version > 1)
-		*t>>name>>label>>number;
+	else if (version > 1) {
+		QString title;
+		*t>>name>>title>>number;
+		label->setTitle(title);
+	}
 	else
 		*t>>name>>number;
 
@@ -91,6 +141,30 @@ void Graph4D::open(QTextStream *t, int version, QProgressDialog *progress) {
 	gtype = (bool)tt;
 }
 
+void Graph4D::openXML(QDomNode node) {
+	int i=0;
+	while(!node.isNull()) {
+		QDomElement e = node.toElement();
+		kdDebug()<<"GRAPH TAG = "<<e.tagName()<<endl;
+		kdDebug()<<"GRAPH TEXT = "<<e.text()<<endl;
+
+		openGraphXML(e);
+
+		if(e.tagName() == "Number")
+			ptr = new Point4D[e.text().toInt()];
+		else if(e.tagName() == "GraphType")
+			gtype = e.text().toInt();
+		else if(e.tagName() == "Data") {
+			ptr[i].setPoint(e.attribute("x").toDouble(),e.attribute("y").toDouble(),
+				e.attribute("z").toDouble(),e.attribute("t").toDouble());
+			ptr[i].setMasked((bool) e.attribute("masked").toInt());
+			i++;
+		}
+
+		node = node.nextSibling();
+	}
+}
+
 QStringList Graph4D::Info(){
 	QStringList s;
 	QString t;
@@ -102,7 +176,7 @@ QStringList Graph4D::Info(){
 		sh=i18n("YES");
 	
 	// TODO : bool gtype ???
-	s << name << t << sh;
+	s << label->simpleTitle() << t << sh;
 	s << QString::number(number) << QString::number(1);
 	s << QString::number(range[0].rMin()) + " .. " + QString::number(range[0].rMax());
 	s << QString::number(range[1].rMin())+ " .. " + QString::number(range[1].rMax());
