@@ -14,11 +14,32 @@ GraphList::GraphList() {
 }
 
 void GraphList::clear() {
-	nr2D = nr3D = nrM = nrGRASS = nr4D = nrIMAGE = 0;
+	nr2D = nr3D = nrM = nrGRASS = nr4D = nrIMAGE = nrL = 0;
 	for (int i=0;i<7*MAX_NR;i++)
 		id[i]=-1;
 }
 
+void GraphList::saveXML(QDomDocument doc, QDomElement root) {
+	for (unsigned int i=0;i < Number();i++) {
+		QDomElement tag = getGraph(i)->saveGraphXML(doc,getStruct(i));
+   		root.appendChild( tag );
+	}
+}
+
+/*void GraphList::openXML(QDomNode node, int type) {
+	while(!node.isNull()) {
+		QDomElement e = node.toElement();
+		kdDebug()<<"GRAPH TAG = "<<e.tagName()<<endl;
+		kdDebug()<<"GRAPH TEXT = "<<e.text()<<endl;
+
+		// TODO : open graphs
+		if(e.tagName() == "Graph")
+			kdDebug()<<" GOT A GRAPH"<<endl;
+
+		node = node.nextSibling();
+	}
+}*/
+
 int GraphList::addGraph2D(Graph2D *g) {
 //	kdDebug()<<"GraphList::addGraphX  Name = "<<g->Name()<<endl;
 //	kdDebug()<<"GraphList::addGraphX : isNotFull() = "<<isNotFull()<<endl;
@@ -26,10 +47,10 @@ int GraphList::addGraph2D(Graph2D *g) {
 //	kdDebug()<<nr2D<<' '<<nr3D<<' '<<nrM<<' '<<nrGRASS<<' '<<nr4D<<' '<<nrIMAGE<<endl;
 
 	if(isNotFull() && nr2D<MAX_NR) {
-		id[nr2D]=nr2D+nr3D+nrM+nr4D+nrIMAGE;
+		id[nr2D] = nr2D+nr3D+nrM+nr4D+nrIMAGE+nrL;
 		list2D[nr2D++] = *g;
 
-//		kdDebug()<<"GraphList::addGraph2D : nr2D = "<<nr2D<<endl;
+		//kdDebug()<<"GraphList::addGraph2D : nr2D = "<<nr2D<<endl;
 		return 1;
 	}
 	return 0;
@@ -37,7 +58,7 @@ int GraphList::addGraph2D(Graph2D *g) {
 
 int GraphList::addGraph3D(Graph3D *g) {
 	if(isNotFull() && nr3D<MAX_NR) {
-		id[MAX_NR+nr3D]=nr2D+nr3D+nrM+nr4D+nrIMAGE;
+		id[MAX_NR+nr3D]=nr2D+nr3D+nrM+nr4D+nrIMAGE+nrL;
 		list3D[nr3D++] = *g;
 
 		kdDebug()<<"GraphList::addGraph3D : id["<<MAX_NR+nr3D-1<<"] = "<<endl;
@@ -52,7 +73,7 @@ int GraphList::addGraph3D(Graph3D *g) {
 
 int GraphList::addGraphM(GraphM *g) {
 	if(isNotFull() && nrM<MAX_NR) {
-		id[2*MAX_NR+nrM]=nr2D+nr3D+nrM+nr4D+nrIMAGE;
+		id[2*MAX_NR+nrM]=nr2D+nr3D+nrM+nr4D+nrIMAGE+nrL;
 		listM[nrM++] = *g;
 
 		kdDebug()<<"GraphList::addGraphM : id["<<2*MAX_NR+nrM-1<<"] = "<<id[2*MAX_NR+nrM-1]<<endl;
@@ -66,7 +87,7 @@ int GraphList::addGraphM(GraphM *g) {
 
 int GraphList::addGraph4D(Graph4D *g) {
 	if(isNotFull() && nr4D<MAX_NR) {
-		id[5*MAX_NR+nr4D]=nr2D+nr3D+nrM+nr4D+nrIMAGE;
+		id[5*MAX_NR+nr4D]=nr2D+nr3D+nrM+nr4D+nrIMAGE+nrL;
 		list4D[nr4D++] = *g;
 
 		kdDebug()<<"GraphList::addGraph4D : id["<<5*MAX_NR+nr4D-1<<"] = "<<endl;
@@ -81,10 +102,10 @@ int GraphList::addGraph4D(Graph4D *g) {
 
 int GraphList::addGraphIMAGE(GraphIMAGE *g) {
 	if(isNotFull() && nrIMAGE<MAX_NR) {
-		id[6*MAX_NR+nrIMAGE]=nr2D+nr3D+nrM+nr4D+nrIMAGE;
+		id[6*MAX_NR+nrIMAGE]=nr2D+nr3D+nrM+nr4D+nrIMAGE+nrL;
 		listIMAGE[nrIMAGE++] = *g;
 
-		kdDebug()<<"GraphList::addGraph3D : id["<<6*MAX_NR+nrIMAGE-1<<"] = "<<endl;
+		kdDebug()<<"GraphList::addGraphIMAGE : id["<<6*MAX_NR+nrIMAGE-1<<"] = "<<endl;
 		kdDebug()<<id[6*MAX_NR+nrIMAGE-1]<<endl;
 		kdDebug()<<"Type = "<<g->Type()<<endl;
 		kdDebug()<<"Type = "<<listIMAGE[nrIMAGE-1].Type()<<endl;
@@ -94,12 +115,27 @@ int GraphList::addGraphIMAGE(GraphIMAGE *g) {
 	return 0;
 }
 
+int GraphList::addGraphL(GraphL *g) {
+	if(isNotFull() && nrL < MAX_NR) {
+		id[7*MAX_NR+nr4D]=nr2D+nr3D+nrM+nr4D+nrIMAGE+nrL;
+		listL[nrL++] = *g;
+
+		kdDebug()<<"GraphList::addGraphL : id["<<7*MAX_NR+nrL-1<<"] = "<<endl;
+		kdDebug()<<id[7*MAX_NR+nrL-1]<<endl;
+		kdDebug()<<"Type = "<<g->Type()<<endl;
+		kdDebug()<<"Type = "<<listL[nrL-1].Type()<<endl;
+
+		return 1;
+	}
+	return 0;
+}
+
 int GraphList::delGraph(unsigned int index) {
 	unsigned int i=index;
 
 	//kdDebug()<<"GraphList::delGraph : index = "<<index<<endl;
 
-	if(index <= nr2D+nr3D+nrM+nr4D+nrIMAGE) {
+	if(index <= nr2D+nr3D+nrM+nr4D+nrIMAGE+nrL) {
 		GRAPHType s = getStruct(index);
 		switch (s) {
 		case GRAPH2D:
@@ -137,6 +173,13 @@ int GraphList::delGraph(unsigned int index) {
 				i++;
 			}
 			break;
+		case GRAPHL:
+			nrL--;
+			while (i<nrL) {
+				listL[i] = listL[i+1];
+				i++;
+			}
+			break;
 		default:
 			break;
 		}	
@@ -175,6 +218,9 @@ GRAPHType GraphList::getStruct(int index) {
 		else if (id[6*MAX_NR+i] == index) {
 			return GRAPHIMAGE;
 		}
+		else if (id[7*MAX_NR+i] == index) {
+			return GRAPHL;
+		}
 	}
 	return GRAPH2D;	//default return
 }
@@ -182,7 +228,8 @@ GRAPHType GraphList::getStruct(int index) {
 int GraphList::Index(int index) {
 	for(int i=0;i<MAX_NR;i++) {
 		if (id[i] == index || id[MAX_NR+i] == index || id[2*MAX_NR+i] == index || id[3*MAX_NR+i] == index ||
-			id[4*MAX_NR+i] == index || id[5*MAX_NR+i] == index || id[6*MAX_NR+i] == index) {
+			id[4*MAX_NR+i] == index || id[5*MAX_NR+i] == index || id[6*MAX_NR+i] == index ||
+			id[7*MAX_NR+i] == index	) {
 			return i;
 		}
 	}
@@ -190,10 +237,10 @@ int GraphList::Index(int index) {
 }
 
 Graph *GraphList::getGraph(unsigned int i) {
-	//kdDebug()<<"GraphList::getGraph(i) i="<<i<<endl;
-	if(i <= nr2D+nr3D+nrM+nr4D+nrIMAGE) {
+	kdDebug()<<"GraphList::getGraph(i) i="<<i<<endl;
+	if(i <= nr2D+nr3D+nrM+nr4D+nrIMAGE+nrL) {
 		GRAPHType s = getStruct(i);
-		//kdDebug()<<"Graph Struct = "<<s<<endl;
+		kdDebug()<<"Graph Struct = "<<s<<endl;
 		//kdDebug()<<"Index = "<<Index(i)<<endl;
 		switch (s) {
 		case GRAPH2D: return (Graph *) &list2D[Index(i)]; break;
@@ -201,6 +248,7 @@ Graph *GraphList::getGraph(unsigned int i) {
 		case GRAPHM: return (Graph *) &listM[Index(i)]; break;
 		case GRAPH4D: return (Graph *) &list4D[Index(i)]; break;
 		case GRAPHIMAGE: return (Graph *) &listIMAGE[Index(i)]; break;
+		case GRAPHL: return (Graph *) &listL[Index(i)]; break;
 		default: break;
 		}
 	}
@@ -237,3 +285,9 @@ GraphIMAGE *GraphList::getGraphIMAGE(int i) {
 	return 0;
 }	
 
+GraphL *GraphList::getGraphL(int i) {
+	if (i >= Index(i))
+		return &listL[Index(i)];
+	return 0;
+}	
+
