@@ -20,6 +20,9 @@ GraphListDialog::GraphListDialog(MainWin *mw,const char *name)
 	QObject::connect(del,SIGNAL(clicked()),SLOT(deleteGraph()));
 	KPushButton *ch = new KPushButton(i18n("Change Graph"),hb);
 	QObject::connect(ch,SIGNAL(clicked()),SLOT(changeGraph()));	
+	hb = new QHBox(tabmani);
+	KPushButton *addGraph = new KPushButton(i18n("Add Graph"),hb);
+	QObject::connect(addGraph,SIGNAL(clicked()),SLOT(addGraph()));
 	KPushButton *clone = new KPushButton(i18n("Clone Graph"),hb);
 	QObject::connect(clone,SIGNAL(clicked()),SLOT(Clone()));
 	
@@ -74,9 +77,13 @@ GraphListDialog::GraphListDialog(MainWin *mw,const char *name)
 	tw->addTab(tabstyle,i18n("Set Style"));
 	tw->addTab(tabmask,i18n("Masking"));
 	
+	sheetlabel->hide();
+	sheetcb->hide();
+	
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(accept()));
 	apply->hide();
 	cancel->hide();
+	save->hide();
 	
 	setMinimumWidth(vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
