@@ -12,15 +12,6 @@ GraphM::GraphM(QString n, QString l, LRange r[3], LSource src, PType t, Style *s
 		Symbol *sy, double *a,int dimx, int dimy, bool s)
 	: Graph(n,l,src,t,st,sy,dimx*dimy,s)
 {
-	range = new LRange[3];
-
-	if (r) {
-		kdDebug()<<"Range : "<<r[0].rMin()<<' '<<r[0].rMax()<<endl;
-		kdDebug()<<"Range : "<<r[1].rMin()<<' '<<r[1].rMax()<<endl;
-		kdDebug()<<"Range : "<<r[2].rMin()<<' '<<r[2].rMax()<<endl;
-	}
-	//kdDebug()<<"NX = "<<dimx<<" / NY = "<<dimy<<endl;
-
 	if(r) {
 		range[0].setMin(r[0].rMin());
 		range[0].setMax(r[0].rMax());
@@ -46,6 +37,51 @@ GraphM::GraphM(QString n, QString l, LRange r[3], LSource src, PType t, Style *s
 	}*/
 }
 
+GraphM *GraphM::Clone() {
+	GraphM *newg = new GraphM(*this);
+	Label *l = new Label();
+	*l = *(label);
+	newg->setLabel(l);	// set label
+	double *data = new double[number];
+	for(int i=0;i<number;i++)
+		data[i] = array[i];
+	newg->setData(data);	// set data
+
+	LRange nrange[3];
+	nrange[0] = range[0];
+	nrange[1] = range[1];
+	nrange[2] = range[2];
+	newg->setRange(nrange);
+
+	return newg;
+}
+
+void GraphM::saveXML(QDomDocument doc, QDomElement graphtag) {
+	QDomElement tag = doc.createElement( "Range" );
+	tag.setAttribute("xmin",QString::number(range[0].rMin()));
+	tag.setAttribute("xmax",QString::number(range[0].rMax()));
+	tag.setAttribute("ymin",QString::number(range[1].rMin()));
+	tag.setAttribute("ymax",QString::number(range[1].rMax()));
+	tag.setAttribute("zmin",QString::number(range[2].rMin()));
+	tag.setAttribute("zmax",QString::number(range[2].rMax()));
+    	graphtag.appendChild( tag );
+
+	tag = doc.createElement( "Dimension" );
+	tag.setAttribute("x",QString::number(nx));
+	tag.setAttribute("y",QString::number(ny));
+    	graphtag.appendChild( tag );
+	
+	for (int i=0;i< nx;i++) {
+		for (int j=0;j< ny;j++) {
+			tag = doc.createElement( "Data" );
+			tag.setAttribute("x",QString::number(i));
+			tag.setAttribute("y",QString::number(j));
+			tag.setAttribute("v",QString::number(array[j+i*ny]));
+    			graphtag.appendChild( tag );
+		}
+	}
+}
+
 void GraphM::save(QTextStream *t, QProgressDialog *progress) {
 	saveGraph(t);
 	*t<<nx<<' '<<ny<<endl;
@@ -116,6 +152,35 @@ void GraphM::open(QTextStream *t, int version, QProgressDialog *progress) {
 	progress->cancel();
 }
 
+void GraphM::openXML(QDomNode node) {
+	while(!node.isNull()) {
+		QDomElement e = node.toElement();
+//		kdDebug()<<"GRAPH TAG = "<<e.tagName()<<endl;
+//		kdDebug()<<"GRAPH TEXT = "<<e.text()<<endl;
+
+		openGraphXML(e);
+
+		if(e.tagName() == "Dimension") {
+			nx = e.attribute("x").toInt();
+			ny = e.attribute("y").toInt();
+			array = new double[nx*ny];
+			kdDebug()<<"NX/NY "<<nx<<' '<<ny<<endl;
+		}
+		else if(e.tagName() == "Range") {
+			range[0].setRange(e.attribute("xmin").toDouble(),e.attribute("xmax").toDouble());
+			range[1].setRange(e.attribute("ymin").toDouble(),e.attribute("ymax").toDouble());
+			range[2].setRange(e.attribute("zmin").toDouble(),e.attribute("zmax").toDouble());
+		}
+		else if(e.tagName() == "Data") {
+			int i= e.attribute("x").toInt(), j = e.attribute("y").toInt();
+			// kdDebug()<<"i/j "<<i<<' '<<j<<endl;
+			array[j+i*ny] = e.attribute("v").toDouble();
+		}
+
+		node = node.nextSibling();
+	}
+}
+
 QStringList GraphM::Info(){
 	kdDebug()<<"GraphM:Info()"<<endl;
 
@@ -134,7 +199,7 @@ QStringList GraphM::Info(){
 	if (shown)
 		sh=i18n("YES");
 
-	s << name << t << sh;
+	s << label->simpleTitle() << t << sh;
 	s << QString::number(nx) << QString::number(ny);
 	s << QString::number(range[0].rMin())+ " .. " + QString::number(range[0].rMax());
 	s << QString::number(range[1].rMin())+ " .. " + QString::number(range[1].rMax());
