@@ -13,7 +13,9 @@ class GraphM: public Graph
 public:
 	GraphM(QString n="", QString l="", LRange r[3]=0, LSource src=SFUNCTION, PType t=PSURFACE, Style *st=0, 
 		Symbol *sy=0, double *a=0, int dimx=0, int dimy=0, bool s=true);
+	GraphM *Clone();		// clone this graph
 	double *Data() { return array; }
+	void setData(double *data) { array = data; }
 	QPixmap Pixmap();
 	void setPixmap(QPixmap pm);
 	int width() { return (int)range[0].rMax(); }
@@ -21,7 +23,7 @@ public:
 	void setWidth(int w) { range[0] = LRange(0,w); }
 	void setHeight(int h) { range[1] = LRange(0,h); }
 	LRange Range(int i) { return range[i]; }
-	void setRange(LRange *r) { range[0]=r[0];range[1]=r[1];range[2]=r[2]; }
+	void setRange(LRange r[3]) { range[0]=r[0];range[1]=r[1];range[2]=r[2]; }
 	void setZRange(LRange *r) { range[2]=*r; }	// only set z range (EditDialog)
 	int NX() { return nx; }
 	int NY() { return ny; }
@@ -29,10 +31,12 @@ public:
 	QStringList Info();
 	void save(QTextStream *t, QProgressDialog *progress);
 	void open(QTextStream *t, int version, QProgressDialog *progress);
+	void saveXML(QDomDocument doc, QDomElement graphtag);
+	void openXML(QDomNode node);
 private:
+	LRange range[3];
 	int nx, ny;		//dimension
 	double *array;
-	LRange *range;
 };
 
 #endif // GRAPHM_H
