@@ -26,6 +26,8 @@ ImageMagickDialog::ImageMagickDialog(MainWin *mw, QString fn, int f, int sx, int
 {
 	setCaption(i18n("Export via ImageMagick"));
 	kdDebug()<<"ImageMagick dialog"<<endl;
+	KConfig *config = mw->Config();
+	config->setGroup( "ImageMagick" );
 
 	QHBox *hb = new QHBox(vbox);
 	new QLabel(i18n("Export to : "),hb);
@@ -47,10 +49,14 @@ ImageMagickDialog::ImageMagickDialog(MainWin *mw, QString fn, int f, int sx, int
 			entry++;
 		}
 		format->insertStringList(formatlist);
+		if(f == -1)
+			f = config->readNumEntry("Format",0);
 		format->setCurrentItem(f);
 	}
 	catch (Exception &e) {
+#ifdef HAVE_EXCEPTIONS
 		kdDebug()<<"Image coderLIst : Caught Exception "<< e.what() << endl;
+#endif
 		return;
 	}
 #endif
@@ -62,9 +68,13 @@ ImageMagickDialog::ImageMagickDialog(MainWin *mw, QString fn, int f, int sx, int
 
 	hb = new QHBox(vbox);
         new QLabel(i18n("Size : "),hb);
+	if(sx==0)
+		sx=config->readNumEntry("XSize",600);
         xle = new KLineEdit(QString::number(sx),hb);
 	xle->setValidator(new QIntValidator(xle));
         new QLabel(QString(" x "),hb);
+	if(sy==0)
+		sx=config->readNumEntry("YSize",400);
         yle = new KLineEdit(QString::number(sy),hb);
 	yle->setValidator(new QIntValidator(yle));
         new QLabel(i18n(" Rotation : "),hb);
@@ -73,12 +83,23 @@ ImageMagickDialog::ImageMagickDialog(MainWin *mw, QString fn, int f, int sx, int
 
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(Apply()));
 	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	QObject::connect(save,SIGNAL(clicked()),SLOT(saveSettings()));
 
 	setMinimumWidth(vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
 	resize(minimumSize());
 }
 
+void ImageMagickDialog::saveSettings() {
+	KConfig *config = mw->Config();
+	config->setGroup( "ImageMagick" );
+
+	config->writeEntry("Format",format->currentItem());
+	config->writeEntry("XSize",xle->text());
+	config->writeEntry("YSize",yle->text());
+	config->writeEntry("Rotation",rotle->text());	// not used
+}
+
 //! slot for "format" combobox
 void ImageMagickDialog::updateFilename(int index) {
 	QString filename =  filele->text();
