@@ -3,6 +3,7 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include "InterpolationListDialog.h"
+#include "defs.h"
 
 #ifdef HAVE_GSL
 #include <gsl/gsl_spline.h>
@@ -12,6 +13,8 @@ InterpolationListDialog::InterpolationListDialog(MainWin *mw, const char *name)
 	: ListDialog(mw, name)
 {
 	setCaption(i18n("Interpolation Dialog"));
+	KConfig *config = mw->Config();
+	config->setGroup( "Interpolation" );
 
 	QTabWidget *tw = new QTabWidget(vbox);
 	QVBox *tab1 = new QVBox(tw);
@@ -24,21 +27,22 @@ InterpolationListDialog::InterpolationListDialog(MainWin *mw, const char *name)
 	typelist<<i18n("linear")<<i18n("polynomial")<<i18n("cspline")<<i18n("cspline (periodic)");
 	typelist<<i18n("akima")<<i18n("akima (periodic)");
 	typecb->insertStringList(typelist);
+	typecb->setCurrentItem(config->readNumEntry("Type",0));
 
 	hb = new QHBox(tab1);
 	new QLabel(i18n(" From : "),hb);
-	ale = new KLineEdit(QString("0"),hb);
+	ale = new KLineEdit(config->readEntry("From","0"),hb);
 	ale->setValidator(new QDoubleValidator(ale));
 	new QLabel(i18n(" To : "),hb);
-	int b=0;
+	double b=config->readDoubleNumEntry("To",0.0);
 	if(s)
 		b=s->Table()->numRows();
 	ble = new KLineEdit(QString::number(b),hb);
 	ble->setValidator(new QDoubleValidator(ble));
 	hb = new QHBox(tab1);
 	new QLabel(i18n(" number of points : "),hb);
-	nrle = new KLineEdit(QString("100"),hb);
-	nrle->setValidator(new QIntValidator(nrle));
+	nrni = new KIntNumInput(config->readNumEntry("Number",100),hb);
+	nrni->setRange(1,INF,1,false);
 
 	if(p) {
 		updateRange();
@@ -58,17 +62,28 @@ InterpolationListDialog::InterpolationListDialog(MainWin *mw, const char *name)
 
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
         QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	QObject::connect(save,SIGNAL(clicked()),SLOT(saveSettings()));
 
 	setMinimumWidth(vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
 	resize(minimumSize());
 }
 
+void InterpolationListDialog::saveSettings() {
+	KConfig *config = mw->Config();
+	config->setGroup( "Interpolation" );
+
+	config->writeEntry("Type",typecb->currentItem());
+	config->writeEntry("From",ale->text());
+	config->writeEntry("To",ble->text());
+	config->writeEntry("Number",nrni->value());
+}
+
 int InterpolationListDialog::apply_clicked() {
 #ifdef HAVE_GSL
 	double a=(ale->text()).toDouble();
 	double b=(ble->text()).toDouble();
-	int number = (nrle->text()).toInt();
+	int number = nrni->value();
 
 	gsl_interp_accel *acc = gsl_interp_accel_alloc();
 
@@ -90,9 +105,8 @@ int InterpolationListDialog::apply_clicked() {
 		// add column if needed
 		bool empty=true;
 		for(int i=0;i<n;i++) {
-			if(table->text(i,table->numCols()-1).length()>0) {
+			if(!table->text(i,table->numCols()-1).isEmpty())
 				empty =false;
-			}
 		}
 		if (!empty)
 			s->addColumn();
@@ -133,8 +147,11 @@ int InterpolationListDialog::apply_clicked() {
 	Symbol *symbol=0;
 	if(st != GRAPHM) {
 		style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
-			widthle->text().toInt(),pencb->currentItem(),brushcb->currentItem());
-		symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->text().toInt(),
+			width->value(),pencb->currentItem(),brushcb->currentItem());
+		style->setBoxWidth(boxwidth->value());
+		style->setAutoBoxWidth(autobox->isChecked());
+		style->setPointsSorting(sortpointscb->isChecked());
+		symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->value(),
 			(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());
 	}
 
@@ -172,7 +189,7 @@ int InterpolationListDialog::apply_clicked() {
 		range[0] = LRange(xmin,xmax);
 		range[1] = LRange(ymin,ymax);
 
-		QString fun = QString(i18n("interpolation of ")+g->Label());
+		QString fun = QString(i18n("interpolation of ")+g->getLabel()->simpleTitle());
 
 		Graph2D *ng = new Graph2D(fun,fun,range,SSPREADSHEET,P2D,style,symbol,ptr,number);
 		mw->addGraph2D(ng,sheetcb->currentItem());
@@ -215,7 +232,7 @@ int InterpolationListDialog::apply_clicked() {
 		range[1] = LRange(ymin,ymax);
 		range[2] = LRange(zmin,zmax);
 
-		QString fun = QString(i18n("interpolation of ")+g->Label());
+		QString fun = QString(i18n("interpolation of ")+g->getLabel()->simpleTitle());
 
 		Graph3D *ng = new Graph3D(fun,fun,range,SSPREADSHEET,type,style,symbol,ptr,number,1);
 		ng->setNumberX(number);
@@ -263,7 +280,7 @@ int InterpolationListDialog::apply_clicked() {
 		range[2] = LRange(zmin,zmax);
 		range[3] = LRange(tmin,tmax);
 
-		QString fun = QString(i18n("interpolation of ")+g->Label());
+		QString fun = QString(i18n("interpolation of ")+g->getLabel()->simpleTitle());
 
 		Graph4D *ng = new Graph4D(fun,fun,range,SSPREADSHEET,type,style,symbol,ptr,number,g->GType());
 		mw->addGraph4D(ng,sheetcb->currentItem());
