@@ -14,11 +14,15 @@ public slots:
 	void setType(int type) {typecb->setCurrentItem(type); }		//!< set type of interpolation
 	void setRange(double a, double b) {						//!< set range for interpolation
 		ale->setText(QString::number(a)); ble->setText(QString::number(b)); }
-	void setNumber(int nr) { nrle->setText(QString::number(nr)); }	//!< set number of interpolating points
+	void setFrom(double v) { ale->setText(QString::number(v)); }
+	void setTo(double v) { ble->setText(QString::number(v)); }
+	void setNumber(int nr) { nrni->setValue(nr); }			//!< set number of interpolating points
+	int Apply() { return apply_clicked(); }
 private:
 	KComboBox *typecb;
-	KLineEdit *nrle;
+	KIntNumInput *nrni;
 private slots:
+	void saveSettings();
 	int apply_clicked();
 };
 
