@@ -12,16 +12,17 @@
 
 using namespace std;
 
-static KCmdLineOptions options[]= {
-	{ "+[file]", "open a project file", 0 },
+static KCmdLineOptions options[] = {
+	{ "no-splash", I18N_NOOP("do not show the splash screen"), 0 },
+	{ "+[file]", I18N_NOOP("open a project file"), 0 },
 	KCmdLineLastOption
 };
 
 int main(int argc, char *argv[]) {
 	KAboutData aboutData("LabPlot","LabPlot", LVERSION,
 		I18N_NOOP("An application for plotting and analysis of 2d and 3d functions and data."),
-		KAboutData::License_GPL, "(c) 2003, Stefan Gerlach",0,"http://labplot.sourceforge.net",
-		"gerlach@mbi-berlin.de");
+		KAboutData::License_GPL, "(c) 2006, Stefan Gerlach",0,"http://labplot.sourceforge.net",
+		"http://sourceforge.net/tracker/?group_id=90279&atid=593035");
 	aboutData.addAuthor("Stefan Gerlach", 0, "gerlach@mbi-berlin.de");
 	KCmdLineArgs::init(argc, argv, &aboutData);
 	KCmdLineArgs::addCmdLineOptions(options);
@@ -32,18 +33,24 @@ int main(int argc, char *argv[]) {
 #endif
 	const char *filename=0;
 	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
-	if (args->count()>0)
+	if (args->count() > 0)
 		filename = args->arg(0);
 
 	KApplication a;
 	
-	static LabPlotSplash *splash = new LabPlotSplash("labplot.png");
-	if (splash) splash->show();
+#if QT_VERSION > 0x030102
+	if (args->isSet("-splash")) {
+		static LabPlotSplash *splash = new LabPlotSplash("labplot.png");
+		if (splash) splash->show();
+	}
+#endif
 
 	MainWin *w = new MainWin("MainWindow",filename);
+	args->clear();
 
 	a.setMainWidget(w);
 	w->show();
 
+	
 	return a.exec(); 
 }
