@@ -16,6 +16,8 @@ public:
 	QStringList Info();
 	void save(QTextStream *t);
 	void open(QTextStream *t,int version);
+	QDomElement saveXML(QDomDocument doc);
+	void openXML(QDomNode node);
 	Point startPoint() { return start; }
 	Point endPoint() { return end; }
 	void setStartPoint(double x, double y) { start=Point(x,y);}
