@@ -25,11 +25,12 @@ public:
 	ListDialog(MainWin *mw, const char *name);
 	void updateList();
 	void updateSheetList();
-	// needed from Spreadsheet => public
 public slots:
+	// needed from Spreadsheet => public
 	void Menu(QListViewItem *, const QPoint& pos, int) { menu->popup(pos); }
 	void updateRange(int axis=0);
 	void toggleShown();
+	void addGraph();
 	void deleteGraph();
 	void changeGraph();
 	void dumpGraph();
@@ -56,6 +57,7 @@ protected:
 	QPopupMenu *menu;
 	PType type;
 	KLineEdit *ale, *ble;
+	QLabel *sheetlabel;
 protected slots:
 	void ok_clicked() { if ( apply_clicked() == 0) accept(); }
 	virtual int apply_clicked() = 0;
