@@ -23,6 +23,7 @@
 #include "Spreadsheet.h"
 #include "Worksheet.h"
 #include "Project.h"
+#include "History.h"
 
 #ifdef HAVE_QSA
 #include <qsproject.h>
@@ -32,73 +33,81 @@
 #endif
 #endif
 
-#define PROJECT_VERSION 21
-
-extern "C" double parse(char[]);
-extern "C" int parse_errors();
+#define PROJECT_VERSION 24
 
 class Worksheet;
 class Spreadsheet;
 class Plot;
 class Plot2DSimple;
+class ExplorerDialog;
+class LegendDialog;
+class TitleDialog;
+class AxesDialog;
+class PlotSettingsDialog;
+class WorksheetDialog;
+class ObjectDialog;
 
 class MainWin
 	: public KParts::MainWindow
 {
 	Q_OBJECT
 private:
+	void setupActions();
 	void readConfig();
 	void enableAutosave(bool as);
 	void newDialog(bool d, PType type);		//!< interface to all data and function dialogs
 	Plot *newPlot(PType type=P2D);			//!< interface to all new plot functions
-	QWorkspace* ws;	
-	QString filename;
+	QString filename;				//!< project filename; empty if not saved yet
 	KParts::ReadOnlyPart* gvpart;
 	QPopupMenu *spreadsheetpopup;
 	QSignalMapper *sm, *smg;			// signal mapper for sheets and graphs
+	QWorkspace* ws;	
 	KConfig *config;
-	KRecentFilesAction* recent;
-	KAction *configureAction, *project_action, *explorer_action;
-	KAction *import_action, *importopj_action, *export_image, *export_svg, *export_pic, *export_ps, *export_eps, *export_pdf;
-	KAction	*export_pstoedit, *export_ImageMagick, *print_action, *save_action, *save_as;
-	KAction *graph_list, *plot_list, *clear_action, *close_action, *worksheet_action, *plot_action, *arrange, *overlay;
-	KAction *deleteplot, *qwt3d_plot, *qwt3d_func, *qwt3d_data;
-	KAction *evaluate, *operations, *imagepro;
-	KAction *smooth, *prune, *average, *compress, *periodic, *seasonal, *hist, *peak;
-	KAction *interpolation, *differences, *integration, *regression, *fft, *convolution, *wavelet, *hankel, *fit;
-	KAction *axes, *title_action, *legend, *objects;
-	KAction *asx, *asy, *asz, *asall, *maglens, *panzoom, *sl, *sr, *su, *sd, *sxu, *sxd, *syu, *syd, *szu, *szd;
-	KAction *zoomin, *zoomout, *maskplot;
-	KAction *baseline, *region, *label, *line, *rect, *ellipse, *image;
-	KAction *ideAction, *scriptAction;
-	KToggleAction *menubar, *toolbar, *sidetoolbar, *analysistoolbar, *drawingtoolbar, *statusbar;
-	KToggleAction *printpreview, *togglespeedmode, *toggledatamode;
-	bool printpreviewchecked;	// needed for print preview
 	Project *project;
-	QTimer *autosaveTimer;
-	bool autosave;
-	long autosaveinterval;
-	bool modified;
-	bool speedmode, datamode;
-	int speedmodevalue;
-	QFont defaultfont;
-	int nr_w, nr_s;
+	History *history;
 #ifdef HAVE_QSA
 	QSProject *qsproject;
 #ifdef HAVE_QSA_IDE
 	QSWorkbench *ide;
 #endif
 #endif
-	bool is_fullscreen;
+	KRecentFilesAction* recent;
+	KAction *configureAction, *project_action, *explorer_action;
+	KAction *import_action, *importopj_action, *export_image, *export_svg, *export_pic, *export_ps, *export_eps, *export_pdf;
+	KAction *export_pstoedit, *export_ImageMagick, *print_action, *save_action, *save_as, *saveXML_action, *openXML_action;
+	KAction *graph_list, *plot_list, *clear_action, *close_action, *worksheet_action, *plot_action, *arrange, *overlay;
+	KAction *deleteplot, *qwt3d_plot, *qwt3d_func, *qwt3d_data;
+	KAction *evaluate, *operations, *imagepro;
+	KAction *smooth, *prune, *average, *compress, *periodic, *seasonal, *hist, *peak;
+	KAction *interpolation, *differences, *integration, *capability, *regression, *fft, *convolution, *wavelet;
+	KAction *hankel, *fit, *filter, *noise, *correl;
+	KAction *axes, *title_action, *legend, *objects;
+	KAction *asx, *asy, *asz, *asall, *maglens, *panzoom, *sl, *sr, *su, *sd, *sxu, *sxd, *syu, *syd, *szu, *szd;
+	KAction *zoomin, *zoomout, *maskplot;
+	KAction *baseline, *region, *label, *line, *rect, *ellipse, *image;
+	KAction *ideAction, *scriptAction, *nextwindow_action, *prevwindow_action, *undo_action, *redo_action;
+	KToggleAction *menubar, *toolbar, *sidetoolbar, *analysistoolbar, *drawingtoolbar, *statusbar;
+	KToggleAction *printpreview, *togglespeedmode, *toggledatamode;
+	bool printpreviewchecked;	// needed for print preview
+	QTimer *autosaveTimer;
+	bool autosave;
+	long autosaveinterval;
+	bool modified, is_fullscreen;
+	bool speedmode, datamode;
+	int speedmodevalue;
+	QFont defaultfont;
+	int nr_w, nr_s;
 private slots:
 	void closeWin();
 	void setWinFocus(int i) { (ws->windowList()).at(i)->setFocus(); }
 	void SpreadsheetMenu();
+	void windowActivated(); // called when active window changes
 	
 	void configure();
 	void configureKeys() { KKeyDialog::configure(actionCollection(), this, true); }
 	void configureToolbars();
 	void saveSettings();
+	void autoSave();
 	void setAutosaveInterval(long interval) { autosaveinterval=interval;}
 
 	void openIDE();
@@ -128,9 +137,11 @@ private slots:
 	void exampleSurfaceStyle() { openfile(locate("data", QString("LabPlot/surfacestyle.lpl.gz"))); }
 	void exampleTeXLabel() { openfile(locate("data", QString("LabPlot/texlabel.lpl.gz"))); }
 public slots:
-	void open(QString fn=0);							//!< open the LabPlot project file fn (*.lpl)
 	void New();									//!< open new project 
+	void open(QString fn=0);							//!< open the LabPlot project file fn (*.lpl)
 	void save(QString fn=0);							//!< save LabPlot project to file fn
+	void openXML(QString fn=0);							//!< open LabPlot project from XML file fn
+	void saveXML(QString fn=0);							//!< save LabPlot project to XML file fn
 	void saveAs(QString fn=0);						//!< save LabPlot project to file fn
 	void projectInfo();								// TODO : project info dialog
 	void projectExplorer();							// TODO : project explorer
@@ -203,6 +214,8 @@ public slots:
 
 	Style* newStyle() { return new Style(); }		//!< create new Style	: Wrapper for QSA
 	Symbol* newSymbol() { return new Symbol(); }		//!< create new Symbol	: Wrapper for QSA
+	Style *defaultStyle();					//!< get default Style
+	Symbol *defaultSymbol();				//!< get default Symbol
 	void lDebug(QString s) { kdDebug()<<s<<endl; }		//!< wrapper for debug messages
 	
 	void evaluateDialog();							// TODO 
@@ -218,12 +231,16 @@ public slots:
 	void interpolationDialog();
 	void differencesDialog();
 	void integrationDialog();
+	void capabilityDialog();
 	void regressionDialog();
 	void fftDialog();
 	void convolutionDialog();
 	void waveletDialog();
 	void hankelDialog();
 	void fitDialog();
+	void filterDialog();
+	void noiseDialog();
+	void correlDialog();
 	void imageDialog();
 
 	void arrangeDialog();							// TODO
@@ -268,26 +285,58 @@ public slots:
 	void defineEllipse();
 	void defineImage();
 	
-	void setActiveSheet(int i);	// called from signal mapper (sheet list)
+	void setActiveSheet(int i);		// called from signal mapper (sheet list)
 	void changeGraph(int i);		// called from signal mapper (graph list)
+	void cloneActiveSheet();		// clone active sheet
+	void cloneWorksheet(Worksheet *w);	// clone worksheet w
+	void cloneSpreadsheet(Spreadsheet *s);	// clone spreadsheet s
 	Spreadsheet* newSpreadsheet();
 	Worksheet* newWorksheet();
 	Worksheet* activeWorksheet();
 	Spreadsheet* activeSpreadsheet();
+	int activeSheetIndex();
 	void updateGraphList();
 	void updateSheetList();
+	
+	// dialog update wrapper
+	void updateExplorerDialog();
+	void updateLegendDialog();
+	void updateTitleDialog();
+	void updateAxesDialog(int i=-1);
+	void updatePlotSettingsDialog();
+	void updateWorksheetDialog();
+	void updateObjectDialog();
+
+	void activateNextWindow() { 
+#if QT_VERSION > 0x030102
+		ws->activateNextWindow(); 
+#endif
+	}
+	void activatePrevWindow() { 
+#if QT_VERSION > 0x030102
+		ws->activatePrevWindow(); 
+#endif
+	}
+	void undoAction();
+	void redoAction();
 public:
 	MainWin(const char *name,const char *filen,bool is_part=false);
 	void replot();
 	void openfile(QString file);
 	void message(QString msg) {statusBar()->message(msg); }
 	KConfig* Config() { return config; }
+	History* getHistory() { return history; }
 	int defining_region, defining_line, defining_rect, defining_ellipse;	// value = 0-not,1-left,2-right line
 	int defining_maglens,defining_panzoom, defining_mask;			// dto.
 	bool defining_baseline,defining_label,defining_image;
-	QString last_2dfunction, last_3dfunction, last_filename;		// function, filename of last input
-	int last_readas, last_nrpointsx, last_nrpointsy;	
-	double last_xmin, last_xmax, last_ymin, last_ymax;			// readas, nrpoints and range of last input
+	// dialogs to update
+	ExplorerDialog *explorer_dialog;
+	LegendDialog *legend_dialog;
+	TitleDialog *title_dialog;
+	AxesDialog *axes_dialog;
+	PlotSettingsDialog *plotsettings_dialog;
+	WorksheetDialog *worksheet_dialog;
+	ObjectDialog *object_dialog;
 	
 	Project *getProject() { return project; }
 	void setProject(Project *p) { project=p; }
@@ -300,26 +349,27 @@ public:
 	void setModified() {modified = true;}
 	int NrSpreadsheets() { return nr_s; }
 	int NrWorksheets() { return nr_w; }
+	QString Filename() { return filename; }				//!< get project file name 
 	Worksheet *addWorksheet(PType type, int sheet);				// add a new worksheet if needed (function/data dialog)
 	int addGraph2D(Graph2D *g, int item, PType type=P2D);		// add Graph2D to widget item in workspace
 	int addGraph3D(Graph3D *g, int item, PType type=P3D);		// add Graph3D to widget item in workspace
 	int addGraph4D(Graph4D *g, int item);						// add Graph4D to widget item in workspace
 	int addGraphM(GraphM *g, int item, PType type=PSURFACE);	// add GraphM to widget item in workspace
 	int addGraphIMAGE(GraphIMAGE *g, int item);				// add GraphIMAGE to widget item in workspace
+	int addGraphL(GraphL *g, int item, PType type=PPIE);		// add GraphL to widget item in workspace
 	void calculateRanges2D(Point *a, int n, double *xmin, double *xmax,
 		double *ymin, double *ymax);
 	void calculateRanges3D(Point3D *a, int n, double *xmin, double *xmax,
 		double *ymin, double *ymax, double *zmin, double *zmax);
 	void calculateRanges4D(Point4D *a, int n, double *xmin, double *xmax,
 		double *ymin, double *ymax, double *zmin, double *zmax, double *tmin, double *tmax);
-	QString parseExpression(QString tmp, double value, int j);	// parse expression
 	double formatLabel(QString value,int item);
 protected:
 	void resizeEvent(QResizeEvent *e) { this->resize(e->size()); }
 	void dragEnterEvent(QDragEnterEvent *e) { e->accept(QTextDrag::canDecode(e)); }
 	void dropEvent(QDropEvent *e);
 	void closeEvent(QCloseEvent *e);
-	void mouseDoubleClickEvent(QMouseEvent *e) { e->pos(); if(!menuBar()->isVisible()) menuBar()->show(); }
+	void mouseDoubleClickEvent(QMouseEvent *e);
 
 };
 
