@@ -13,12 +13,14 @@ public:
 public slots:
 	void setOperation(int o) { 	type->setCurrentItem(o); }		//!< set type of operation
 	void setType(int o) { setOperation(o); }
-	void setFirst(int a) {set1le->setText(QString::number(a)); }		//!< set first set/column
-	void setSecond(int b) {set2le->setText(QString::number(b)); }	//!< set second set/column
+	void setFirst(int a) {set1ni->setValue(a); }		//!< set first set/column
+	void setSecond(int b) {set2ni->setValue(b); }		//!< set second set/column
+	int Apply() { return apply_clicked(); }
 private:
-	KLineEdit *set1le, *set2le;
+	KIntNumInput *set1ni, *set2ni;
 	KComboBox *type;
 private slots:
+	void saveSettings();
 	int apply_clicked();
 };
 
