@@ -15,15 +15,17 @@ OverlayPlotDialog::OverlayPlotDialog(MainWin *mw, const char *name)
 	: PlotDialog(mw, name)
 {
 	setCaption(i18n("Overlay Plots"));
+	KConfig *config = mw->Config();
+	config->setGroup( "Overlay" );
 
 	//TODO : i and j
 	QHBox* hb = new QHBox(vbox);
 	new QLabel(i18n("Overlay Plot "),hb);
-	ale = new KLineEdit(QString("2"),hb);
-	ale->setValidator(new QIntValidator(1,p->NrPlots(),ale));
+	ani = new KIntNumInput(config->readNumEntry("Set1",2),hb);
+	ani->setRange(1,p->NrPlots(),1,false);
 	new QLabel(i18n(" onto Plot "),hb);
-	ble = new KLineEdit(QString("1"),hb);
-	ble->setValidator(new QIntValidator(1,p->NrPlots(),ble));
+	bni = new KIntNumInput(config->readNumEntry("Set2",1),hb);
+	bni->setRange(1,p->NrPlots(),1,false);
 
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
 	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
@@ -33,9 +35,17 @@ OverlayPlotDialog::OverlayPlotDialog(MainWin *mw, const char *name)
 	resize(minimumSize());
 }
 
+void OverlayPlotDialog::saveSettings() {
+	KConfig *config = mw->Config();
+	config->setGroup( "Overlay" );
+
+	config->writeEntry("Set1", ani->value());
+	config->writeEntry("Set2", bni->value());
+}
+
 void OverlayPlotDialog::apply_clicked() {
-	int a = ale->text().toInt()-1;
-	int b = ble->text().toInt()-1;
+	int a = ani->value()-1;
+	int b = bni->value()-1;
 	Plot *plota = p->getPlot(a);
 	Plot *plotb = p->getPlot(b);
 
