@@ -1,14 +1,16 @@
-
 // LabPlot : Plot.cc
 
 #include <math.h>
 #include <iostream>
 #include <kdebug.h>
 #include <klocale.h>
+#include <kconfig.h>
 #include "Plot.h"
 #include "Plot2DSurface.h"
 #include "PlotQWT3D.h"
 
+#include "parser_extern.h"
+
 using namespace std;
 
 //! general Plot class
@@ -18,8 +20,11 @@ Plot::Plot(Worksheet *w)
 	kdDebug()<<"Plot::Plot()"<<endl;
 	graphlist = new GraphList();
 
-	bgcolor = QColor(Qt::white);
-	gbgcolor = QColor(Qt::white);
+	KConfig *config = w->getMainWin()->Config();
+	aspect_enabled = config->readBoolEntry("AspectRatio",false);
+
+	bgcolor = config->readColorEntry("BackgroundColor",&Qt::white);
+	gbgcolor = config->readColorEntry("GraphBackgroundColor",&Qt::white);
 
 	// title (richtext title)
 	if(worksheet==0) kdDebug()<<"no Worksheet defined!"<<endl;
@@ -30,30 +35,147 @@ Plot::Plot(Worksheet *w)
 	font.setPointSize((int)(0.4*font.pointSize()));
 	legend.setFont(font);
 	
-	position.setPoint(0.0,0.0);
-	size.setPoint(1.0,1.0);
+	position.setPoint(config->readDoubleNumEntry("Position X",0.0),config->readDoubleNumEntry("Position Y",0.0));
+	size.setPoint(config->readDoubleNumEntry("Size X",1.0),config->readDoubleNumEntry("Size Y",1.0));
 	p1.setPoint(.15,.15);
 	p2.setPoint(.95,.85);
 
-	baseline=0;
-	baseline_enabled=0;
-	xbaseline=0;
-	xbaseline_enabled=0;
+	baseline = config->readDoubleNumEntry("YBaseline",0);
+	baseline_enabled = config->readBoolEntry("YBaselineEnabled",false);
+	xbaseline = config->readDoubleNumEntry("XBaseline",0);
+	xbaseline_enabled = config->readBoolEntry("XBaselineEnabled",false);
 
-	region= new LRange(0.0,0.0);
-	region_enabled=1;
+	region= new LRange(config->readDoubleNumEntry("RegionMin",0.0),config->readDoubleNumEntry("RegionMax",0.0));
+	region_enabled = config->readBoolEntry("RegionEnabled",false);
 
-	transparent=false;
-	clipoffset=10;
+	transparent = config->readBoolEntry("Transparent",false);
+	clipoffset = config->readNumEntry("ClipOffset",10);
 
-	marks_enabled=false;
-	markx = new LRange(0.0,1.0);
-	marky = new LRange(0.0,1.0);
+	marks_enabled = config->readBoolEntry("MarkerEnabled",false);
+	markx = new LRange(config->readDoubleNumEntry("MarkerXMin",0.0),config->readDoubleNumEntry("MarkerXMax",1.0));
+	marky = new LRange(config->readDoubleNumEntry("MarkerYMin",0.0),config->readDoubleNumEntry("MarkerYMax",1.0));
 
+	// fill
+	fill_enabled = config->readBoolEntry("FillEnabled",false);
+	filltype = config->readNumEntry("FillType",0);
+	fillg1 = config->readNumEntry("FillG1",1);
+	fillg2 = config->readNumEntry("FillG2",2);
+	fillbrush = QBrush(config->readColorEntry("FillColor",&Qt::red),
+		(Qt::BrushStyle)config->readNumEntry("FillBrush",Qt::SolidPattern));
 	kdDebug()<<"Plot OK"<<endl;
 }
 
-void Plot::drawStyle(QPainter *p, Style *style, Symbol *symbol, QPointArray pa,int xmin, int xmax,int ymin, int ymax) {
+// read default axis settings
+void Plot::readAxisSettings(Axis *a, int type, int item) {
+	KConfig *config = worksheet->getMainWin()->Config();
+	config->setGroup( "Axes" );
+	
+	// default values for different plots
+	bool e=true, borderenabled=true, gridenabled=false;
+	switch (type) {
+	case P2D:
+		if(item>1) {
+			e = false;
+			borderenabled = false;
+		};break;
+	case P3D:
+		if(item>2) {
+			e = false;
+		}; break;
+	case PPIE: case PTERNARY:
+		gridenabled = true;
+		break;
+	default:break;
+	}
+	
+	QString entry = QString("PlotType %1 Axis %2 ").arg(type).arg(item); 
+
+	a->Enable(config->readBoolEntry(entry+"Enabled",e));
+	a->setPosition(config->readNumEntry(entry+"Position"));
+	a->setScale((TScale) (config->readNumEntry(entry+"Scale",LINEAR)));
+	a->setScaling(config->readNumEntry(entry+"Scaling",1));
+	a->setShift(config->readNumEntry(entry+"Shift"));
+	// dont set range -> automatic
+
+	a->getLabel()->readSettings(config,entry);
+	
+	a->setTickPos(config->readNumEntry(entry+"TickPosition"));
+	a->setTickType(config->readNumEntry(entry+"TickStyle",1));
+	a->enableMajorTicks(config->readBoolEntry(entry+"MajorTicksEnabled",true));
+	a->setMajorTicks(config->readDoubleNumEntry(entry+"MajorTicks",-1));
+	a->setMajorTickWidth(config->readNumEntry(entry+"MajorTickWidth",1));
+	a->enableMinorTicks(config->readBoolEntry(entry+"MinorTicksEnabled",true));
+	a->setMinorTicks(config->readNumEntry(entry+"MinorTicks",3));
+	a->setMinorTickWidth(config->readNumEntry(entry+"MinorTickWidth",1));
+	a->setTickColor(config->readColorEntry(entry+"TickColor",&Qt::black));
+
+	if(type == PQWT3D) {
+		a->setMajorTickLength(config->readDoubleNumEntry(entry+"MajorTickLength",0.05));
+		a->setMinorTickLength(config->readDoubleNumEntry(entry+"MinorTickLength",0.05));
+	}
+
+	a->enableTickLabel(config->readBoolEntry(entry+"TickLabelEnabled",true));
+	QFont font(QString("Adobe Times"),12);
+	a->setTickLabelFont(config->readFontEntry(entry+"TickLabelFont",&font));
+	a->setTickLabelColor(config->readColorEntry(entry+"TickLabelColor",&Qt::black));
+	a->setTickLabelFormat((TFormat)config->readNumEntry(entry+"TickLabelFormat",(int)AUTO));
+	a->setDateTimeFormat(config->readEntry(entry+"DateTimeFormat","auto"));
+	a->setTickLabelPrecision(config->readNumEntry(entry+"TickLabelPrecision",3));
+	a->setTickLabelPosition(config->readNumEntry(entry+"TickLabelPosition",15));
+	a->setTickLabelPrefix(config->readEntry(entry+"TickLabelPrefix"));
+	a->setTickLabelSuffix(config->readEntry(entry+"TickLabelSuffix"));
+	a->setTickLabelRotation(config->readNumEntry(entry+"TickLabelRotation"));
+	
+	a->enableMajorGrid(config->readBoolEntry(entry+"MajorGridEnabled",gridenabled));
+	a->enableMinorGrid(config->readBoolEntry(entry+"MinorGridEnabled",gridenabled));
+	a->setMajorGridWidth(config->readNumEntry(entry+"MajorGridWidth",1));
+	a->setMajorGridType((Qt::PenStyle)config->readNumEntry(entry+"MajorGridStyle",(int)Qt::DashLine));
+	a->setMajorGridColor(config->readColorEntry(entry+"MajorGridColor",&Qt::black));
+	a->setMinorGridWidth(config->readNumEntry(entry+"MinorGridWidth",1));
+	a->setMinorGridType((Qt::PenStyle)config->readNumEntry(entry+"MinorGridStyle",(int)Qt::DotLine));
+	a->setMinorGridColor(config->readColorEntry(entry+"MinorGridColor",&Qt::black));
+	
+	a->enableBorder(config->readBoolEntry(entry+"BorderEnabled",borderenabled));
+	a->setBorderColor(config->readColorEntry(entry+"BorderColor",&Qt::black));
+	a->setBorderWidth(config->readNumEntry(entry+"BorderWidth",1));
+}
+
+void Plot::sortPoints(QPointArray pa,int s, int e) {
+	// bubble sort
+/*	QPoint tmp;
+	for(unsigned int i=a;i<e;i++) {
+		for(unsigned int j=0;j<pa.size()-1;j++) {
+			if(pa[j].x()>pa[j+1].x()) {
+				tmp=pa[j];
+				pa[j]=pa[j+1];
+				pa[j+1]=tmp;
+			}
+		}
+	}
+*/
+	// quick sort
+	if(e>s+1) {
+		QPoint tmp, mid = pa[(s+e)/2];
+
+		int i=s, j=e;
+		while(i<j) {
+			while(pa[i].x() < mid.x()) i++;
+			while(mid.x() < pa[j].x()) j--;
+
+			if(i<j) {
+				tmp = pa[i];
+				pa[i] = pa[j];
+				pa[j] = tmp;
+				i++;j--;
+			}
+		}
+
+		sortPoints(pa,s,j);
+		sortPoints(pa,i,e);
+	}
+}
+
+void Plot::drawStyle(QPainter *p, Style *style, Symbol *symbol, QPointArray pa, int xmin, int xmax, int ymin, int ymax) {
 	kdDebug()<<"Plot::drawStyle()"<<endl;
 	bool filled = style->isFilled();
 	QColor c = style->FillColor();
@@ -70,21 +192,36 @@ void Plot::drawStyle(QPainter *p, Style *style, Symbol *symbol, QPointArray pa,i
 	int basey = ymax - (int) ((baseline-min)/(max-min)*(double)(ymax-ymin));
 	int basex = xmin + (int) ((xbaseline-minx)/(maxx-minx)*(double)(xmax-xmin));
 	int bw = style->BoxWidth();
+	int rmin = xmin + (int) ((region->rMin()-minx)/(maxx-minx)*(double)(xmax-xmin));
+	int rmax = xmin + (int) ((region->rMax()-minx)/(maxx-minx)*(double)(xmax-xmin));
 	//kdDebug()<<"BASEX = "<<basex<<endl;
 	//kdDebug()<<"BASEY = "<<basey<<endl;
 
 //	kdDebug()<<"POINTARRAY "<<i<<'='<<pa[i].x()<<' '<<pa[i].y()<<endl;
-		
+
 	switch(style->Type()) {
 	case 0:	// line
 		if (filled) {
-			QPointArray fillpa(pa.size()+2);
 			p->setPen(Qt::NoPen);
 			p->setBrush(brush);
-			fillpa[0]=QPoint(pa[0].x(),basey);
-			for(unsigned int i=0;i<pa.size();i++)
-				fillpa[i+1]=pa[i];
-			fillpa[pa.size()+1]=QPoint(pa[pa.size()-1].x(),basey);
+		
+			QPointArray fillpa(pa.size()+2);
+			if(fabs((double)(rmax-rmin)) > 0) {	//draw only region
+				int index=0,newindex=1;
+				while(pa[index].x() < rmin)
+					index++;
+				fillpa[0] = QPoint(pa[index].x(),basey);
+				while(pa[index].x() < rmax)
+					fillpa[newindex++] = pa[index++];
+				fillpa[newindex] = QPoint(pa[index-1].x(),basey);
+				fillpa.resize(newindex+1);
+			}
+			else {
+				fillpa[0] = QPoint(pa[0].x(),basey);
+				for(unsigned int i=0;i<pa.size();i++)
+					fillpa[i+1]=pa[i];
+				fillpa[pa.size()+1]=QPoint(pa[pa.size()-1].x(),basey);
+			}
 			p->drawPolygon(fillpa);
 			p->setPen(pen);
 		}
@@ -106,10 +243,22 @@ void Plot::drawStyle(QPainter *p, Style *style, Symbol *symbol, QPointArray pa,i
 			QPointArray fillpa(stepspa.size()+2);
 			p->setPen(Qt::NoPen);
 			p->setBrush(brush);
-			fillpa[0]=QPoint(stepspa[0].x(),basey);
-			for(unsigned int i=0;i<stepspa.size();i++)
-				fillpa[i+1]=stepspa[i];
-			fillpa[stepspa.size()+1]=QPoint(stepspa[stepspa.size()-1].x(),basey);
+			if(fabs((double)(rmax-rmin)) > 0) {	// draw only region
+				int index=0,newindex=1;
+				while(stepspa[index].x() < rmin)
+					index++;
+				fillpa[0] = QPoint(stepspa[index].x(),basey);
+				while(stepspa[index].x() < rmax)
+					fillpa[newindex++] = stepspa[index++];
+				fillpa[newindex] = QPoint(stepspa[index-1].x(),basey);
+				fillpa.resize(newindex+1);
+			}
+			else {
+				fillpa[0]=QPoint(stepspa[0].x(),basey);
+				for(unsigned int i=0;i<stepspa.size();i++)
+					fillpa[i+1]=stepspa[i];
+				fillpa[stepspa.size()+1]=QPoint(stepspa[stepspa.size()-1].x(),basey);
+			}
 			p->drawPolygon(fillpa);
 			p->setPen(pen);
 		}
@@ -228,6 +377,103 @@ void Plot::drawErrorBar(QPainter *p, QPointArray pa, QPointArray hpa, QPointArra
 	}
 }
 
+QDomElement Plot::savePlotXML(QDomDocument doc) {
+	QDomElement plottag = doc.createElement( "Plot" );
+	plottag.setAttribute("type",QString::number(type));
+
+	QDomElement tag = doc.createElement( "Background" );
+   	plottag.appendChild( tag );
+  	QDomText t = doc.createTextNode( bgcolor.name() );
+    	tag.appendChild( t );
+	tag = doc.createElement( "GraphBackground" );
+   	plottag.appendChild( tag );
+  	t = doc.createTextNode( gbgcolor.name() );
+    	tag.appendChild( t );
+	tag = doc.createElement( "Transparent" );
+   	plottag.appendChild( tag );
+  	t = doc.createTextNode( QString::number(transparent) );
+    	tag.appendChild( t );
+	tag = doc.createElement( "ClipOffset" );
+   	plottag.appendChild( tag );
+  	t = doc.createTextNode( QString::number(clipoffset) );
+    	tag.appendChild( t );
+
+	tag = doc.createElement( "XActRange" );
+	tag.setAttribute("min",QString::number(actrange[0].rMin()));
+	tag.setAttribute("max",QString::number(actrange[0].rMax()));
+   	plottag.appendChild( tag );
+	tag = doc.createElement( "YActRange" );
+	tag.setAttribute("min",QString::number(actrange[1].rMin()));
+	tag.setAttribute("max",QString::number(actrange[1].rMax()));
+   	plottag.appendChild( tag );
+	tag = doc.createElement( "ZActRange" );
+	tag.setAttribute("min",QString::number(actrange[2].rMin()));
+	tag.setAttribute("max",QString::number(actrange[2].rMax()));
+   	plottag.appendChild( tag );
+	
+	tag = doc.createElement( "Baseline" );
+	tag.setAttribute("x",QString::number(xbaseline));
+	tag.setAttribute("y",QString::number(baseline));
+	tag.setAttribute("x_enabled",QString::number(xbaseline_enabled));
+	tag.setAttribute("y_enabled",QString::number(baseline_enabled));
+   	plottag.appendChild( tag );
+
+	tag = doc.createElement( "Region" );
+	tag.setAttribute("min",QString::number(region->rMin()));
+	tag.setAttribute("max",QString::number(region->rMax()));
+	tag.setAttribute("enabled",QString::number(region_enabled));
+   	plottag.appendChild( tag );
+
+	tag = doc.createElement( "Position" );
+	tag.setAttribute("x",QString::number(position.X()));
+	tag.setAttribute("y",QString::number(position.Y()));
+   	plottag.appendChild( tag );
+	tag = doc.createElement( "Size" );
+	tag.setAttribute("x",QString::number(size.X()));
+	tag.setAttribute("y",QString::number(size.Y()));
+   	plottag.appendChild( tag );
+	tag = doc.createElement( "PlotArea" );
+	tag.setAttribute("xmin",QString::number(p1.X()));
+	tag.setAttribute("xmax",QString::number(p2.X()));
+	tag.setAttribute("ymin",QString::number(p1.Y()));
+	tag.setAttribute("ymax",QString::number(p2.Y()));
+   	plottag.appendChild( tag );
+
+	tag = doc.createElement( "AspectRatio" );
+   	plottag.appendChild( tag );
+  	t = doc.createTextNode( QString::number(aspect_enabled) );
+    	tag.appendChild( t );
+
+	tag = doc.createElement( "Marks" );
+	tag.setAttribute("enabled",QString::number(marks_enabled));
+	tag.setAttribute("xmin",QString::number(markx->rMin()));
+	tag.setAttribute("xmax",QString::number(markx->rMax()));
+	tag.setAttribute("ymin",QString::number(marky->rMin()));
+	tag.setAttribute("ymax",QString::number(marky->rMax()));
+   	plottag.appendChild( tag );
+
+	tag = doc.createElement( "Fill" );
+	tag.setAttribute("enabled",QString::number(fill_enabled));
+	tag.setAttribute("type",QString::number(filltype));
+	tag.setAttribute("firstgraph",QString::number(fillg1));
+	tag.setAttribute("secondgraph",QString::number(fillg2));
+	tag.setAttribute("color",fillbrush.color().name());
+	tag.setAttribute("brush",QString::number(fillbrush.style()));
+   	plottag.appendChild( tag );
+
+	tag = title->saveXML(doc);
+   	plottag.appendChild( tag );
+	tag = legend.saveXML(doc);
+   	plottag.appendChild( tag );
+
+	// save aditional plot stuff
+	saveXML(doc,plottag);
+
+	graphlist->saveXML(doc,plottag);
+
+	return plottag;
+}
+
 void Plot::save(QTextStream *t) {
 	kdDebug()<<"Plot::save()"<<endl;
 	*t<<bgcolor.name()<<endl;
@@ -249,9 +495,16 @@ void Plot::save(QTextStream *t) {
 	*t<<p1.X()<<' '<<p1.Y()<<endl;
 	*t<<p2.X()<<' '<<p2.Y()<<endl;
 	
+	*t<<aspect_enabled<<endl;
+	
 	//marks
 	*t<<marks_enabled<<' '<<markx->rMin()<<' '<<markx->rMax()<<' '<<marky->rMin()<<' '<<marky->rMax()<<endl;
 
+	// fill
+	*t<<(int)fill_enabled<<' '<<filltype<<endl;
+	*t<<fillg1<<' '<<fillg2<<endl;
+	*t<<fillbrush.color().name()<<' '<<fillbrush.style()<<endl;
+
 	title->save(t);
 	legend.save(t);
 	saveAxes(t);
@@ -259,10 +512,16 @@ void Plot::save(QTextStream *t) {
 	if (type == PSURFACE) {
 		Plot2DSurface *plot = (Plot2DSurface *)this;
 		*t<<plot->densityEnabled()<<' '<<plot->contourEnabled()<<endl;
-		*t<<plot->Number()<<' '<<plot->Palette()<<endl;
+		*t<<plot->Number()<<' '<<endl;
 		*t<<plot->ContourColor().name()<<endl;
 		*t<<plot->Mesh()<<' '<<plot->ColoredContour()<<' '<<plot->Brush()<<' ';
 		*t<<plot->Relative()<<' '<<plot->Threshold()<<endl;
+#ifdef HAVE_GL
+		Qwt3D::ColorVector cv = plot->getColorVector();
+		*t<<cv.size()<<endl;
+		for(unsigned int i=0;i<cv.size();i++)
+			*t<<cv[i].r<<' '<<cv[i].g<<' '<<cv[i].b<<' '<<cv[i].a<<endl;
+#endif
 	}
 #ifdef HAVE_GL
 	else if (type == PQWT3D) {
@@ -275,7 +534,7 @@ void Plot::save(QTextStream *t) {
 		*t<<plot->isolines()<<endl;
 		*t<<(int) plot->mouseDisabled()<<endl;
 		for(int i=0;i<12;i++)
-			*t<<plot->majorTicLength(i)<<' '<<plot->minorTicLength(i)<<endl;
+			*t<<plot->getAxis(i)->majorTickLength()<<' '<<plot->getAxis(i)->minorTickLength()<<endl;
 		*t<<(int) plot->Resolution()<<endl;
 
 		Qwt3D::ColorVector cv = plot->getColorVector();
@@ -313,12 +572,327 @@ void Plot::save(QTextStream *t) {
 			*t<<"GraphIMAGE "<<i<<endl;
 			graphlist->getGraphIMAGE(i)->save(t);
 			break;
+		case GRAPHL:
+			*t<<"GraphL "<<i<<endl;
+			graphlist->getGraphL(i)->save(t,progress);
+			break;
 		default: break;
 		}
 	}
 	*t<<"EOG "<<i<<endl;
 }
 
+#ifdef HAVE_GL
+Qwt3D::ColorVector Plot::convertOldColormap(int index) {
+	Qwt3D::ColorVector cv;
+	cv.clear();
+		
+	Qwt3D::RGBA rgb;
+
+	switch(index) {
+	case 0: 
+		for(int i=0;i<255;i++) {
+			rgb.a = 1;
+			i>127?rgb.r = (2*(i-128))/255.0:rgb.r = 0;
+			rgb.g = 0;
+			i>127?rgb.b = 0:rgb.b = (2*(127-i))/255.0;
+			cv.push_back(rgb);
+		}
+		break;
+	case 1:
+		for(int i=0;i<255;i++) {
+			rgb.a = 1;
+			rgb.r=0;
+			i>127?rgb.g = (2*(i-128))/255.0:rgb.g = 0;
+			i>127?rgb.b = 0:rgb.b = (2*(127-i))/255.0;
+			cv.push_back(rgb);
+		}
+		break;
+	case 2:
+		for(int i=0;i<255;i++) {
+			rgb.a = 1;
+			i>127?rgb.r = 0:rgb.r = (2*(127-i))/255.0;
+			rgb.g=0;
+			i>127?rgb.b = (2*(i-128))/255.0:rgb.b=0;
+			cv.push_back(rgb);
+		}
+		break;
+	case 3:
+		for(int i=0;i<255;i++) {
+			rgb.a = 1;
+			rgb.r=0;
+			i>127?rgb.g = 0:rgb.g = (2*(127-i))/255.0;
+			i>127?rgb.b = (2*(i-128))/255.0:rgb.b=0;
+			cv.push_back(rgb);
+		}
+		break;
+	case 4:
+		for(int i=0;i<255;i++) {
+			rgb.a = 1;
+			i>127?rgb.r = 0:rgb.r = (2*(127-i))/255.0;
+			i>127?rgb.g = (2*(i-128))/255.0:rgb.g=0;
+			rgb.b=0;
+			cv.push_back(rgb);
+		}
+		break;
+	case 5:
+		for(int i=0;i<255;i++) {
+			rgb.a = 1;
+			rgb.r=i/255.;
+			rgb.g=0;
+			rgb.b=0;
+			cv.push_back(rgb);
+		}
+		break;
+	case 6:
+		for(int i=0;i<255;i++) {
+			rgb.a = 1;
+			rgb.r=0;
+			rgb.g=i/255.;
+			rgb.b=0;
+			cv.push_back(rgb);
+		}
+		break;
+	case 7:
+		for(int i=0;i<255;i++) {
+			rgb.a = 1;
+			rgb.r=0;
+			rgb.g=0;
+			rgb.b=i/255.;
+			cv.push_back(rgb);
+		}
+		break;
+	case 8:
+		for(int i=0;i<255;i++) {
+			rgb.a = 1;
+			rgb.r=i/255.;
+			rgb.g=i/255.;
+			rgb.b=i/255.;
+			cv.push_back(rgb);
+		}
+		break;
+	case 9:
+		for(int i=0;i<255;i++) {
+			rgb.a = 1;
+			rgb.r=i/255.;
+			rgb.g=i/255.;
+			rgb.b=0;
+			cv.push_back(rgb);
+		}
+		break;
+	case 10:
+		for(int i=0;i<255;i++) {
+			rgb.a = 1;
+			rgb.r=i/255.;
+			rgb.g=0;
+			rgb.b=i/255.;
+			cv.push_back(rgb);
+		}
+		break;
+	case 11:
+		for(int i=0;i<255;i++) {
+			rgb.a = 1;
+			rgb.r=0;
+			rgb.g=i/255.;
+			rgb.b=i/255.;
+			cv.push_back(rgb);
+		}
+		break;
+	case 12:
+		for(int i=0;i<255;i++) {
+			QColor c = QColor(255-i,255,255,QColor::Hsv);
+			rgb.a = 1;
+			rgb.r=c.red()/255.;
+			rgb.g=c.green()/255.;
+			rgb.b=c.blue()/255.;
+			cv.push_back(rgb);
+		}
+		break;
+	case 13:
+		for(int i=0;i<255;i++) {
+			QColor c = QColor(255-i,255,200,QColor::Hsv);
+			rgb.a = 1;
+			rgb.r=c.red()/255.;
+			rgb.g=c.green()/255.;
+			rgb.b=c.blue()/255.;
+			cv.push_back(rgb);
+		}
+		break;
+	case 14:
+		for(int i=0;i<255;i++) {
+			QColor c = QColor(255-i,100,255,QColor::Hsv);
+			rgb.a = 1;
+			rgb.r=c.red()/255.;
+			rgb.g=c.green()/255.;
+			rgb.b=c.blue()/255.;
+			cv.push_back(rgb);
+		}
+		break;
+	case 15:
+		for(int i=0;i<255;i++) {
+			QColor c = QColor(255-i,100,200,QColor::Hsv);
+			rgb.a = 1;
+			rgb.r=c.red()/255.;
+			rgb.g=c.green()/255.;
+			rgb.b=c.blue()/255.;
+			cv.push_back(rgb);
+		}
+		break;
+	case 16:
+		for(int i=0;i<255;i++) {
+			QColor c = QColor(i,255,255,QColor::Hsv);
+			rgb.a = 1;
+			rgb.r=c.red()/255.;
+			rgb.g=c.green()/255.;
+			rgb.b=c.blue()/255.;
+			cv.push_back(rgb);
+		}
+		break;
+	case 17:
+		for(int i=0;i<255;i++) {
+			QColor c = QColor(i,255,200,QColor::Hsv);
+			rgb.a = 1;
+			rgb.r=c.red()/255.;
+			rgb.g=c.green()/255.;
+			rgb.b=c.blue()/255.;
+			cv.push_back(rgb);
+		}
+		break;
+	case 18:
+		for(int i=0;i<255;i++) {
+			QColor c = QColor(i,100,255,QColor::Hsv);
+			rgb.a = 1;
+			rgb.r=c.red()/255.;
+			rgb.g=c.green()/255.;
+			rgb.b=c.blue()/255.;
+			cv.push_back(rgb);
+		}
+		break;
+	case 19:
+		for(int i=0;i<255;i++) {
+			QColor c = QColor(i,100,200,QColor::Hsv);
+			rgb.a = 1;
+			rgb.r=c.red()/255.;
+			rgb.g=c.green()/255.;
+			rgb.b=c.blue()/255.;
+			cv.push_back(rgb);
+		}
+		break;
+	case 20:
+		for(int i=0;i<255;i++) {
+			rgb.a = 1;
+			rgb.r=(255.-i)/255.;
+			rgb.g=(255.-i)/255.;
+			rgb.b=(255.-i)/255.;
+			cv.push_back(rgb);
+		}
+		break;
+	}
+	
+	return cv;
+}
+#endif
+
+void Plot::openPlotXML(QDomNode node) {
+	while(!node.isNull()) {
+		QDomElement e = node.toElement();
+//		kdDebug()<<"PLOT TAG = "<<e.tagName()<<endl;
+//		kdDebug()<<"PLOT TEXT = "<<e.text()<<endl;
+
+		if(e.tagName() == "Background")
+			bgcolor = QColor(e.text());
+		else if(e.tagName() == "GraphBackground")
+			gbgcolor = QColor(e.text());
+		else if(e.tagName() == "Transparent")
+			transparent = (bool) e.text().toInt();
+		else if(e.tagName() == "ClipOffset")
+			clipoffset = e.text().toInt();
+
+		else if(e.tagName() == "XActRange")
+			actrange[0].setRange(e.attribute("min").toDouble(),e.attribute("max").toDouble());
+		else if(e.tagName() == "YActRange")
+			actrange[1].setRange(e.attribute("min").toDouble(),e.attribute("max").toDouble());
+		else if(e.tagName() == "ZActRange")
+			actrange[2].setRange(e.attribute("min").toDouble(),e.attribute("max").toDouble());
+
+		else if(e.tagName() == "Baseline") {
+			xbaseline_enabled = (bool) e.attribute("x_enabled").toInt();
+			baseline_enabled = (bool) e.attribute("y_enabled").toInt();
+			xbaseline = e.attribute("x").toDouble();
+			baseline = e.attribute("y").toDouble();
+		}
+		else if(e.tagName() == "Region") {
+			region_enabled = (bool) e.attribute("enabled").toInt();
+			region->setRange(e.attribute("min").toDouble(),e.attribute("max").toDouble());
+		}
+		else if(e.tagName() == "Position")
+			position.setPoint(e.attribute("x").toDouble(),e.attribute("y").toDouble());
+		else if(e.tagName() == "Size")
+			size.setPoint(e.attribute("x").toDouble(),e.attribute("y").toDouble());
+		else if(e.tagName() == "PlotArea") {
+			p1.setPoint(e.attribute("xmin").toDouble(),e.attribute("ymin").toDouble());
+			p2.setPoint(e.attribute("xmax").toDouble(),e.attribute("ymax").toDouble());
+		}
+		else if(e.tagName() == "AspectRatio")
+			aspect_enabled = (bool) e.text().toInt();
+		else if(e.tagName() == "Marks") {
+			marks_enabled = (bool) e.attribute("enabled").toInt();
+			markx->setRange(e.attribute("xmin").toDouble(),e.attribute("ymin").toDouble());
+			marky->setRange(e.attribute("xmax").toDouble(),e.attribute("ymax").toDouble());
+		}
+		else if(e.tagName() == "Fill") {
+			fill_enabled = (bool) e.attribute("enabled").toInt();
+			filltype = e.attribute("type").toInt();
+			fillg1 = e.attribute("firstgraph").toInt();
+			fillg2 = e.attribute("secondgraph").toInt();
+			fillbrush = QBrush(e.attribute("color"),(Qt::BrushStyle) e.attribute("brush").toInt());
+		}
+		else if(e.tagName() == "Label")
+			title->openXML(e.firstChild());		
+		else if(e.tagName() == "Legend")
+			legend.openXML(e.firstChild());
+		else if(e.tagName() == "Graph") {
+			switch(e.attribute("type").toInt()) {
+			case GRAPH2D: {
+				Graph2D *g = new Graph2D();
+				g->openXML(e.firstChild());
+				worksheet->addGraph2D(g,type);
+				}; break;
+			case GRAPH3D: {
+				Graph3D *g = new Graph3D();
+				g->openXML(e.firstChild());
+				worksheet->addGraph3D(g,type);
+				}; break;
+			case GRAPH4D: {
+				Graph4D *g = new Graph4D();
+				g->openXML(e.firstChild());
+				worksheet->addGraph4D(g);
+				}; break;
+			case GRAPHM: {
+				GraphM *g = new GraphM();
+				g->openXML(e.firstChild());
+				worksheet->addGraphM(g,type);
+				}; break;
+			case GRAPHIMAGE: {
+				GraphIMAGE *g = new GraphIMAGE();
+				g->openXML(e.firstChild());
+				worksheet->addGraphIMAGE(g);
+				}; break;
+			case GRAPHL: {
+				GraphL *g = new GraphL();
+				g->openXML(e.firstChild());
+				worksheet->addGraphL(g,type);
+				}; break;
+			}
+		}
+		
+		// plot type stuff
+		openXML(e);
+
+		node = node.nextSibling();
+	}
+}
+
 void Plot::open(QTextStream *t, int version) {
 	kdDebug()<<"Plot::open()"<<endl;
 
@@ -378,6 +952,12 @@ void Plot::open(QTextStream *t, int version) {
 			*t>>x>>y;
 			p2.setPoint(x,y);
 			
+			if(version>22) {
+				int e;
+				*t>>e;
+				aspect_enabled=e;
+			}
+
 			if(version>19) {
 				int e;
 				double xmin, xmax, ymin,ymax;
@@ -388,6 +968,18 @@ void Plot::open(QTextStream *t, int version) {
 				marky->setMin(ymin);
 				marky->setMax(ymax);
 			}
+			if(version > 23) {
+				QString c;
+				int v;
+
+				*t>>v>>filltype;
+				fill_enabled = bool(v);
+				*t>>fillg1>>fillg2;
+					
+				*t>>c>>v;
+				fillbrush = QBrush(c,(Qt::BrushStyle) v);
+			}
+
 		}
 		else {
 			position.setPoint(0,0);
@@ -417,9 +1009,15 @@ void Plot::open(QTextStream *t, int version) {
 		*t>>de>>ce;
 		plot->enableDensity(de);
 		plot->enableContour(ce);
-		*t>>n>>p;
+		if(version>22)
+			*t>>n;
+		else {	
+			*t>>n>>p;
+#ifdef HAVE_GL
+			plot->setColorVector(convertOldColormap(p));
+#endif
+		}
 		plot->setNumber(n);
-		plot->setPalette(p);
 		if (version>12) {
 			*t>>tmp;
 			plot->setContourColor(QColor(tmp));
@@ -430,6 +1028,29 @@ void Plot::open(QTextStream *t, int version) {
 			plot->setRelative(p);
 			plot->setThreshold(tmp.toDouble());
 		}
+		if(version > 22) {
+#ifdef HAVE_GL
+			//read colorvector
+			Qwt3D::ColorVector cv;
+			cv.clear();
+			Qwt3D::RGBA rgb;
+#endif
+
+			int size;
+			*t>>size;
+			for(int i=0;i<size;i++) {
+#ifdef HAVE_GL
+				*t >> rgb.r >> rgb.g >> rgb.b>>rgb.a;
+				cv.push_back(rgb);
+#else
+				int r,g,b;	// over read values
+				*t>>r>>g>>b;
+#endif
+			}
+#ifdef HAVE_GL
+			plot->setColorVector(cv);
+#endif
+		}
 	}
 	else if (type == PQWT3D && version > 17) {
 		PlotQWT3D *plot = (PlotQWT3D *)this;
@@ -456,8 +1077,8 @@ void Plot::open(QTextStream *t, int version) {
 		if(version > 20) {
 			plot->disableMouse(mouse);
 			for(int i=0;i<12;i++) {
-				plot->setMajorTicLength(i,maj[i]);
-				plot->setMinorTicLength(i,min[i]);
+				plot->getAxis(i)->setMajorTickLength(maj[i]);
+				plot->getAxis(i)->setMinorTickLength(min[i]);
 			}
 			plot->setDataResolution(resolution);
 		}
@@ -522,6 +1143,11 @@ void Plot::open(QTextStream *t, int version) {
 			g->open(t,version,progress);
 			worksheet->addGraphIMAGE(g);
 		}
+		else if (gstring == "GraphL") {
+			GraphL *g = new GraphL();
+			g->open(t,version,progress);
+			worksheet->addGraphL(g,type);
+		}
 		*t>>gstring>>n;
 		kdDebug()<<" GRAPH LINE :  "<<gstring<<' '<<n<<endl;
 	}
@@ -529,50 +1155,55 @@ void Plot::open(QTextStream *t, int version) {
 }
 
 // called from Plot<Type> with all axes
-void Plot::saveAxis(QTextStream *t,Axis *axis,int gridenabled, int borderenabled, int minorgridenabled) {
+void Plot::saveAxis(QTextStream *t, Axis *axis) {
 	kdDebug()<<"Plot::saveAxis()"<<endl;
 	*t<<axis->Scale()<<endl;
 
 	//Grid & Border
-	*t<<gridenabled<<' '<<borderenabled<<' '<<axis->enabled()<<endl;
-	*t<<minorgridenabled<<endl;
+	*t<<axis->MajorGridEnabled()<<' '<<axis->BorderEnabled()<<' '<<axis->Enabled()<<endl;
+	*t<<axis->MinorGridEnabled()<<endl;
 	*t<<axis->majorGridColor().name()<<endl;
 	*t<<axis->minorGridColor().name()<<endl;
 	*t<<(int)axis->MajorGridType()<<' '<<(int)axis->MinorGridType()<<' '<<axis->borderWidth()<<endl;
-	*t<<axis->majorGridWidth()<<' '<<axis->minorGridWidth()<<' '<<axis->majorTicsWidth()<<' '<<axis->minorTicsWidth()<<endl;
+	*t<<axis->majorGridWidth()<<' '<<axis->minorGridWidth()<<' '<<axis->majorTickWidth()<<' '<<axis->minorTickWidth()<<endl;
 
-	axis->label()->save(t);
+	axis->getLabel()->save(t);
 
-	*t<<axis->TicsPos()<<endl;
+	*t<<axis->Position()<<endl;
+
+	*t<<axis->TickPos()<<endl;
 	*t<<axis->Scaling()<<' '<<axis->Shift()<<endl;
-	*t<<axis->TicsLabelPrefix()<<endl;
-	*t<<axis->TicsLabelSuffix()<<endl;
-	*t<<axis->TicsLabelRotation()<<endl;
-	*t<<axis->TicsLabelGap()<<endl;
+	*t<<axis->tickType()<<endl;
+	*t<<axis->tickLabelEnabled()<<endl;
+	*t<<axis->TickLabelPrefix()<<endl;
+	*t<<axis->TickLabelSuffix()<<endl;
+	*t<<axis->TickLabelRotation()<<endl;
+	*t<<axis->TickLabelPosition()<<endl;
 
-	//Tics
-	QFont tf = axis->TicsFont();
+	//Ticks
+	QFont tf = axis->TickLabelFont();
 	*t<<tf.family()<<endl;
 	*t<<tf.pointSize()<<' '<<tf.weight()<<' '<<tf.italic()<<endl;
-	*t<<axis->MajorTics()<<' '<<axis->MinorTics()<<endl;
-	*t<<axis->MajorTicsEnabled()<<' '<<axis->MinorTicsEnabled()<<endl;
-	*t<<axis->TicsColor().name()<<endl;
-	*t<<axis->TicsLabelColor().name()<<endl;
+	*t<<axis->MajorTicks()<<' '<<axis->MinorTicks()<<endl;
+	*t<<axis->MajorTicksEnabled()<<' '<<axis->MinorTicksEnabled()<<endl;
+	*t<<axis->TickColor().name()<<endl;
+	*t<<axis->TickLabelColor().name()<<endl;
 	*t<<axis->BorderColor().name()<<endl;
-	*t<<axis->TicsLabelFormat()<<endl;
-	*t<<axis->TicsLabelPrecision()<<endl;
+	*t<<axis->TickLabelFormat()<<endl;
+	*t<<axis->TickLabelPrecision()<<endl;
 	*t<<axis->DateTimeFormat()<<endl;
 }
 
 // called from Plot<Type> with all axes
-void Plot::openAxis(QTextStream *t,int version,Axis *axis,bool *gridenabled,bool *borderenabled, bool *minorgridenabled) {
+void Plot::openAxis(QTextStream *t,int version,Axis *axis) {
 	kdDebug()<<"Plot::openAxis()"<<endl;
-	QString family, color;
-	int pointsize, weight, italic;
+	QString family, color, bgcolor;
+	int pointsize, weight, italic, trans;
 	double x,y;
 
 	QString l;
-	int major,minor;
+	double major;
+	int minor;
 	int majore,minore;
 	int ge,be,e;
 	int boxed=0;
@@ -583,20 +1214,19 @@ void Plot::openAxis(QTextStream *t,int version,Axis *axis,bool *gridenabled,bool
 	if(version > 7)
 		*t>>s;
 	axis->setScale((TScale)s);
+	kdDebug()<<"SCALE "<<s<<endl;
 
 	*t>>ge>>be>>e;
-	*gridenabled=ge;
-	*borderenabled=be;
+	axis->enableBorder(be);
+	axis->enableMajorGrid(ge);
+	kdDebug()<<"BORDER/MAJORGRID "<<be<<' '<<ge<<endl;
 	
-	kdDebug()<<"GRID  enabled : "<<*gridenabled<<endl;
-	kdDebug()<<"BORDER enabled : "<<*borderenabled<<endl;
-
 	if(version > 14) {
 		*t>>ge;
-		*minorgridenabled=ge;
+		axis->enableMinorGrid(ge);
 	}
 
-	axis->enable(e);
+	axis->Enable(e);
 	if (version > 3) {
 		*t>>color;
 		axis->setMajorGridColor(QColor(color));
@@ -613,8 +1243,8 @@ void Plot::openAxis(QTextStream *t,int version,Axis *axis,bool *gridenabled,bool
 			*t>>e1>>e2>>e3>>e4;
 			axis->setMajorGridWidth(e1);
 			axis->setMinorGridWidth(e2);
-			axis->setMajorTicsWidth(e3);
-			axis->setMinorTicsWidth(e4);
+			axis->setMajorTickWidth(e3);
+			axis->setMinorTickWidth(e4);
 			kdDebug()<<"GRID WIDTHs : "<<e1<<e2<<e3<<e4<<endl;
 		}
 	}
@@ -626,7 +1256,7 @@ void Plot::openAxis(QTextStream *t,int version,Axis *axis,bool *gridenabled,bool
 
 	kdDebug()<<"Label = "<<l<<endl;
 
-	// Label::save() partly duplicated here !!!
+	// Label::open() partly duplicated here !!!
 	if (version > 6) {	// new order
 		family=t->readLine();
 		*t>>pointsize>>weight>>italic;
@@ -638,11 +1268,15 @@ void Plot::openAxis(QTextStream *t,int version,Axis *axis,bool *gridenabled,bool
 			*t>>rotation;
 		if(version > 20)
 			*t>>is_texlabel;
+		if (version > 21) {
+			*t>>bgcolor;
+			*t>>trans;
+		}
 	}
 	else if (version > 3) {
 		*t>>color;
 		*t>>x>>y;
-		axis->label()->setPosition(x,y);
+		axis->getLabel()->setPosition(x,y);
 
 		t->readLine();
 		family=t->readLine();
@@ -659,29 +1293,47 @@ void Plot::openAxis(QTextStream *t,int version,Axis *axis,bool *gridenabled,bool
 	label->setBoxed(boxed);
 	label->setRotation(rotation);
 	label->setTeXLabel(is_texlabel);
+	label->setBackgroundColor(bgcolor);
+	label->setTransparent(trans);
 	axis->setLabel(label);
 
+	if (version > 22) {
+		int pos;
+		*t>>pos;
+		axis->setPosition(pos);
+	}
+
 	if (version > 10) {
 		*t>>x;
-		axis->setTicsPos((int)x);
+		axis->setTickPos((int)x);
 		kdDebug()<<"	TIC POSITION = "<<x<<endl;
 		*t>>x>>y;
 		axis->setScaling(x);
 		axis->setShift(y);
 		kdDebug()<<"	SCALING/SHIFT = "<<x<<' '<<y<<endl;
+		if(version > 22) {
+			int e;
+			*t>>e;
+			axis->setTickType(e);
+		}
+		if(version > 21) {
+			int e;
+			*t>>e;
+			axis->enableTickLabel(e);
+		}
 		t->readLine();
 		QString tmpprefix=t->readLine();
-		axis->setTicsLabelPrefix(tmpprefix);
+		axis->setTickLabelPrefix(tmpprefix);
 		kdDebug()<<"Prefix = "<<tmpprefix<<endl;
 		QString tmpsuffix=t->readLine();
-		axis->setTicsLabelSuffix(tmpsuffix);
+		axis->setTickLabelSuffix(tmpsuffix);
 		kdDebug()<<"Suffix = "<<tmpsuffix<<endl;
 		if(version > 14) {
 			*t>>x;
-			axis->setTicsLabelRotation(x);
+			axis->setTickLabelRotation(x);
 			if(version > 16) {
 				*t>>x;
-				axis->setTicsLabelGap((int)x);
+				axis->setTickLabelPosition((int)x);
 			}
 			t->readLine();
 		}
@@ -693,31 +1345,31 @@ void Plot::openAxis(QTextStream *t,int version,Axis *axis,bool *gridenabled,bool
 			t->readLine();
 		family=t->readLine();
 		*t>>pointsize>>weight>>italic;
-		axis->setTicsFont( QFont(family,pointsize,weight,italic));
+		axis->setTickLabelFont( QFont(family,pointsize,weight,italic));
 	}
 
-	kdDebug()<<"axis (Tics) "<<family<<pointsize<<endl;
+	kdDebug()<<"axis (Ticks) "<<family<<pointsize<<endl;
 
 	*t>>major>>minor;
-	axis->setMajorTics(major);
-	axis->setMinorTics(minor);
+	axis->setMajorTicks(major);
+	axis->setMinorTicks(minor);
 	*t>> majore>>minore;
-	axis->enableMajorTics(majore);
-	axis->enableMinorTics(minore);
+	axis->enableMajorTicks(majore);
+	axis->enableMinorTicks(minore);
 	if (version > 3) {
 		*t>>color;
-		axis->setTicsColor(QColor(color));
+		axis->setTickColor(QColor(color));
 		*t>>color;
-		axis->setTicsLabelColor(QColor(color));
+		axis->setTickLabelColor(QColor(color));
 		*t>>color;
 		axis->setBorderColor(QColor(color));
 	}
 	if (version > 4) {
 		int tmp;
 		*t>>tmp;
-		axis->setTicsLabelFormat((TFormat)tmp);
+		axis->setTickLabelFormat((TFormat)tmp);
 		*t>>tmp;
-		axis->setTicsLabelPrecision(tmp);
+		axis->setTickLabelPrecision(tmp);
 	}
 	if(version >11) {
 		QString tmp;
@@ -1312,8 +1964,8 @@ Point Plot::dataValue(double x) {
 }
 	
 //! calcuate tic number for auto tics
-int Plot::autoTics(double min, double max) {
-//	kdDebug()<<"Plot::autoTics : min/max = "<<min<<' '<<max<<endl;
+int Plot::autoTicks(double min, double max) {
+//	kdDebug()<<"Plot::autoTicks : min/max = "<<min<<' '<<max<<endl;
 	if(max-min==0)
 		return -1;
 	int floorvalue = (int) floor(log10(max-min));
