@@ -9,6 +9,10 @@
 #include "Label.h"
 #include "Axis.h"
 
+#ifdef HAVE_GL
+#include "qwt3d_surfaceplot.h"
+#endif
+
 class Legend;
 
 class Plot {
@@ -18,11 +22,15 @@ public:
 	GraphList *getGraphList() { return graphlist; }
 	void clear() {graphlist->clear();}
 	void save(QTextStream *t);
-	virtual void saveAxes(QTextStream *t) = 0;
-	void saveAxis(QTextStream *t,Axis *axis,int gridenabled, int borderenabled, int minorgridenabled);
 	void open(QTextStream *t, int version);
-	void openAxis(QTextStream *t,int version, Axis *axis,bool *gridenabled,bool *borderenabled, bool *minorgridenabled);
+	QDomElement savePlotXML(QDomDocument doc);
+	void openPlotXML(QDomNode node);
+	virtual void saveXML(QDomDocument doc, QDomElement plottag) = 0;
+	virtual void openXML(QDomElement e) = 0;
+	virtual void saveAxes(QTextStream *t) = 0;
 	virtual void openAxes(QTextStream *t, int version) = 0;
+	void saveAxis(QTextStream *t,Axis *axis);
+	void openAxis(QTextStream *t,int version, Axis *axis);
 
 	QString TicLabel(int atlf, int prec, QString dtf, double value);
 	double TicLabelValue(int atlf, QString string);
@@ -48,36 +56,46 @@ public:
 	double RegionMax() {return region->rMax();}
 	LRange *Region() { return region; }
 	bool regionEnabled() { return region_enabled; }
-	void setRegionEnabled(bool e=true) { region_enabled = e; }
+	void enableRegion(bool e=true) { region_enabled = e; }
+	void setRegionEnabled(bool e=true) { enableRegion(e); }
 	void setTransparent(bool t) { transparent = t; }
 	bool Transparent() { return transparent; }
 	void setClipOffset(int c) { clipoffset=c;}
 	int ClipOffset() { return clipoffset;}
 
-	virtual void enableGrid(int index,bool b=true) = 0;
-	virtual bool gridEnabled(int index) = 0;
-	virtual void enableBorder(int index,bool b=true) = 0;
-	virtual bool borderEnabled(int index) = 0;
-	bool baselineEnabled() { return baseline_enabled; }
-	void setBaselineEnabled(bool e=true) { baseline_enabled = e; }
+	bool BaselineEnabled() { return baseline_enabled; }
+	void enableBaseline(bool e=true) { baseline_enabled = e; }
+	void setBaselineEnabled(bool e=true) { enableBaseline(e); }
 	double Baseline() { return baseline; }
 	void setBaseline(double b) { baseline = b; }
 	double XBaseline() { return xbaseline; }
 	void setXBaseline(double b) { xbaseline = b; }
-	bool xbaselineEnabled() { return xbaseline_enabled; }
-	void setXBaselineEnabled(bool e=true) { xbaseline_enabled = e; }
+	bool XBaselineEnabled() { return xbaseline_enabled; }
+	void enableXBaseline(bool e=true) { baseline_enabled = e; }
+	void setXBaselineEnabled(bool e=true) { enableXBaseline(e); }
 
-	bool marksEnabled() { return marks_enabled; }
-	void setMarksEnabled(bool m=true) { marks_enabled=m; }
+	bool marksEnabled() { return marks_enabled; }			// marker
+	void enableMarks(bool m=true) { marks_enabled=m; }
+	void setMarksEnabled(bool m=true) { enableMarks(m); }
 	LRange *markX() { return markx; }
 	void setMarkX(LRange *l) { markx=l; }
 	LRange *markY() { return marky; }
 	void setMarkY(LRange *l) { marky=l; }
+	void setFill(bool f=true) { fill_enabled=f; }				// fill
+	bool Fill() { return fill_enabled; }		
+	void setFillType(int t) { filltype=t; }
+	int  FillType() { return filltype; }
+	void setFillG1(int f) { fillg1=f; }
+	int FillG1() { return fillg1; }
+	void setFillG2(int f) { fillg2=f; }
+	int FillG2() { return fillg2; }
+	void setFillBrush(QBrush b) { fillbrush=b; }
+	QBrush FillBrush() { return fillbrush; }
 
 	virtual void draw(QPainter *p, int w, int h) = 0;
+	void sortPoints(QPointArray pa, int s, int e);
 	void drawStyle(QPainter *p, Style *s, Symbol *symbol, QPointArray pa, int xmin, int xmax, int ymin, int ymax);
 	void drawErrorBar(QPainter *p, QPointArray pa, QPointArray hpa, QPointArray vpa);
-	virtual void setBorder(int,bool) = 0;
 	bool inside(double x, double y) {
 		if(x>position.X() && x<position.X()+size.X() && y>position.Y() && y<position.Y()+size.Y())
 			return true;
@@ -139,6 +157,8 @@ public:
 	void setSize(Point s) { size = s; }
 	void setSize(double x, double y) { size = Point(x,y); }
 	Point Size() { return size; }
+	void enableAspectRatio(bool a=true) { aspect_enabled=a; }
+	bool AspectRatioEnabled() { return aspect_enabled; }
 	QColor Background() { return bgcolor; }
 	void setBackground(QColor c) { bgcolor = c; }
 	void setBackground(QString c) { bgcolor = QColor(c); }
@@ -148,6 +168,7 @@ public:
 	void autoScaleX();
 	void autoScaleY();
 	void autoScaleZ();
+	void autoScaleAll() { autoScaleX(); autoScaleY(); autoScaleZ(); }
 	void setXRange(double x1, double x2) {actrange[0].setMin(x1); actrange[0].setMax(x2); }
 	void setYRange(double y1, double y2) {actrange[1].setMin(y1); actrange[1].setMax(y2); }
 	void setZRange(double z1, double z2) {actrange[2].setMin(z1); actrange[2].setMax(z2); }
@@ -156,7 +177,11 @@ public:
 	Point P2() { return p2;}
 	void setP1(Point p) { p1=p;}
 	void setP2(Point p) { p2=p;}
-
+	void setLeftPanel() { p1.setX(0.0); }
+	void setRightPanel() { p2.setX(1.0); }
+	void setTopPanel() { p1.setY(0.0); }
+	void setBottomPanel() { p2.setY(1.0); }
+	
 	void setXMin(int xmin,int X) { p1.setPoint((xmin/(double)X-position.X())/size.X(),p1.Y()); }
 	void setXMax(int xmax,int X) { p2.setPoint((xmax/(double)X-position.X())/size.X(),p2.Y()); }
 	void setYMin(int ymin,int Y) { p1.setPoint(p1.X(),(ymin/(double)Y-position.Y())/size.Y()); }
@@ -177,11 +202,16 @@ public:
 
 	Point dataValue(double x);
 protected:
-	int autoTics(double min, double max);	// calcuate tic number for auto tics
+	int autoTicks(double min, double max);	// calcuate tick number for auto ticks
+	void readAxisSettings(Axis *a, int type, int item=0);	// read default settings for axis
+#ifdef HAVE_GL
+	Qwt3D::ColorVector convertOldColormap(int index);
+#endif
 	Worksheet *worksheet;			// parent worksheet
 	PType type;				// type of the plot
 	GraphList *graphlist;			// list of graphs
 	Point position, size;				// position and size (0..1)
+	bool aspect_enabled;			// plot in aspect ratio
 	Label *title;					// Title
 	Legend legend;				// Legend
 	QColor bgcolor, gbgcolor;		// background & graph background color
@@ -198,6 +228,10 @@ protected:
 	int clipoffset;					// offset for clipping area drawing (Symbols->full drawn, line section->limited)
 	bool marks_enabled;
 	LRange *markx, *marky;			// marker
+	bool fill_enabled;				// fill between curve fillg1 and fillg2 ?
+	int filltype;					// 0-all, 1-higher, 2-lower, 3-region
+	int fillg1, fillg2;
+	QBrush fillbrush;				// use brush for fill
 };
 
 #ifndef HAVE_LOG2
