@@ -24,8 +24,107 @@ QStringList Plot2DSimple::Info() {
 	return s;
 }
 
+// fill between graph fillg1 and fillg2
+void Plot2DSimple::drawFill(QPainter *p,int w, int h) {
+	if(fillg1 > (int) graphlist->Number() || fillg2 > (int) graphlist->Number() )
+		return;
+
+	const int xmin = (int)(w*(size.X()*p1.X()+position.X()));
+	const int xmax = (int)(w*(size.X()*p2.X()+position.X()));
+	const int ymin = (int)(h*(size.Y()*p1.Y()+position.Y()));
+	const int ymax = (int)(h*(size.Y()*p2.Y()+position.Y()));
+	// clipping rect with some space (clipoffset)
+	p->setClipRect(xmin-clipoffset,ymin-clipoffset,xmax-xmin+2*clipoffset,ymax-ymin+2*clipoffset);
+
+	GRAPHType s1 = graphlist->getStruct(fillg1);
+	GRAPHType s2 = graphlist->getStruct(fillg2);
+
+	if (s1 == GRAPH2D && s2 ==  GRAPH2D) {
+		Graph2D *g1 = graphlist->getGraph2D(fillg1);
+		Graph2D *g2 = graphlist->getGraph2D(fillg2);
+		QPointArray pa(g1->Number()+g2->Number());
+
+		if(g1->Number() != g2->Number())
+			filltype=0;
+
+		int ptnr=0;
+		for(int i=0;i<g1->Number();i++) {
+			double x=xmin,y=ymax;
+			calculateXY(g1->Data()[i],&x,&y,w,h);
+			if(x==xmin) x=xmin+1;	// don't overdraw axes
+			if(y==ymin) y=ymin+1;	// don't overdraw axes
+			if(filltype==1) {
+				if(g1->Data()[i].Y()<g2->Data()[i].Y())
+					continue;
+			}
+			else if(filltype==2){
+				if(g1->Data()[i].Y()>g2->Data()[i].Y())
+					continue;
+			}
+			else if(filltype==3){
+				if(g1->Data()[i].X()<region->rMin() || g1->Data()[i].X()>region->rMax())
+					continue;
+			}
+			pa[ptnr++] = QPoint((int)x,(int)y);
+		}
+		for(int i=g2->Number()-1;i>=0;i--) {
+			double x=xmin,y=ymax;
+			calculateXY(g2->Data()[i],&x,&y,w,h);
+			if(x==xmin) x=xmin+1;	// don't overdraw axes
+			if(y==ymin) y=ymin+1;	// don't overdraw axes
+			if(filltype==1) {
+				if(g1->Data()[i].Y()<g2->Data()[i].Y())
+					continue;
+			}
+			else if(filltype==2) {
+				if(g1->Data()[i].Y()>g2->Data()[i].Y())
+					continue;
+			}
+			else if(filltype==3){
+				if(g2->Data()[i].X()<region->rMin() || g2->Data()[i].X()>region->rMax())
+					continue;
+			}
+
+			pa[ptnr++] = QPoint((int)x,(int)y);
+		}
+
+		pa.resize(ptnr);
+		p->setPen(Qt::NoPen);
+		p->setBrush(fillbrush);
+		p->drawPolygon(pa);
+	}
+}
+
+void Plot2DSimple::calculateXY(Point d,double *x, double *y, int w, int h) {
+	const int xmin = (int)(w*(size.X()*p1.X()+position.X()));
+	const int xmax = (int)(w*(size.X()*p2.X()+position.X()));
+	const int ymin = (int)(h*(size.Y()*p1.Y()+position.Y()));
+	const int ymax = (int)(h*(size.Y()*p2.Y()+position.Y()));
+	double minx = actrange[0].rMin();
+	double maxx = actrange[0].rMax();
+	double miny = actrange[1].rMin();
+	double maxy = actrange[1].rMax();
+
+	switch(axis[0].Scale()) {
+		case LINEAR:	*x += (d.X() - minx) * (xmax-xmin)/(maxx-minx); break;
+		case LOG10:	*x += (log10(d.X()/minx)) * (xmax-xmin)/(log10(maxx/minx)); break;
+		case LOG2:	*x += (log2(d.X()/minx)) * (xmax-xmin)/(log2(maxx/minx)); break;
+		case LN:	*x += (log(d.X()/minx)) * (xmax-xmin)/(log(maxx/minx)); break;
+		case SQRT:	*x += (sqrt(d.X())-sqrt(minx)) * (xmax-xmin)/(sqrt(maxx)-sqrt(minx)); break;
+		case SX2:	*x += ((d.X()*d.X())-(minx*minx))*(xmax-xmin)/((maxx*maxx)-(minx*minx)); break;
+	}
+	switch(axis[1].Scale()) {
+		case LINEAR:	*y -= (d.Y() - miny) * (ymax-ymin)/(maxy-miny); break;
+		case LOG10:	*y -= (log10(d.Y()/miny)) * (ymax-ymin)/(log10(maxy/miny)); break;
+		case LOG2:	*y -= (log2(d.Y()/miny)) * (ymax-ymin)/(log2(maxy/miny)); break;
+		case LN:	*y -= (log(d.Y()/miny)) * (ymax-ymin)/(log(maxy/miny)); break;
+		case SQRT:	*y -= (sqrt(d.Y())-sqrt(miny)) * (ymax-ymin)/(sqrt(maxy)-sqrt(miny)); break;
+		case SX2:	*y -= ((d.Y()*d.Y())-(miny*miny)) * (ymax-ymin)/((maxy*maxy)-(miny*miny)); break;
+	}
+}
+
 void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
-	//kdDebug()<<" Plot2DSimple::drawCurves"<<endl;
+	kdDebug()<<" Plot2DSimple::drawCurves"<<endl;
 	const int xmin = (int)(w*(size.X()*p1.X()+position.X()));
 	const int xmax = (int)(w*(size.X()*p2.X()+position.X()));
 	const int ymin = (int)(h*(size.Y()*p1.Y()+position.Y()));
@@ -34,6 +133,11 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 
 	// clipping rect with some space (clipoffset)
 	p->setClipRect(xmin-clipoffset,ymin-clipoffset,xmax-xmin+2*clipoffset,ymax-ymin+2*clipoffset);
+			
+	double minx = actrange[0].rMin();
+	double maxx = actrange[0].rMax();
+	double miny = actrange[1].rMin();
+	double maxy = actrange[1].rMax();
 	
 	for (unsigned int i=0; i < graphlist->Number() ; i++) {
 		GRAPHType s = graphlist->getStruct(i);
@@ -45,7 +149,7 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 
 		if (s == GRAPH2D) {
 			Graph2D *g = graphlist->getGraph2D(i);
-			//kdDebug()<<"GRAPH2D Name = "<<g->Name()<<endl;
+//			kdDebug()<<"GRAPH2D Label = "<<g->getLabel()->simpleTitle()<<endl;
 
 			if(g->Type() == P2D) {
 				//kdDebug()<<"Type T2D\n";
@@ -68,32 +172,13 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 						if(j%mod != 0) continue;	// speed mode
 					}
 
-					double minx = actrange[0].rMin();
-					double maxx = actrange[0].rMax();
-					double miny = actrange[1].rMin();
-					double maxy = actrange[1].rMax();
 					double x=xmin,y=ymax;
-					switch(axis[0].Scale()) {
-					case LINEAR:	x += (d[j].X() - minx) * (xmax-xmin)/(maxx-minx); break;
-					case LOG10:	x += (log10(d[j].X()/minx)) * (xmax-xmin)/(log10(maxx/minx)); break;
-					case LOG2:	x += (log2(d[j].X()/minx)) * (xmax-xmin)/(log2(maxx/minx)); break;
-					case LN:		x += (log(d[j].X()/minx)) * (xmax-xmin)/(log(maxx/minx)); break;
-					case SQRT:	x += (sqrt(d[j].X())-sqrt(minx)) * (xmax-xmin)/(sqrt(maxx)-sqrt(minx)); break;
-					case SX2:	x += ((d[j].X()*d[j].X())-(minx*minx))*(xmax-xmin)/((maxx*maxx)-(minx*minx)); break;
-					}
-					switch(axis[1].Scale()) {
-					case LINEAR:	y -= (d[j].Y() - miny) * (ymax-ymin)/(maxy-miny); break;
-					case LOG10:	y -= (log10(d[j].Y()/miny)) * (ymax-ymin)/(log10(maxy/miny)); break;
-					case LOG2:	y -= (log2(d[j].Y()/miny)) * (ymax-ymin)/(log2(maxy/miny)); break;
-					case LN:		y -= (log(d[j].Y()/miny)) * (ymax-ymin)/(log(maxy/miny)); break;
-					case SQRT:	y -= (sqrt(d[j].Y())-sqrt(miny)) * (ymax-ymin)/(sqrt(maxy)-sqrt(miny)); break;
-					case SX2:	y -= ((d[j].Y()*d[j].Y())-(miny*miny)) * (ymax-ymin)/((maxy*maxy)-(miny*miny)); break;
-					}
+					calculateXY(d[j],&x,&y,w,h);
 					
 					// dont draw outside border
 					// HACK : prevent drawing errors with too large coordinates
-					if(oldy>10*ymax && y>10*ymax || oldy<-1000 && y<-1000 || 
-						oldx>10*xmax && x>10*xmax || oldx<-1000 && x<-1000)
+					if(oldy > 10*ymax && y > 10*ymax || oldy < -1000 && y < -1000 || 
+						oldx > 10*xmax && x > 10*xmax || oldx < -1000 && x < -1000)
 						;
 					else
 						pa[pointindex++]=QPoint((int)x,(int)y);
@@ -103,6 +188,8 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 					oldx = x;oldy = y;
 				}
 				pa.resize(pointindex);	// resize to clear all unneeded points (from draw outside border)
+				if(g->getStyle()->PointsSortingEnabled())
+					sortPoints(pa,0,pa.size()-1);
 				drawStyle(p,g->getStyle(),g->getSymbol(),pa,xmin,xmax,ymin,ymax);
 			}
 		}
@@ -121,10 +208,6 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 			else
 				N=(g->NX())*(g->NY());
 
-			double minx = actrange[0].rMin();
-			double maxx = actrange[0].rMax();
-			double miny = actrange[1].rMin();
-			double maxy = actrange[1].rMax();
 			QPointArray pa(N), hpa(N), vpa(N);
 			int pointindex=0;
 			for(int j=0 ;j < N;j++) {
@@ -207,6 +290,8 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 				oldx = x;oldy = y;
 			}
 			pa.resize(pointindex);	// resize to clear all unneeded points (from draw outside border)
+			if(g->getStyle()->PointsSortingEnabled())
+				sortPoints(pa,0,pa.size()-1);
 			drawStyle(p,g->getStyle(),g->getSymbol(),pa,xmin,xmax,ymin,ymax);
 			p->setPen(g->getStyle()->Color());
 			drawErrorBar(p,pa,hpa,vpa);
@@ -221,10 +306,6 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 			double oldx=0, oldy=0;
 			int N=g->Number();
 			bool type = g->GType();
-			double minx = actrange[0].rMin();
-			double maxx = actrange[0].rMax();
-			double miny = actrange[1].rMin();
-			double maxy = actrange[1].rMax();
 			double xscale, yscale;
 			QPointArray pa(N), hpa(N), vpa(N);
 			int pointindex=0;
@@ -390,6 +471,8 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 				oldx = x;oldy = y;
 			}
 			pa.resize(pointindex);	// resize to clear all unneeded points (from draw outside border)
+			if(g->getStyle()->PointsSortingEnabled())
+				sortPoints(pa,0,pa.size()-1);
 			drawStyle(p,g->getStyle(),g->getSymbol(),pa,xmin,xmax,ymin,ymax);
 			p->setPen(g->getStyle()->Color());
 			drawErrorBar(p,pa,hpa,vpa);
