@@ -1,12 +1,13 @@
 //LabPlot Plot2DSurface.cc
 
+#include <math.h>
+#include <fstream>
 #include <kdebug.h>
 #include <kconfig.h>
 #include "Plot2DSurface.h"
 #include "defs.h"
 
-inline double MAX(double x,double y) {if (x>y) return x; else return y;}
-inline double MIN(double x,double y) {if (x<y) return x; else return y;}
+using namespace std;
 
 // density and contour 2D Plot class
 Plot2DSurface::Plot2DSurface(Worksheet *p)
@@ -21,7 +22,8 @@ Plot2DSurface::Plot2DSurface(Worksheet *p)
 	densityenabled=config->readBoolEntry("Density Enabled",true);
 	contourenabled=config->readBoolEntry("Contour Enabled",true);
 	number=config->readNumEntry("Contour Level",10);
-	palette=config->readNumEntry("Palette",0);
+//	palette=config->readNumEntry("Palette",0);
+	QString colorscale=config->readEntry("Colorscale",0);
 	contour_color=config->readColorEntry("Contour Color",&Qt::black);
 	colored_contour=config->readBoolEntry("Colored Contour",false);
 	mesh=config->readBoolEntry("Show Mesh",false);
@@ -32,6 +34,131 @@ Plot2DSurface::Plot2DSurface(Worksheet *p)
 	// room for legend
 	int xmax = (int)(worksheet->width()*(size.X()*p2.X()+position.X()));
 	setXMax(xmax-(int)(120*size.X()),worksheet->width());
+
+#ifdef HAVE_GL
+	cv.clear();
+	Qwt3D::RGBA rgb;
+
+	// use colorscale
+	ifstream file((const char*)colorscale.local8Bit());
+	
+	if(file) {
+		while ( file ) {
+			file >> rgb.r >> rgb.g >> rgb.b;
+			file.ignore(1000,'\n');
+			if (!file.good())
+				break;
+			else {
+				rgb.a = 1;
+				rgb.r /= 255;
+				rgb.g /= 255;
+				rgb.b /= 255;
+				cv.push_back(rgb);
+			}
+		}
+	}
+	else {
+		for(int i=0;i<255;i++) {
+			rgb.a = 1;
+			rgb.r = i/255.0;
+			rgb.g = 40.0/255.0;
+			rgb.b = 1.0-i/255.0;
+			cv.push_back(rgb);
+		}
+	}
+#endif
+}
+
+void Plot2DSurface::saveSurfaceXML(QDomDocument doc, QDomElement plottag) {
+	QDomElement tag = doc.createElement( "DensityEnabled" );
+	plottag.appendChild( tag );
+	QDomText t = doc.createTextNode( QString::number(densityenabled) );
+	tag.appendChild( t );
+	tag = doc.createElement( "ContourEnabled" );
+	plottag.appendChild( tag );
+	t = doc.createTextNode( QString::number(contourenabled) );
+	tag.appendChild( t );
+	tag = doc.createElement( "ContourColor" );
+	plottag.appendChild( tag );
+	t = doc.createTextNode( contour_color.name() );
+	tag.appendChild( t );
+	tag = doc.createElement( "ColoredContour" );
+	plottag.appendChild( tag );
+	t = doc.createTextNode( QString::number(colored_contour) );
+	tag.appendChild( t );
+	tag = doc.createElement( "Mesh" );
+	plottag.appendChild( tag );
+	t = doc.createTextNode( QString::number(mesh) );
+	tag.appendChild( t );
+	tag = doc.createElement( "Relative" );
+	plottag.appendChild( tag );
+	t = doc.createTextNode( QString::number(relative) );
+	tag.appendChild( t );
+	tag = doc.createElement( "Brush" );
+	plottag.appendChild( tag );
+	t = doc.createTextNode( QString::number(brush) );
+	tag.appendChild( t );
+	tag = doc.createElement( "Level" );
+	plottag.appendChild( tag );
+	t = doc.createTextNode( QString::number(number) );
+	tag.appendChild( t );
+	tag = doc.createElement( "Threshold" );
+	plottag.appendChild( tag );
+	t = doc.createTextNode( QString::number(threshold) );
+	tag.appendChild( t );
+
+	//color scale
+#ifdef HAVE_GL
+	QDomElement cvtag = doc.createElement( "ColorVector" );
+	plottag.appendChild( cvtag );
+	for(unsigned int i=0;i<cv.size();i++) {
+		tag = doc.createElement( "Color" );
+		tag.setAttribute("r",QString::number(cv[i].r));
+		tag.setAttribute("g",QString::number(cv[i].g));
+		tag.setAttribute("b",QString::number(cv[i].b));
+		tag.setAttribute("a",QString::number(cv[i].a));
+		cvtag.appendChild( tag );
+	}
+#endif
+}
+
+void Plot2DSurface::openSurfaceXML(QDomElement e) {
+	if(e.tagName() == "DensityEnabled")
+		densityenabled = (bool) e.text().toInt();
+	else if(e.tagName() == "ContourEnabled")
+		contourenabled = (bool) e.text().toInt();
+	else if(e.tagName() == "ContourColor")
+		contour_color = QColor(e.text());
+	else if(e.tagName() == "ColoredContoured")
+		colored_contour = (bool) e.text().toInt();
+	else if(e.tagName() == "Mesh")
+		mesh = (bool) e.text().toInt();
+	else if(e.tagName() == "Relative")
+		relative = (bool) e.text().toInt();
+	else if(e.tagName() == "Brush")
+		brush = e.text().toInt();
+	else if(e.tagName() == "Level")
+		number = e.text().toInt();
+	else if(e.tagName() == "Threshold")
+		threshold = e.text().toDouble();
+
+#ifdef HAVE_GL
+	if(e.tagName() == "ColorVector") {
+		QDomNode node = e.firstChild();
+		cv.clear();
+		Qwt3D::RGBA rgb;
+		while(!node.isNull()) {
+			QDomElement e = node.toElement();
+			rgb.r = e.attribute("r").toDouble();
+			rgb.g = e.attribute("g").toDouble();
+			rgb.b = e.attribute("b").toDouble();
+			rgb.a = e.attribute("a").toDouble();
+			// kdDebug()<<"RGBA : "<<rgb.r<<' '<<rgb.g<<' '<<rgb.b<<' '<<rgb.a<<endl;
+			cv.push_back(rgb);
+			node = node.nextSibling();
+		}
+	}
+#endif
 }
 
 QStringList Plot2DSurface::Info() {
@@ -54,17 +181,16 @@ void Plot2DSurface::drawLegend(QPainter *p, int x, int y) {
 	kdDebug()<<"Plot2DSurface::drawLegend() : x/y "<<x<<' '<<y<<endl;
 	int nr_graphs = graphlist->Number();
 
-	int j = palette;
 	if(densityenabled) {
 		for (int i=0;i<255;i++) {
 			if(legend.getOrientation()) {
 				int tmpx=x+(int)((10+i/2)*size.X());
-				p->setPen(Color(255-i,j));
+				p->setPen(Color(255-i));
 				p->drawLine(tmpx, (int)(y+30*size.Y()*nr_graphs),tmpx,(int)(y+(30+25*nr_graphs)*size.Y()));
 			}
 			else {
 				int tmpy=y+(int)((30*nr_graphs+i/2)*size.Y());
-				p->setPen(Color(255-i,j));
+				p->setPen(Color(255-i));
 				p->drawLine((int)(x+5*size.X()),tmpy,(int)(x+30*size.X()),tmpy);
 			}
 		}
@@ -77,13 +203,13 @@ void Plot2DSurface::drawLegend(QPainter *p, int x, int y) {
 		for (int i=0;i<level;i++) {
 			if(legend.getOrientation()) {
 				if (colored_contour)
-					p->setPen(Color((int)(255-i*255.0/level),j));
+					p->setPen(Color((int)(255-i*255.0/level)));
 				int tmpx = (int) (x+size.X()*(10+255/(double)(level-1)*i/2));
 				p->drawLine(tmpx,y+(int)(30*size.Y()*nr_graphs),tmpx,y+(int)((30+25*nr_graphs)*size.Y()));
 			}
 			else {
 				if (colored_contour)
-					p->setPen(Color((int)(255-i*255.0/level),j));
+					p->setPen(Color((int)(255-i*255.0/level)));
 				int tmpy = (int) (y+size.Y()*(30*nr_graphs+255/(double)(level-1)*i/2));
 				p->drawLine(x+(int)(5*size.X()),tmpy,x+(int)(30*size.X()),tmpy);
 			}
@@ -110,8 +236,8 @@ void Plot2DSurface::drawLegend(QPainter *p, int x, int y) {
 			zmax = r.rMax();
 		}
 		else {
-			zmin = - MAX(fabs(r.rMax()),fabs(r.rMin()));
-			zmax = MAX(fabs(r.rMax()),fabs(r.rMin()));
+			zmin = - fmax(fabs(r.rMax()),fabs(r.rMin()));
+			zmax = fmax(fabs(r.rMax()),fabs(r.rMin()));
 		}
 
 		// resize font for contour level in legend with the size
@@ -225,19 +351,25 @@ void Plot2DSurface::drawCurves(QPainter *p, int w, int h) {
 			a = new double[g->Number()];
 			NX = g->NX();
 			NY = g->NY();
+			kdDebug()<<"NX/NY = "<<NX<<' '<<NY<<endl;
+			kdDebug()<<"Number = "<<g->Number()<<endl;
 			r[0]= g->Range(0);
 			r[1]= g->Range(1);
 			r[2]= g->Range(2);
 
+			double dx=r[0].rMax()-r[0].rMin();
+			double dy=r[1].rMax()-r[1].rMin();
+			kdDebug()<<"	 dx/dy = "<<dx<<' '<<dy<<endl;
 			for(int i=0;i<g->Number();i++) {
-				int indexx = (int) round((double)(NX-1)*(data[i].X()-r[0].rMin())/(r[0].rMax()-r[0].rMin()));
-				int indexy = (int) round((double)(NY-1)*(data[i].Y()-r[1].rMin())/(r[1].rMax()-r[1].rMin()));
-				//kdDebug()<<"	INDEX X/Y = "<<indexx<<' '<<indexy<<endl;
-				//kdDebug()<<"	index="<<g->Number()-1-indexx+indexy*NX<<endl;
+				int indexx = (int) round((double)(NX-1)*(data[i].X()-r[0].rMin())/dx);
+				int indexy = (int) round((double)(NY-1)*(data[i].Y()-r[1].rMin())/dy);
+//				kdDebug()<<"	DATA : X/Y "<<data[i].X()<<' '<<data[i].Y()<<endl;
+//				kdDebug()<<"	INDEX X/Y = "<<indexx<<' '<<indexy<<endl;
+//				kdDebug()<<"	index="<<g->Number()-1-indexx+indexy*NX<<endl;
 				
 				int index = indexx+indexy*NX;
 				if(index >=0 &&  index<g->Number())
-					a[indexx+indexy*NX]=data[i].Z();
+					a[indexx+indexy*NX] = data[i].Z();
 				else
 					kdDebug()<<"	CONVERSION ERROR in Surface from 3D data!"<<endl;
 				// unsorted
@@ -283,18 +415,18 @@ void Plot2DSurface::drawCurves(QPainter *p, int w, int h) {
 				case LINEAR:
 					// only i = NY*(1-(maxy-r[1].rMin())/(r-rMax()-r.rMin())) ..
 					//	NY(1-(miny-r[1].rMin())/(r-rMax()-r.rMin())) needed , see scalesurface.nb
-					y = ymax-1 - (int)((maxy - rymax+i/(double)(NY)*(rymax-rymin))*(ymax-ymin)/(maxy-miny));
+					y = ymax-1 - (int)((rymin-miny+i/(double)(NY)*(rymax-rymin))*(ymax-ymin)/(maxy-miny));
 					break;
 				case LOG10:
-					y = ymax - (int)((maxy - rymax+log10((double)i+1)/log10((double)NY+1)*
+					y = ymax - (int)((rymin-miny+log10((double)i+1)/log10((double)NY+1)*
 						(rymax-rymin))*(ymax-ymin)/(maxy-miny));
 					break;
 				case LOG2:
-					y = ymax - (int)((maxy - rymax+log2((double)i+1)/log2((double)NY+1)*
+					y = ymax - (int)((rymin-miny+log2((double)i+1)/log2((double)NY+1)*
 						(rymax-rymin))*(ymax-ymin)/(maxy-miny));
 					break;
 				case LN:
-					y = ymax - (int)((maxy - rymax+log((double)i+1)/log((double)NY+1)*
+					y = ymax - (int)((rymin-miny+log((double)i+1)/log((double)NY+1)*
 						(rymax-rymin))*(ymax-ymin)/(maxy-miny));
 					break;
 				case SQRT:
@@ -317,19 +449,19 @@ void Plot2DSurface::drawCurves(QPainter *p, int w, int h) {
 					}
 					switch (axis[0].Scale()) {
 					case LINEAR:
-						x = xmin + (int)((-minx + rxmin+j/(double)(NX)*(rxmax-rxmin))
+						x = xmin + (int)((rxmin-minx+j/(double)(NX)*(rxmax-rxmin))
 							*(xmax-xmin)/(maxx-minx));
 						break;
 					case LOG10:
-						x = xmin + (int)((-minx + rxmin+log10((double)j+1)/log10((double)NX+1)*(rxmax-rxmin))*
+						x = xmin + (int)((rxmin-minx+log10((double)j+1)/log10((double)NX+1)*(rxmax-rxmin))*
 							(xmax-xmin)/(maxx-minx));
 						break;
 					case LOG2:
-						x = xmin + (int)((-minx + rxmin+log2((double)j+1)/log2((double)NX+1)*(rxmax-rxmin))*
+						x = xmin + (int)((rxmin-minx+log2((double)j+1)/log2((double)NX+1)*(rxmax-rxmin))*
 							(xmax-xmin)/(maxx-minx));
 						break;
 					case LN:
-						x = xmin + (int)((-minx + rxmin+log((double)j+1)/log((double)NX+1)*(rxmax-rxmin))*
+						x = xmin + (int)((rxmin-minx+log((double)j+1)/log((double)NX+1)*(rxmax-rxmin))*
 							(xmax-xmin)/(maxx-minx));
 						break;
 					case SQRT:
@@ -345,19 +477,25 @@ void Plot2DSurface::drawCurves(QPainter *p, int w, int h) {
 					//kdDebug()<<"	DENSITY : x = "<<x<<" y = "<<y<<" (i="<<i<<",j="<<j<<") "<<endl;
 
 					if(i>0 && j>0) {
+						// dont draw empty pixel
+						if(a[j-1+NX*(i-1)] < zmin || a[j-1+NX*(i-1)] > zmax)
+							continue;
+						
 						// value = 0 .. 255
 						// ??? : i=0,j=0 : a[-1-NX] ???
 						int value;
 						if (relative)
 							value = (int) (255.0*(a[j-1+NX*(i-1)]-zmin)/(zmax-zmin));
 						else
-							value = (int) (127.0*a[j-1+NX*(i-1)]/MAX(fabs(zmax),fabs(zmin))+127.0);
+							value = (int) (127.0*a[j-1+NX*(i-1)]/fmax(fabs(zmax),fabs(zmin))+127.0);
 
+						
 						//kdDebug()<<"	max = "<<zmax<<"/ min = "<<zmin<<endl;
 //						kdDebug()<<"	a = "<<a[j-1+NX*(i-1)]<<endl;
 //						kdDebug()<<"	color value ("<<i<<"/"<<j<<") = "<<value<<endl;
 
-						QBrush qbrush(Color(value,palette),(Qt::BrushStyle)brush);
+						QBrush qbrush(Color(value),(Qt::BrushStyle)brush);
+
 						p->setBrush(qbrush);
 						if(mesh)
 							p->setPen( Qt::black );
@@ -382,7 +520,7 @@ void Plot2DSurface::drawCurves(QPainter *p, int w, int h) {
 
 						if(xold >= xmin-1  && tmpx+xold <= xmax+1 &&
 							yold >= ymin-1 &&  tmpy+yold <= ymax+1) {
-					//	kdDebug()<<" Draw Rect ("<<xold+1<<","<<yold<<" / size ("<<tmpx<<","<<tmpy<<")"<<endl;
+//		kdDebug()<<" Draw Rect ("<<xold+1<<","<<yold<<" / size ("<<tmpx<<","<<tmpy<<")"<<endl;
 							if (a[j-1+NX*(i-1)]>= threshold)
 								p->drawRect(xold+1,yold,tmpx,tmpy);
 						}
@@ -404,21 +542,21 @@ void Plot2DSurface::drawCurves(QPainter *p, int w, int h) {
 			switch (axis[0].Scale()) {
 			case LINEAR:
 				for(int i=0;i<NX;i++)
-					x[i] = xmin + (-minx + rxmin+i/(double)(NX-1)*(rxmax-rxmin))*(xmax-xmin)/(maxx-minx);
+					x[i] = xmin + (rxmin-minx+i/(double)(NX-1)*(rxmax-rxmin))*(xmax-xmin)/(maxx-minx);
 				break;
 			case LOG10:
 				for(int i=0;i<NX;i++)
-					x[i] = xmin + (-minx + rxmin+log10((double)i+1)/log10((double)NX)*(rxmax-rxmin))*
+					x[i] = xmin + (rxmin-minx+log10((double)i+1)/log10((double)NX)*(rxmax-rxmin))*
 							(xmax-xmin)/(maxx-minx);
 				break;
 			case LOG2:
 				for(int i=0;i<NX;i++)
-					x[i] = xmin + (-minx + rxmin+log2((double)i+1)/log2((double)NX)*(rxmax-rxmin))*
+					x[i] = xmin + (rxmin-minx+log2((double)i+1)/log2((double)NX)*(rxmax-rxmin))*
 							(xmax-xmin)/(maxx-minx);
 				break;
 			case LN:
 				for(int i=0;i<NX;i++)
-					x[i] = xmin + (-minx + rxmin+log((double)i+1)/log((double)NX)*(rxmax-rxmin))*
+					x[i] = xmin + (rxmin-minx+log((double)i+1)/log((double)NX)*(rxmax-rxmin))*
 							(xmax-xmin)/(maxx-minx);
 				break;
 			case SQRT:
@@ -434,21 +572,21 @@ void Plot2DSurface::drawCurves(QPainter *p, int w, int h) {
 			switch(axis[1].Scale()) {
 			case LINEAR:
 				for(int j=0;j<NY;j++)
-					y[j] = ymax - (maxy - rymax+j/(double)(NY-1)*(rymax-rymin))*(ymax-ymin)/(maxy-miny);
+					y[j] = ymax - (rymin-miny+j/(double)(NY-1)*(rymax-rymin))*(ymax-ymin)/(maxy-miny);
 				break;
 			case LOG10:
 				for(int j=0;j<NY;j++)
-					y[j] = ymax - (maxy - rymax+log10((double)j+1)/log10((double)NY)*
+					y[j] = ymax - (rymin-miny+log10((double)j+1)/log10((double)NY)*
 						(rymax-rymin))*(ymax-ymin)/(maxy-miny);
 				break;
 			case LOG2:
 				for(int j=0;j<NY;j++)
-					y[j] = ymax - (maxy - rymax+log2((double)j+1)/log2((double)NY)*
+					y[j] = ymax - (rymin-miny+log2((double)j+1)/log2((double)NY)*
 						(rymax-rymin))*(ymax-ymin)/(maxy-miny);
 				break;
 			case LN:
 				for(int j=0;j<NY;j++)
-					y[j] = ymax - (maxy - rymax+log((double)j+1)/log((double)NY)*
+					y[j] = ymax - (rymin-miny+log((double)j+1)/log((double)NY)*
 						(rymax-rymin))*(ymax-ymin)/(maxy-miny);
 				break;
 			case SQRT:
@@ -503,8 +641,8 @@ void Plot2DSurface::drawCurves(QPainter *p, int w, int h) {
 							if (relative)
 								value = (int)((level-zmin)/(zmax-zmin)*255.0);
 							else
-								value = (int)(127.0*(level)/MAX(fabs(zmax),fabs(zmin))+127.0);
-							p->setPen(Color(value,palette));
+								value = (int)(127.0*(level)/fmax(fabs(zmax),fabs(zmin))+127.0);
+							p->setPen(Color(value));
 						}
 
 						// TODO : fill border rects to border
@@ -533,90 +671,11 @@ void Plot2DSurface::drawCurves(QPainter *p, int w, int h) {
 	}
 }
 
-QColor Plot2DSurface::Color(int value, int palette) {
-	QColor c;
-
-	// value = 0 .. 255
-	switch (palette) {
-	case 0:
-		if (value > 127)
-			c = QColor(2*(value-128),0,0);
-		else
-			c = QColor(0,0,2*(127-value));
-		break;
-	case 1:
-		if (value > 127)
-			c = QColor(0,2*(value-128),0);
-		else
-			c = QColor(0,0,2*(127-value));
-		break;
-	case 2:
-		if (value > 127)
-			c = QColor(0,0,2*(value-128));
-		else
-			c = QColor(2*(127-value),0,0);
-		break;
-	case 3:
-		if (value > 127)
-			c = QColor(0,0,2*(value-128));
-		else
-			c = QColor(0,2*(127-value),0);
-		break;
-	case 4:
-		if (value > 127)
-			c = QColor(0,2*(value-128),0);
-		else
-			c = QColor(2*(127-value),0,0);
-		break;
-	case 5:
-		c = QColor(value,0,0);
-		break;
-	case 6:
-		c = QColor(0,value,0);
-		break;
-	case 7:
-		c = QColor(0,0,value);
-		break;
-	case 8:
-		c = QColor(value,value,value);
-		break;
-	case 9:
-		c = QColor(value,value,0);
-		break;
-	case 10:
-		c = QColor(value,0,value);
-		break;
-	case 11:
-		c = QColor(0,value,value);
-		break;
-	case 12:
-		c = QColor(255-value,255,255,QColor::Hsv);
-		break;
-	case 13:
-		c = QColor(255-value,255,200,QColor::Hsv);
-		break;
-	case 14:
-		c = QColor(255-value,100,255,QColor::Hsv);
-		break;
-	case 15:
-		c = QColor(255-value,100,200,QColor::Hsv);
-		break;
-	case 16:
-		c = QColor(value,255,255,QColor::Hsv);
-		break;
-	case 17:
-			c = QColor(value,255,200,QColor::Hsv);
-		break;
-	case 18:
-			c = QColor(value,100,255,QColor::Hsv);
-		break;
-	case 19:
-			c = QColor(value,100,200,QColor::Hsv);
-		break;
-	case 20:
-		c = QColor(255-value,255-value,255-value);
-		break;
-	}
-
-	return c;
+QColor Plot2DSurface::Color(int value) {
+#ifdef HAVE_GL
+//	kdDebug()<<"r/g/b "<<255*cv[value-1].r<<' '<<255*cv[value-1].g<<' '<<255*cv[value-1].b<<endl;
+	return QColor((int) (255*cv[value-1].r),(int)(255*cv[value-1].g),(int)(255*cv[value-1].b));
+#else
+	return QColor();
+#endif
 }
