@@ -7,147 +7,201 @@
 #include <qhbox.h>
 #include <qlayout.h>
 #include <qcolordialog.h>
-#include <qbuttongroup.h>
+#include <qradiobutton.h>
 #include <klocale.h>
+#include <kconfig.h>
 #include "PlotSettingsDialog.h"
 #include "Plot2DSurface.h"
 #include "PlotQWT3D.h"
 #include "ColormapReader.h"
-
 #include "qwt3d.h"
+#include "defs.h"
 
 //! class for general plot settings
 PlotSettingsDialog::PlotSettingsDialog(MainWin *mw, const char *name)
 	: Dialog(mw, name)
 {
-	plot = p->getPlot(p->API());
-	type = plot->Type();
+	kdDebug()<<"PlotSettingsDialog()"<<endl;
 	setCaption(i18n("Plot Settings")+i18n(" : ")+QString(name));
 
+	// get type
+	p = mw->activeWorksheet();
+	if(p == 0) return;
+	plot = p->getPlot(p->API());
+	if(plot == 0) return;
+	type = plot->Type();
+
+	KConfig *config = mw->Config();
 	QTabWidget *tw;
 	QHBox *hb;
 	tw = new QTabWidget(vbox);
 	if(type != PQWT3D) {
 		QVBox *tab1 = new QVBox(tw);
 		hb = new QHBox(tab1);
+		aspect = new QCheckBox(i18n("Aspect Ratio"),hb);
+		hb = new QHBox(tab1);
 		new QLabel(i18n("Plot Position : "),hb);
-		posx = new KLineEdit(QString::number(plot->Position().X()),hb);
+		posx = new KLineEdit("",hb);
 		posx->setValidator(new QDoubleValidator(0,1,3,posx));
 		new QLabel(i18n(" , "),hb);
-		posy = new KLineEdit(QString::number(plot->Position().Y()),hb);
+		posy = new KLineEdit("",hb);
 		posy->setValidator(new QDoubleValidator(0,1,3,posy));
 		hb = new QHBox(tab1);
 		new QLabel(i18n("Plot Size : "),hb);
-		sizex = new KLineEdit(QString::number(plot->Size().X()),hb);
+		sizex = new KLineEdit("",hb);
 		sizex->setValidator(new QDoubleValidator(0,1,3,sizex));
 		new QLabel(i18n(" , "),hb);
-		sizey = new KLineEdit(QString::number(plot->Size().Y()),hb);
+		sizey = new KLineEdit("",hb);
 		sizey->setValidator(new QDoubleValidator(0,1,3,sizey));
+		hb = new QHBox(tab1);
+		new QLabel(i18n("Panel : "),hb);
+		leftpanel = new QCheckBox(i18n("Left"),hb);
+		if(config->readNumEntry("Panel",0) == 1) leftpanel->setChecked(true);
+		rightpanel = new QCheckBox(i18n("Right"),hb);
+		if(config->readNumEntry("Panel",0) == 2) rightpanel->setChecked(true);
+		toppanel = new QCheckBox(i18n("Top"),hb);
+		if(config->readNumEntry("Panel",0) == 3) toppanel->setChecked(true);
+		bottompanel = new QCheckBox(i18n("Bottom"),hb);
+		if(config->readNumEntry("Panel",0) == 4) bottompanel->setChecked(true);
 		tw->addTab(tab1,i18n("Main"));
 		
 		QVBox *tab2 = new QVBox(tw);
 		hb = new QHBox(tab2);
 		KPushButton *asx = new KPushButton(i18n("Autoscale x"),hb);
-		QObject::connect(asx,SIGNAL(clicked()),SLOT(autoscalex()));
+		QObject::connect(asx,SIGNAL(clicked()),mw,SLOT(autoScaleX()));
 		KPushButton *asy = new KPushButton(i18n("Autoscale y"),hb);
-		QObject::connect(asy,SIGNAL(clicked()),SLOT(autoscaley()));
+		QObject::connect(asy,SIGNAL(clicked()),mw,SLOT(autoScaleY()));
 		if (type == P3D) {
 			KPushButton *asz = new KPushButton(i18n("Autoscale z"),hb);
-			QObject::connect(asz,SIGNAL(clicked()),SLOT(autoscalez()));
+			QObject::connect(asz,SIGNAL(clicked()),mw,SLOT(autoScaleZ()));
 		}
-		LRange *r = plot->ActRanges();
 		hb = new QHBox(tab2);
 		new QLabel(i18n("x = "),hb);
-		xmin = new KLineEdit(QString::number(r[0].rMin()),hb);
+		xmin = new KLineEdit("",hb);
 		xmin->setValidator(new QDoubleValidator(xmin));
 		new QLabel(i18n(" .. "),hb);
-		xmax = new KLineEdit(QString::number(r[0].rMax()),hb);
+		xmax = new KLineEdit("",hb);
 		xmax->setValidator(new QDoubleValidator(xmax));
 		hb = new QHBox(tab2);
 		new QLabel(i18n("y = "),hb);
-		ymin = new KLineEdit(QString::number(r[1].rMin()),hb);
+		ymin = new KLineEdit("",hb);
 		ymin->setValidator(new QDoubleValidator(ymin));
 		new QLabel(i18n(" .. "),hb);
-		ymax = new KLineEdit(QString::number(r[1].rMax()),hb);
+		ymax = new KLineEdit("",hb);
 		ymax->setValidator(new QDoubleValidator(ymax));
 
 		if (type == P3D) {
 			hb = new QHBox(tab2);
 			new QLabel(i18n("z = "),hb);
-			zmin = new KLineEdit(QString::number(r[2].rMin()),hb);
+			zmin = new KLineEdit("",hb);
 			zmin->setValidator(new QDoubleValidator(zmin));
 			new QLabel(i18n(" .. "),hb);
-			zmax = new KLineEdit(QString::number(r[2].rMax()),hb);
+			zmax = new KLineEdit("",hb);
 			zmax->setValidator(new QDoubleValidator(zmax));
 		}
 
 		hb = new QHBox(tab2);
 		new QLabel(i18n("clipping offset : "),hb);
-		cliple = new KLineEdit(QString::number(plot->ClipOffset()),hb);
-		cliple->setValidator(new QIntValidator(cliple));
+		clipni = new KIntNumInput(0,hb);
+		clipni->setRange(0,INF,1,false);
 		tw->addTab(tab2,i18n("Ranges"));
 	}
 	
 	QVBox *tab3 = new QVBox(tw);
 	hb = new QHBox(tab3);
 	transparentcb = new QCheckBox(i18n("transparent plot"),hb);
-	transparentcb->setChecked(plot->Transparent());
 
 	hb = new QHBox(tab3);
 	new QLabel(i18n("Background Color : "),hb);
-	bgcolor = new KColorButton(plot->Background(),hb);
+	bgcolor = new KColorButton(Qt::white,hb);
 
 	hb = new QHBox(tab3);
 	new QLabel(i18n("Graph Background Color : "),hb);
-	gbgcolor = new KColorButton(plot->graphBackground(),hb);
+	gbgcolor = new KColorButton(Qt::white,hb);
 	tw->addTab(tab3,i18n("Background"));
 
 	if(type != PQWT3D) {
 		QVBox *tab4 = new QVBox(tw);
 		hb = new QHBox(tab4);
 		xbaselinecb = new QCheckBox(i18n("draw X Baseline "),hb);
-		xbaselinecb->setChecked(plot->xbaselineEnabled());
 		new QLabel(i18n("Baseline @ x = "),hb);
-		xbaselinele = new KLineEdit(QString::number(plot->XBaseline()),hb);
+		xbaselinele = new KLineEdit("",hb);
 		xbaselinele->setValidator(new QDoubleValidator(xbaselinele));
 
 		hb = new QHBox(tab4);
 		baselinecb = new QCheckBox(i18n("draw Y Baseline "),hb);
-		baselinecb->setChecked(plot->baselineEnabled());
 		new QLabel(i18n("Baseline @ y = "),hb);
-		baselinele = new KLineEdit(QString::number(plot->Baseline()),hb);
+		baselinele = new KLineEdit("",hb);
 		baselinele->setValidator(new QDoubleValidator(baselinele));
 
 		hb = new QHBox(tab4);
 		regioncb = new QCheckBox(i18n("draw Region "),hb);
-		regioncb->setChecked(plot->regionEnabled());
 		new QLabel(i18n("x = "),hb);
-		regionminle = new KLineEdit(QString::number(plot->RegionMin()),hb);
+		regionminle = new KLineEdit("",hb);
 		regionminle->setValidator(new QDoubleValidator(regionminle));
 		new QLabel(i18n(" .. "),hb);
-		regionmaxle = new KLineEdit(QString::number(plot->RegionMax()),hb);
+		regionmaxle = new KLineEdit("",hb);
 		regionmaxle->setValidator(new QDoubleValidator(regionmaxle));
 		tw->addTab(tab4,i18n("Baseline/Region"));
 	
 		QVBox *tab5 = new QVBox(tw);
 		hb = new QHBox(tab5);
 		markercb = new QCheckBox(i18n("show Marker "),hb);
-		markercb->setChecked(plot->marksEnabled());
 		hb = new QHBox(tab5);
 		new QLabel(i18n("x1 = "),hb);
-		markminxle = new KLineEdit(QString::number(plot->markX()->rMin()),hb);
-		markminxle->setValidator(new QDoubleValidator(markminxle));
+		markxminle = new KLineEdit("",hb);
+		markxminle->setValidator(new QDoubleValidator(markxminle));
 		new QLabel(i18n(" x2 = "),hb);
-		markmaxxle = new KLineEdit(QString::number(plot->markX()->rMax()),hb);
-		markmaxxle->setValidator(new QDoubleValidator(markmaxxle));
+		markxmaxle = new KLineEdit("",hb);
+		markxmaxle->setValidator(new QDoubleValidator(markxmaxle));
 		hb = new QHBox(tab5);
 		new QLabel(i18n("y1 = "),hb);
-		markminyle = new KLineEdit(QString::number(plot->markY()->rMin()),hb);
-		markminyle->setValidator(new QDoubleValidator(markminyle));
+		markyminle = new KLineEdit("",hb);
+		markyminle->setValidator(new QDoubleValidator(markyminle));
 		new QLabel(i18n(" y2 = "),hb);
-		markmaxyle = new KLineEdit(QString::number(plot->markY()->rMax()),hb);
-		markmaxyle->setValidator(new QDoubleValidator(markmaxyle));
+		markymaxle = new KLineEdit("",hb);
+		markymaxle->setValidator(new QDoubleValidator(markymaxle));
 		tw->addTab(tab5,i18n("Marker"));
+	
+		if(type == P2D) {
+			QVBox *tab6 = new QVBox(tw);
+			hb = new QHBox(tab6);
+			fillcb = new QCheckBox(i18n("enable Fill"),hb);
+
+			hbg = new QHButtonGroup(hb,0);
+			hbg->setRadioButtonExclusive(true);
+			hbg->hide();
+			QRadioButton *rb;
+			rb = new QRadioButton(i18n("all"),hb);
+			rb->setChecked(true);
+			hbg->insert(rb);
+			rb = new QRadioButton(i18n("higher"),hb);
+			hbg->insert(rb);
+			rb = new QRadioButton(i18n("lower"),hb);
+			hbg->insert(rb);
+			rb = new QRadioButton(i18n("region"),hb);
+			hbg->insert(rb);
+	
+			hb = new QHBox(tab6);
+			new QLabel(i18n("First Graph : "),hb);
+			fillg1le = new KLineEdit("",hb);
+			fillg1le->setValidator(new QIntValidator(1,1000,fillg1le));
+			new QLabel(i18n("Second Graph : "),hb);
+			fillg2le = new KLineEdit("",hb);
+			fillg2le->setValidator(new QIntValidator(1,1000,fillg2le));
+		
+			hb = new QHBox(tab6);
+			new QLabel(i18n(" Color : "),hb);
+			fillcolorcb = new KColorButton(Qt::red,hb);
+			QObject::connect(fillcolorcb,SIGNAL(changed(const QColor &)),this,SLOT(fillBrushBox()));
+			
+			hb = new QHBox(tab6);
+			new QLabel(i18n(" Brush : "),hb);
+			fillbrushcb = new KComboBox(hb);
+			fillBrushBox();
+
+			tw->addTab(tab6,i18n("Fill"));
+		}
 	}
 #ifdef HAVE_GL
 	else {
@@ -157,41 +211,36 @@ PlotSettingsDialog::PlotSettingsDialog(MainWin *mw, const char *name)
 
 		hb = new QHBox(tab4);
 		disablemousecb = new QCheckBox(i18n("disable mouse"),hb);
-		disablemousecb->setChecked(((PlotQWT3D *)plot)->mouseDisabled());
 		new QLabel(i18n(" resolution = "),hb);
-		resolutionle = new KLineEdit(QString::number(((PlotQWT3D *)plot)->Resolution()),hb);
+		resolutionle = new KLineEdit("",hb);
 		resolutionle->setValidator(new QIntValidator(1,1000,resolutionle));
 		
 		hb = new QHBox(tab4);
 		new QLabel(i18n("Aspect ration "),hb);
 		aspectcb = new KComboBox(hb);
 		while(aspectRatio[i] != 0) aspectcb->insertItem(i18n(aspectRatio[i++]));
-		aspectcb->setCurrentItem(((PlotQWT3D *) plot)->aspectRatio());
 
 		hb = new QHBox(tab4);
 		new QLabel(i18n("Plot Style : "),hb);
 		plotstyle = new KComboBox(hb);
 		i=0;
 		while(plotStyle[i] != 0) plotstyle->insertItem(i18n(plotStyle[i++]));
-		plotstyle->setCurrentItem(((PlotQWT3D *) plot)->PlotStyle());
 		
 		hb = new QHBox(tab4);
 		new QLabel(i18n("Coordinate Style : "),hb);
 		coordinatestyle = new KComboBox(hb);
 		i=0;
 		while(coordinateStyle[i] != 0) coordinatestyle->insertItem(i18n(coordinateStyle[i++]));
-		coordinatestyle->setCurrentItem(((PlotQWT3D *) plot)->CoordinateStyle());
 		
 		hb = new QHBox(tab4);
 		new QLabel(i18n("Floor Style : "),hb);
 		floorstyle = new KComboBox(hb);
 		i=0;
 		while(floorStyle[i] != 0) floorstyle->insertItem(i18n(floorStyle[i++]));
-		floorstyle->setCurrentItem(((PlotQWT3D *) plot)->FloorStyle());
 		
 		hb = new QHBox(tab4);
 		new QLabel(i18n("isolines = "),hb);
-		isolines = new KLineEdit(QString::number(((PlotQWT3D *) plot)->isolines()),hb);
+		isolines = new KLineEdit("",hb);
 		isolines->setValidator(new QIntValidator(isolines));
 		
 		hb = new QHBox(tab4);
@@ -200,76 +249,161 @@ PlotSettingsDialog::PlotSettingsDialog(MainWin *mw, const char *name)
 		tw->addTab(tab4,i18n("Style"));
 	}
 #endif
-	
+
+	kdDebug()<<"TYPE = "<<type<<endl;
 	if (type == PSURFACE) {
 		QVBox *styletab = surfaceStyle(tw,true);
 		tw->addTab(styletab,i18n("Style"));
 	}
 
+	updateDialog();
+
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
 	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	QObject::connect(save,SIGNAL(clicked()),SLOT(saveSettings()));
 
 	setMinimumWidth((int)(1.8*tw->minimumSizeHint().width()));
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
 	resize(minimumSize());
 }
 
-void PlotSettingsDialog::selectColormap() {
-	ColorMapPreview *colormap = new ColorMapPreview;
-	QFileDialog *datacolor = new QFileDialog(this);
+void PlotSettingsDialog::fillBrushBox() {
+	int brush = fillbrushcb->currentItem();
+	fillbrushcb->clear();
+	// Qt : number of different brush styles
+	int BRUSHNR=15;
+	for (int i=0;i<BRUSHNR;i++) {
+		QPainter pa;
+		QPixmap pm( 30, 30 );
+		pm.fill(Qt::white);
+		pa.begin( &pm );
 
-	QString cmdir = locate("data","LabPlot/colormaps/");
-	datacolor->setDir(cmdir);
-	datacolor->setFilter("Colormap files (*.map;*.MAP)");
-	datacolor->setContentsPreviewEnabled( true );
-	datacolor->setContentsPreview( colormap, colormap);
-	datacolor->setPreviewMode( QFileDialog::Contents );
+		Symbol symbol(SRECT,Qt::black,10,FFULL,fillcolorcb->color(),i);
+		symbol.draw(&pa,15,15);
+		pa.end();
 
-	connect(datacolor, SIGNAL(fileHighlighted(const QString&)), this, SLOT(adaptDataColors(const QString&)));
-	datacolor->show();
+		fillbrushcb->insertItem(pm);
+	}
+	fillbrushcb->setCurrentItem(brush);
 }
 
-void PlotSettingsDialog::adaptDataColors(const QString& fn) {
-#ifdef HAVE_GL
-	if (!openColorMap(fn))
-		return;
+void PlotSettingsDialog::updateDialog() { 
+	p = mw->activeWorksheet();
+	if(p == 0) return;
+	plot = p->getPlot(p->API());
+	if(plot == 0) return;
+	type = plot->Type();
 
-	Qwt3D::StandardColor *col = new Qwt3D::StandardColor((PlotQWT3D *)plot);
-	col->setColorVector(cv);
+	//TODO : read config values
 
-	((PlotQWT3D *) plot)->setColorVector(cv);
-#endif
-}
-
-bool PlotSettingsDialog::openColorMap(QString fn) {
-#ifdef HAVE_GL
-	kdDebug()<<"openColorMap("<<fn<<")"<<endl;
-	ifstream file((const char*)fn.local8Bit());
-
-	if (!file) return false;
-
-	Qwt3D::RGBA rgb;
-	cv.clear();
-
-	while ( file ) {
-		file >> rgb.r >> rgb.g >> rgb.b;
-		file.ignore(1000,'\n');
-		if (!file.good())
-			break;
-		else {
-			rgb.a = 1;
-			rgb.r /= 255;
-			rgb.g /= 255;
-			rgb.b /= 255;
-			cv.push_back(rgb);
+	if(type != PQWT3D) {
+		aspect->setChecked(plot->AspectRatioEnabled());
+		posx->setText(QString::number(plot->Position().X()));
+		posy->setText(QString::number(plot->Position().Y()));
+		sizex->setText(QString::number(plot->Size().X()));
+		sizey->setText(QString::number(plot->Size().Y()));
+		
+		LRange *r = plot->ActRanges();
+		xmin->setText(QString::number(r[0].rMin()));
+		xmax->setText(QString::number(r[0].rMax()));
+		ymin->setText(QString::number(r[1].rMin()));
+		ymax->setText(QString::number(r[1].rMax()));
+		if (type == P3D) {
+			zmin->setText(QString::number(r[2].rMin()));
+			zmax->setText(QString::number(r[2].rMax()));
+		}
+		clipni->setValue(plot->ClipOffset());
+	}
+	
+	transparentcb->setChecked(plot->Transparent());
+	bgcolor->setColor(plot->Background());
+	gbgcolor->setColor(plot->graphBackground());
+	
+	if(type != PQWT3D) {
+		xbaselinecb->setChecked(plot->XBaselineEnabled());
+		xbaselinele->setText(QString::number(plot->XBaseline()));
+		baselinecb->setChecked(plot->BaselineEnabled());
+		baselinele->setText(QString::number(plot->Baseline()));
+		regioncb->setChecked(plot->regionEnabled());
+		regionminle->setText(QString::number(plot->RegionMin()));
+		regionmaxle->setText(QString::number(plot->RegionMax()));
+		markercb->setChecked(plot->marksEnabled());
+		markxminle->setText(QString::number(plot->markX()->rMin()));
+		markxmaxle->setText(QString::number(plot->markX()->rMax()));
+		markyminle->setText(QString::number(plot->markY()->rMin()));
+		markymaxle->setText(QString::number(plot->markY()->rMax()));
+	
+		if(type == P2D) {
+			fillcb->setChecked(plot->Fill());
+			hbg->setButton(plot->FillType());
+			fillg1le->setText(QString::number(plot->FillG1()));
+			fillg2le->setText(QString::number(plot->FillG2()));
+			QBrush fillbrush = plot->FillBrush();
+			fillcolorcb->setColor(fillbrush.color());
+			fillbrushcb->setCurrentItem((int) fillbrush.style());
 		}
 	}
-
-	return true;
+#ifdef HAVE_GL
+	else {
+		disablemousecb->setChecked(((PlotQWT3D *)plot)->mouseDisabled());
+		// need to be disabled on MacOSX ???
+		resolutionle->setText(QString::number(((PlotQWT3D *)plot)->Resolution()));
+		aspectcb->setCurrentItem(((PlotQWT3D *) plot)->aspectRatio());
+		plotstyle->setCurrentItem(((PlotQWT3D *) plot)->PlotStyle());
+		coordinatestyle->setCurrentItem(((PlotQWT3D *) plot)->CoordinateStyle());
+		floorstyle->setCurrentItem(((PlotQWT3D *) plot)->FloorStyle());
+		isolines->setText(QString::number(((PlotQWT3D *) plot)->isolines()));
+	}
 #endif
 }
 
-void PlotSettingsDialog::apply_clicked() {
+void PlotSettingsDialog::saveSettings() {
+	KConfig *config = mw->Config();
+	config->setGroup( "Plot" );
+	
+	config->writeEntry("AspectRatio",aspect->isChecked());
+	config->writeEntry("Position X",posx->text());
+	config->writeEntry("Position Y",posy->text());
+	config->writeEntry("Size X",sizex->text());
+	config->writeEntry("Size Y",sizey->text());
+	int panel=0;
+	if(leftpanel->isChecked()) panel=1;
+	if(rightpanel->isChecked()) panel=2;
+	if(toppanel->isChecked()) panel=3;
+	if(bottompanel->isChecked()) panel=4;
+	config->writeEntry("Panel",panel);
+
+	config->writeEntry("ClipOffset",clipni->value());
+	config->writeEntry("Transparent",transparentcb->isChecked());
+	config->writeEntry("BackgroundColor",bgcolor->color());
+	config->writeEntry("GraphBackgroundColor",gbgcolor->color());
+	
+	config->writeEntry("XBaselineEnabled",xbaselinecb->isChecked());
+	config->writeEntry("XBaseline",xbaselinele->text().toDouble());
+	config->writeEntry("YBaselineEnabled",baselinecb->isChecked());
+	config->writeEntry("YBaseline",baselinele->text().toDouble());
+	config->writeEntry("RegionEnabled",regioncb->isChecked());
+	config->writeEntry("RegionMin",regionminle->text().toDouble());
+	config->writeEntry("RegionMax",regionmaxle->text().toDouble());
+	config->writeEntry("MarkerEnabled",markercb->isChecked());
+	config->writeEntry("MarkerXMin",markxminle->text().toDouble());
+	config->writeEntry("MarkerXMax",markxmaxle->text().toDouble());
+	config->writeEntry("MarkerYMin",markyminle->text().toDouble());
+	config->writeEntry("MarkerYMax",markymaxle->text().toDouble());
+
+	config->writeEntry("FillEnabled",fillcb->isChecked());
+#if QT_VERSION > 0x030102
+	config->writeEntry("FillType",hbg->selectedId());
+#endif
+	config->writeEntry("FillG1",fillg1le->text().toInt());
+	config->writeEntry("FillG2",fillg2le->text().toInt());
+	config->writeEntry("FillColor",fillcolorcb->color());
+	config->writeEntry("FillBrush",fillbrushcb->currentItem());
+
+}
+
+int PlotSettingsDialog::apply_clicked() {
+	kdDebug()<<"PlotSettingsDialog::apply()"<<endl;
 	plot->setBackground(bgcolor->color());
 	plot->setGraphBackground(gbgcolor->color());
 	plot->setTransparent(transparentcb->isChecked());
@@ -277,8 +411,13 @@ void PlotSettingsDialog::apply_clicked() {
 	if(type != PQWT3D) {
 		plot->setPosition(posx->text().toDouble(),posy->text().toDouble());
 		plot->setSize(sizex->text().toDouble(),sizey->text().toDouble());
+		plot->enableAspectRatio(aspect->isChecked());
+		if(leftpanel->isChecked()) plot->setLeftPanel();
+		if(rightpanel->isChecked()) plot->setRightPanel();
+		if(toppanel->isChecked()) plot->setTopPanel();
+		if(bottompanel->isChecked()) plot->setBottomPanel();
 	
-		plot->setClipOffset(cliple->text().toInt());
+		plot->setClipOffset(clipni->value());
 		plot->setXRange(xmin->text().toDouble(),xmax->text().toDouble());
 		plot->setYRange(ymin->text().toDouble(),ymax->text().toDouble());
 		if (type == P3D)
@@ -288,7 +427,6 @@ void PlotSettingsDialog::apply_clicked() {
 			((Plot2DSurface* )plot)->enableDensity(dcb->isChecked());
 			((Plot2DSurface* )plot)->enableContour(ccb->isChecked());
 			((Plot2DSurface* )plot)->setNumber(numberle->text().toInt());
-			((Plot2DSurface* )plot)->setPalette(pcb->currentItem());
 			((Plot2DSurface* )plot)->setContourColor(contourcolor->color());
 			((Plot2DSurface* )plot)->setColoredContour(coloredcb->isChecked());
 			((Plot2DSurface* )plot)->setMesh(meshcb->isChecked());
@@ -297,7 +435,6 @@ void PlotSettingsDialog::apply_clicked() {
 			((Plot2DSurface* )plot)->setThreshold(thresholdle->text().toDouble());
 		}
 	
-	kdDebug()<<"OK"<<endl;
 		plot->setBaseline(baselinele->text().toDouble());
 		plot->setBaselineEnabled(baselinecb->isChecked());
 		plot->setXBaseline(xbaselinele->text().toDouble());
@@ -308,11 +445,21 @@ void PlotSettingsDialog::apply_clicked() {
 		plot->setRegionEnabled(regioncb->isChecked());
 		
 		plot->setMarksEnabled(markercb->isChecked());
-		LRange *xrange = new LRange(markminxle->text().toDouble(),markmaxxle->text().toDouble());
-		LRange *yrange = new LRange(markminyle->text().toDouble(),markmaxyle->text().toDouble());
+		LRange *xrange = new LRange(markxminle->text().toDouble(),markxmaxle->text().toDouble());
+		LRange *yrange = new LRange(markyminle->text().toDouble(),markymaxle->text().toDouble());
 		plot->setMarkX(xrange);
 		plot->setMarkY(yrange);
-	kdDebug()<<"OK"<<endl;
+		if(type == P2D) {
+			plot->setFill(fillcb->isChecked());
+#if QT_VERSION > 0x030102
+			plot->setFillType(hbg->selectedId());
+#endif
+			plot->setFillG1(fillg1le->text().toInt());
+			plot->setFillG2(fillg2le->text().toInt());
+			QColor fillcolor = fillcolorcb->color();
+			int fillbrush = fillbrushcb->currentItem();
+			plot->setFillBrush(QBrush(fillcolor,(Qt::BrushStyle) fillbrush));
+		}
 	}
 #ifdef HAVE_GL
 	else {	// PQWT3D
@@ -327,23 +474,24 @@ void PlotSettingsDialog::apply_clicked() {
 #endif
 	
 	p->updatePixmap();
+	return 0;
 }
 
-void PlotSettingsDialog::autoscalex() { 
+void PlotSettingsDialog::autoScaleX() { 
 	plot->autoScaleX();
 	LRange *r = plot->Ranges();
 	xmin->setText(QString::number(r[0].rMin()));
 	xmax->setText(QString::number(r[0].rMax()));
 	p->updatePixmap();
 }
-void PlotSettingsDialog::autoscaley() { 
+void PlotSettingsDialog::autoScaleY() { 
 	plot->autoScaleY();
 	LRange *r = plot->Ranges();
 	ymin->setText(QString::number(r[1].rMin()));
 	ymax->setText(QString::number(r[1].rMax()));
 	p->updatePixmap();
 }
-void PlotSettingsDialog::autoscalez() { 
+void PlotSettingsDialog::autoScaleZ() { 
 	plot->autoScaleZ();
 	LRange *r = plot->Ranges();
 	zmin->setText(QString::number(r[2].rMin()));
