@@ -12,8 +12,8 @@
 
 using namespace std;
 
-ProjectDialog::ProjectDialog(Worksheet *p, const char *name)
-	: Dialog(p->getMainWin(), name),mw(p->getMainWin())
+ProjectDialog::ProjectDialog(MainWin *mw, const char *name)
+	: Dialog(mw, name)
 {
 	setCaption(i18n("Project Settings"));
 
@@ -55,6 +55,7 @@ ProjectDialog::ProjectDialog(Worksheet *p, const char *name)
 
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
 	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	save->setEnabled(false);
 	
 	setMinimumWidth(vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
