@@ -1,11 +1,14 @@
 //LabPlot : PruneListDialog.cc
 
 #include "PruneListDialog.h"
+#include "defs.h"
 
 PruneListDialog::PruneListDialog(MainWin *mw, const char *name)
 	: ListDialog(mw, name)
 {
 	setCaption(i18n("Prune Dialog"));
+	KConfig *config = mw->Config();
+	config->setGroup( "Prune" );
 
 	QTabWidget *tw = new QTabWidget(vbox);
 	QVBox *tab1 = new QVBox(tw);
@@ -13,8 +16,8 @@ PruneListDialog::PruneListDialog(MainWin *mw, const char *name)
 	new QLabel(i18n(" Prune every n points : "),tab1);
 	QHBox *hb = new QHBox(tab1);
 	new QLabel(QString(" n = "),hb);
-	nle = new KLineEdit(QString("3"),hb);
-	nle->setValidator(new QIntValidator(nle));
+	nni = new KIntNumInput(config->readNumEntry("Points",3),hb);
+	nni->setRange(1,INF,1,false);
 
 	Style *style=0;
 	Symbol *symbol=0;
@@ -29,14 +32,22 @@ PruneListDialog::PruneListDialog(MainWin *mw, const char *name)
 
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
         QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	QObject::connect(save,SIGNAL(clicked()),SLOT(saveSettings()));
 
 	setMinimumWidth(vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
 	resize(minimumSize());
 }
  
+void PruneListDialog::saveSettings() {
+	KConfig *config = mw->Config();
+	config->setGroup( "Prune" );
+	
+	config->writeEntry("Points", nni->value());
+}
+
 int PruneListDialog::apply_clicked() {
-	int n = (nle->text()).toInt();
+	int n = nni->value();
 
 	if(s) {
 		QTable *table = s->Table();
@@ -50,7 +61,7 @@ int PruneListDialog::apply_clicked() {
 		// add column if needed
 		bool empty=true;
 		for(int i=0;i<table->numRows();i++) {
-			if(table->text(i,table->numCols()-1).length()>0) {
+			if(!table->text(i,table->numCols()-1).isEmpty()) {
 				empty =false;
 			}
 		}
@@ -85,8 +96,11 @@ int PruneListDialog::apply_clicked() {
 	Symbol *symbol=0;
 	if(st != GRAPHM) {
 		style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
-			widthle->text().toInt(),pencb->currentItem(),brushcb->currentItem());
-		symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->text().toInt(),
+			width->value(),pencb->currentItem(),brushcb->currentItem());
+		style->setBoxWidth(boxwidth->value());
+		style->setAutoBoxWidth(autobox->isChecked());
+		style->setPointsSorting(sortpointscb->isChecked());
+		symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->value(),
 			(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());
 	}	
 	
@@ -116,7 +130,7 @@ int PruneListDialog::apply_clicked() {
 		range[0] = LRange(xmin,xmax);
 		range[1] = LRange(ymin,ymax);
 		
-		QString fun = QString(i18n("prune (")+QString::number(n)+i18n(") of ")+g->Label());
+		QString fun = QString(i18n("prune (")+QString::number(n)+i18n(") of ")+g->getLabel()->simpleTitle());
 		
 		Graph2D *ng = new Graph2D(fun,fun,range,SSPREADSHEET,P2D,style,symbol,ptr,g->Number()/n);
 		mw->addGraph2D(ng,sheetcb->currentItem());
@@ -153,7 +167,7 @@ int PruneListDialog::apply_clicked() {
 		range[1] = LRange(ymin,ymax);
 		range[2] = LRange(zmin,zmax);
 		
-		QString fun = QString(i18n("prune (")+QString::number(n)+i18n(") of ")+g->Label());
+		QString fun = QString(i18n("prune (")+QString::number(n)+i18n(") of ")+g->getLabel()->simpleTitle());
 		
 		Graph3D *ng = new Graph3D(fun,fun,range,SSPREADSHEET,P2D,style,symbol,ptr,g->Number()/n,1);
 		ng->setNumberX((int)(g->NX()/n));
@@ -186,7 +200,7 @@ int PruneListDialog::apply_clicked() {
 		range[2] = LRange(zmin,zmax);
 		range[3] = LRange(tmin,tmax);
 		
-		QString fun = QString(i18n("prune (")+QString::number(n)+i18n(") of ")+g->Label());
+		QString fun = QString(i18n("prune (")+QString::number(n)+i18n(") of ")+g->getLabel()->simpleTitle());
 		
 		Graph4D *ng = new Graph4D(fun,fun,range,SSPREADSHEET,type,style,symbol,ptr,nx/n,g->GType());
 		mw->addGraph4D(ng,sheetcb->currentItem());
