@@ -22,7 +22,7 @@ struct Format {
 };
 
 #define NR_PAGESIZES 42
-#define NR_FORMATS 43
+#define NR_PSFORMATS 43
 
 const QString pagesizes[]={"a0","a1","a2","a3","a4","a5","b4","b5",
 	"tabloid","ledger","legal","statement","excecutive","folio","quarto",
@@ -88,7 +88,7 @@ PstoEditDialog::PstoEditDialog(MainWin *mw, QString fn, int f, int s, double sc,
 	format = new KComboBox(hb);
 	QObject::connect(format,SIGNAL(activated (int)),SLOT(updateFilename(int)));
         QStringList formatlist;
-	for(int i=0;i<NR_FORMATS;i++)
+	for(int i=0;i<NR_PSFORMATS;i++)
 		formatlist<<formats[i].name;
         format->insertStringList(formatlist);
         format->setCurrentItem(f);
@@ -118,6 +118,7 @@ PstoEditDialog::PstoEditDialog(MainWin *mw, QString fn, int f, int s, double sc,
 
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(Apply()));
 	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	save->setEnabled(false);
 
 	setMinimumWidth(vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
