@@ -8,12 +8,16 @@
 #include <gsl/gsl_multifit.h>
 #endif
 
+#include "parser_extern.h"
+
 using namespace std;
 
 RegressionListDialog::RegressionListDialog(MainWin *mw, const char *name)
 	: ListDialog(mw, name)
 {
 	setCaption(i18n("Regression Dialog"));
+	KConfig *config = mw->Config();
+	config->setGroup( "Regression" );
 
 	Plot *plot = p->getPlot(p->API());
 
@@ -23,7 +27,7 @@ RegressionListDialog::RegressionListDialog(MainWin *mw, const char *name)
 	QHBox *hb = new QHBox(tab1);
 	regioncb = new QCheckBox(i18n("use Region "),hb);
 	if(plot->RegionMin() != plot->RegionMax() )
-		regioncb->setChecked(true);
+		regioncb->setChecked(config->readBoolEntry("Region",true));
 	else
 	regioncb->setChecked(false);
 	new QLabel(i18n("( From "),hb);
@@ -33,31 +37,34 @@ RegressionListDialog::RegressionListDialog(MainWin *mw, const char *name)
 	regionmaxle = new KLineEdit(QString::number(plot->RegionMax()),hb);
 	regionmaxle->setValidator(new QDoubleValidator(regionmaxle));
 	new QLabel(i18n(" )"),hb);
+	hb = new QHBox(tab1);
+	negate_regioncb = new QCheckBox(i18n("negate Region"),hb);
+       	negate_regioncb->setChecked(config->readBoolEntry("NegateRegion",false));
 
 	hb = new QHBox(tab1);
 	new QLabel(i18n("Model : "),hb);
         modelcb = new KComboBox(hb);
 	int i=0;
-	while(modelitems[i] != 0) modelcb->insertItem(i18n(modelitems[i++]));
-        modelcb->setCurrentItem(0);
+	while(regression_modelitems[i] != 0) modelcb->insertItem(i18n(regression_modelitems[i++]));
+        modelcb->setCurrentItem(config->readNumEntry("Model",0));
 
 	hb = new QHBox(tab1);
 	new QLabel(i18n("Weight : "),hb);
 	weightcb = new KComboBox(hb);
 	i=0;
 	while(weightitems[i] != 0) weightcb->insertItem(i18n(weightitems[i++]));
-	weightcb->setCurrentItem(0);
+	weightcb->setCurrentItem(config->readNumEntry("Weight",0));
 	QObject::connect(weightcb,SIGNAL(activated(int)),SLOT(weightChanged()));
 	hb = new QHBox(tab1);
 	new QLabel(i18n("Weight Function : "),hb);
-	weightle = new KLineEdit(i18n("equal"),hb);
+	weightle = new KLineEdit(config->readEntry("WeightFunction",i18n("equal")),hb);
 	weightle->setReadOnly(true);
 
 	hb = new QHBox(tab1);
 	new QLabel(i18n("Number of Points for regression function : "),hb);
 	GraphList *gl = plot->getGraphList();
 	GRAPHType st = gl->getStruct(0);
-	int number=100;
+	int number = config->readNumEntry("Number",100);
 	if (st == GRAPH2D) {
 		Graph2D *g = gl->getGraph2D(0);
 		number = g->Number();
@@ -76,9 +83,9 @@ RegressionListDialog::RegressionListDialog(MainWin *mw, const char *name)
 
 	hb = new QHBox(tab1);
 	infocb = new QCheckBox(i18n("Show Info"),hb);
-	infocb->setChecked(true);
+	infocb->setChecked(config->readBoolEntry("ShowInfo",true));
 	rescb = new QCheckBox(i18n("Show Residuals"),hb);
-	rescb->setChecked(false);
+	rescb->setChecked(config->readBoolEntry("Residuals",false));
 
 	Style *style=0;
 	Symbol *symbol=0;
@@ -93,12 +100,27 @@ RegressionListDialog::RegressionListDialog(MainWin *mw, const char *name)
 
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
         QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	QObject::connect(save,SIGNAL(clicked()),SLOT(saveSettings()));
 
 	setMinimumWidth(vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
 	resize(minimumSize());
 }
 
+void RegressionListDialog::saveSettings() {
+	KConfig *config = mw->Config();
+	config->setGroup( "Regression" );
+
+	config->writeEntry("Region", regioncb->isChecked());
+	config->writeEntry("NegateRegion", negate_regioncb->isChecked());
+	config->writeEntry("Model", modelcb->currentItem());
+	config->writeEntry("Weight", weightcb->currentItem());
+	config->writeEntry("WeightFunction", weightle->text());
+	config->writeEntry("Number", numberle->text());
+	config->writeEntry("ShowInfo", infocb->isChecked());
+	config->writeEntry("Residuals", rescb->isChecked());
+}
+
 void RegressionListDialog::weightChanged() {
 	kdDebug()<<"RegressionListDialog::weightChanged()"<<endl;
 	int item = weightcb->currentItem();
@@ -124,6 +146,7 @@ int RegressionListDialog::apply_clicked() {
 		return -2;
 	}
 	int item = (int) (lv->itemPos(lv->currentItem())/lv->currentItem()->height());
+	double regionmin = regionminle->text().toDouble(), regionmax = regionmaxle->text().toDouble();
 
 	GRAPHType st = gl->getStruct(item);
 	QString info;
@@ -168,7 +191,7 @@ int RegressionListDialog::apply_clicked() {
 		int N=0;
 
 		double xmin=0, xmax=1, ymin=0, ymax=1;
-		if (modelcb->currentItem() == MLINEAR) {
+		if (modelcb->currentItem() == MRLINEAR) {
 			double* xdata = new double[nx];
 			double* ydata = new double[nx];
 			double* weight = new double[nx];
@@ -216,21 +239,23 @@ int RegressionListDialog::apply_clicked() {
 						weight[i]=1.0/(e*e);
 				}
 				else if(weightcb->currentItem() == WUSER) {
-					QString tmp;
+					char xvar[]="x", yvar[]="y";
+					init_table();
 					if(st == GRAPH2D) {
-						tmp = mw->parseExpression(weightle->text(), data2d[i].X(), 23);  // "x"
-						tmp = mw->parseExpression(tmp, data2d[i].Y(), 24);  // "y"
+						assign_variable(xvar,data2d[i].X());
+						assign_variable(yvar,data2d[i].Y());
 					}
 					else if(st == GRAPH3D) {
-						tmp = mw->parseExpression(weightle->text(), data3d[i].X(), 23);  // "x"
-						tmp = mw->parseExpression(tmp, data3d[i].Y(), 24);  // "y"
+						assign_variable(xvar,data3d[i].X());
+						assign_variable(yvar,data3d[i].Y());
 					}
 					else if(st == GRAPH4D) {
-						tmp = mw->parseExpression(weightle->text(), data4d[i].X(), 23);  // "x"
-						tmp = mw->parseExpression(tmp, data4d[i].Y(), 24);  // "y"
+						assign_variable(xvar,data4d[i].X());
+						assign_variable(yvar,data4d[i].Y());
 					}
 
-					double value = parse((char *) tmp.latin1());
+					double value = parse((char *) weightle->text().latin1());
+					delete_table();
 					if(parse_errors()>0) {
 						KMessageBox::error(mw, i18n("Parse Error!\n Please check the given weight function."));
 						return -3;
@@ -259,15 +284,21 @@ int RegressionListDialog::apply_clicked() {
 					x = data4d[i].X();
 					y = data4d[i].Y();
 				}
-				if(!regioncb->isChecked() || x > regionminle->text().toDouble() && x < regionmaxle->text().toDouble()) {
-					xdata[N]=x;
-					ydata[N]=y;
-					
-					// dont normalize weighting (weight[N]=weight[i]/sum;)
-					weight[N]=weight[i];
+			
+				// outside region
+				if(regioncb->isChecked() && !negate_regioncb->isChecked()  && ( x < regionmin || x > regionmax ) )
+					continue;
+				// inside neg. region
+				if(regioncb->isChecked() && negate_regioncb->isChecked()  && ( x > regionmin && x < regionmax ) )
+					continue;
 
-					N++;
-				}
+				xdata[N]=x;
+				ydata[N]=y;
+
+				// dont normalize weighting (weight[N]=weight[i]/sum;)
+				weight[N]=weight[i];
+
+				N++;
 			}
 
 			// fit
@@ -332,81 +363,89 @@ int RegressionListDialog::apply_clicked() {
 					x = data4d[i].X();
 					y = data4d[i].Y();
 				}
-				if(!regioncb->isChecked() || x > regionminle->text().toDouble() && x < regionmaxle->text().toDouble()) {
-					if (weightcb->currentItem() == WY)
-						gsl_vector_set (w, N, y);
-					else if(weightcb->currentItem() == WYY)
-						gsl_vector_set (w, N, y*y);
-					else if(weightcb->currentItem() == W1Y) {
-						if (y != 0)
-							gsl_vector_set (w, N, 1.0/y);
-						else
-							gsl_vector_set (w, N, 0.0);
-					}
-					else if(weightcb->currentItem() == W1YY) {
-						if (y != 0)
-							gsl_vector_set (w, N, 1.0/(y*y));
-						else
-							gsl_vector_set (w, N, 0.0);
-					}
-					else if(weightcb->currentItem() == WX)
-						gsl_vector_set (w, N, x);
-					else if(weightcb->currentItem() == WXX)
-						gsl_vector_set (w, N, x*x);
-					else if(weightcb->currentItem() == W1X) {
-						if (x != 0)
-							gsl_vector_set (w, N, 1.0/x);
-						else
-							gsl_vector_set (w, N, 0.0);
-					}
-					else if(weightcb->currentItem() == W1XX) {
-						if (x != 0)
-							gsl_vector_set (w, N, 1.0/(x*x));
-						else
-							gsl_vector_set (w, N, 0.0);
-					}
-					else if(weightcb->currentItem() == WERROR) {
-						double e=1.0;
-						if(st == GRAPH3D) {
-							e = data3d[i].Z();
-						}
-						else if(st == GRAPH4D) {
-							if(g4type) // x-y-dy1-dy2
-								e = data4d[i].Z()+data4d[i].T();
-							else // x-y-dx-dy
-								e = data4d[i].T();
-						}
-						gsl_vector_set (w, N, 1/(e*e));
-					}
-					else if(weightcb->currentItem() == WUSER) {
-						QString tmp;
-						if(st == GRAPH2D) {
-							tmp = mw->parseExpression(weightle->text(), data2d[i].X(), 23);  // "x"
-							tmp = mw->parseExpression(tmp, data2d[i].Y(), 24);  // "y"
-						}
-						else if(st == GRAPH3D) {
-							tmp = mw->parseExpression(weightle->text(), data3d[i].X(), 23);  // "x"
-							tmp = mw->parseExpression(tmp, data3d[i].Y(), 24);  // "y"
-						}
-						else if(st == GRAPH4D) {
-							tmp = mw->parseExpression(weightle->text(), data4d[i].X(), 23);  // "x"
-							tmp = mw->parseExpression(tmp, data4d[i].Y(), 24);  // "y"
-						}
-						
-						double value = parse((char *) tmp.latin1());
-						if(parse_errors()>0) {
-							KMessageBox::error(mw, i18n("Parse Error!\n Please check the given weight function."));
-							return -3;
-						}
 
-						if(!finite(value))
-							value=0;
-						gsl_vector_set (w, N, value);
-					}
+				// outside region
+				if(regioncb->isChecked() && !negate_regioncb->isChecked()  && ( x < regionmin || x > regionmax ) )
+					continue;
+				// inside neg. region
+				if(regioncb->isChecked() && negate_regioncb->isChecked()  && ( x > regionmin && x < regionmax ) )
+					continue;
 
-					sum +=	W(N);
-					N++;
+				if (weightcb->currentItem() == WY)
+					gsl_vector_set (w, N, y);
+				else if(weightcb->currentItem() == WYY)
+					gsl_vector_set (w, N, y*y);
+				else if(weightcb->currentItem() == W1Y) {
+					if (y != 0)
+						gsl_vector_set (w, N, 1.0/y);
+					else
+						gsl_vector_set (w, N, 0.0);
 				}
+				else if(weightcb->currentItem() == W1YY) {
+					if (y != 0)
+						gsl_vector_set (w, N, 1.0/(y*y));
+					else
+						gsl_vector_set (w, N, 0.0);
+				}
+				else if(weightcb->currentItem() == WX)
+					gsl_vector_set (w, N, x);
+				else if(weightcb->currentItem() == WXX)
+					gsl_vector_set (w, N, x*x);
+				else if(weightcb->currentItem() == W1X) {
+					if (x != 0)
+						gsl_vector_set (w, N, 1.0/x);
+					else
+						gsl_vector_set (w, N, 0.0);
+				}
+				else if(weightcb->currentItem() == W1XX) {
+					if (x != 0)
+						gsl_vector_set (w, N, 1.0/(x*x));
+					else
+						gsl_vector_set (w, N, 0.0);
+				}
+				else if(weightcb->currentItem() == WERROR) {
+					double e=1.0;
+					if(st == GRAPH3D) {
+						e = data3d[i].Z();
+					}
+					else if(st == GRAPH4D) {
+						if(g4type) // x-y-dy1-dy2
+							e = data4d[i].Z()+data4d[i].T();
+						else // x-y-dx-dy
+							e = data4d[i].T();
+					}
+					gsl_vector_set (w, N, 1/(e*e));
+				}
+				else if(weightcb->currentItem() == WUSER) {
+					char xvar[]="x", yvar[]="y";
+					init_table();
+					if(st == GRAPH2D) {
+						assign_variable(xvar,data2d[i].X());
+						assign_variable(yvar,data2d[i].Y());
+					}
+					else if(st == GRAPH3D) {
+						assign_variable(xvar,data3d[i].X());
+						assign_variable(yvar,data3d[i].Y());
+					}
+					else if(st == GRAPH4D) {
+						assign_variable(xvar,data4d[i].X());
+						assign_variable(yvar,data4d[i].Y());
+					}
+
+					double value = parse((char *) weightle->text().latin1());
+					delete_table();
+					if(parse_errors()>0) {
+						KMessageBox::error(mw, i18n("Parse Error!\n Please check the given weight function."));
+						return -3;
+					}
+
+					if(!finite(value))
+						value=0;
+					gsl_vector_set (w, N, value);
+				}
+
+				sum +=	W(N);
+				N++;
 			}
 
 			X = gsl_matrix_alloc (N, order);
@@ -430,15 +469,21 @@ int RegressionListDialog::apply_clicked() {
 					x = data4d[i].X();
 					y = data4d[i].Y();
 				}
-				if(!regioncb->isChecked() || x > regionminle->text().toDouble() && x < regionmaxle->text().toDouble()) {
-					for (int j=0;j<order;j++)
-						gsl_matrix_set(X,N,j,pow(x,j));
 
-				 	gsl_vector_set (yy, N, y);
-				 	gsl_vector_set (w, N, W(N)/sum);
-					ydata[N]=y;
-					N++;
-				}
+				// outside region
+				if(regioncb->isChecked() && !negate_regioncb->isChecked()  && ( x < regionmin || x > regionmax ) )
+					continue;
+				// inside neg. region
+				if(regioncb->isChecked() && negate_regioncb->isChecked()  && ( x > regionmin && x < regionmax ) )
+					continue;
+
+				for (int j=0;j<order;j++)
+					gsl_matrix_set(X,N,j,pow(x,j));
+
+				gsl_vector_set (yy, N, y);
+				gsl_vector_set (w, N, W(N)/sum);
+				ydata[N]=y;
+				N++;
 			}
 
 			gsl_multifit_linear_workspace * work = gsl_multifit_linear_alloc (N, order);
@@ -472,22 +517,22 @@ int RegressionListDialog::apply_clicked() {
 				Axis *axis = plot->getAxis(0);
 				double y=0,x=0;
 				switch(axis->Scale()) {
-				case LINEAR:
-				case SQRT:
-				case SX2:
-					x =rangemin+i*(rangemax-rangemin)/(double)(numberx-1);
-					break;
-				case LOG10:
-					x = rangemin+pow((double)i,10)*(rangemax-rangemin)/pow((double)(numberx-1),10);
-					break;
-				case LOG2:
-					x = rangemin+pow((double)i,2)*(rangemax-rangemin)/pow((double)(numberx-1),2);
-					break;
-				case LN:
-					x = rangemin+pow((double)i,M_E)*(rangemax-rangemin)/pow((double)(numberx-1),M_E);
-					break;
+					case LINEAR:
+					case SQRT:
+					case SX2:
+						x =rangemin+i*(rangemax-rangemin)/(double)(numberx-1);
+						break;
+					case LOG10:
+						x = rangemin+pow((double)i,10)*(rangemax-rangemin)/pow((double)(numberx-1),10);
+						break;
+					case LOG2:
+						x = rangemin+pow((double)i,2)*(rangemax-rangemin)/pow((double)(numberx-1),2);
+						break;
+					case LN:
+						x = rangemin+pow((double)i,M_E)*(rangemax-rangemin)/pow((double)(numberx-1),M_E);
+						break;
 				}
-				
+
 				for (int j=0;j<order;j++)
 					y += C(j)*pow(x,j);
 
@@ -510,9 +555,12 @@ int RegressionListDialog::apply_clicked() {
 		range[1] = LRange(ymin,ymax);
 
 		Style *style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
-			widthle->text().toInt(),pencb->currentItem(),brushcb->currentItem());
-		Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->text().toInt(),
-			(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());
+				width->value(),pencb->currentItem(),brushcb->currentItem());
+		style->setBoxWidth(boxwidth->value());
+		style->setAutoBoxWidth(autobox->isChecked());
+		style->setPointsSorting(sortpointscb->isChecked());
+		Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->value(),
+				(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());
 
 		Graph2D *ng = new Graph2D(fun,fun,range,SSPREADSHEET,P2D,style,symbol,ptr,numberx);
 		mw->addGraph2D(ng,sheetcb->currentItem());
@@ -524,7 +572,7 @@ int RegressionListDialog::apply_clicked() {
 	if (infocb->isChecked())
 		KMessageBox::information(0,info);
 #else
-		KMessageBox::error(this, i18n("Sorry. Your installation doesn't support the GSL!"));
+	KMessageBox::error(this, i18n("Sorry. Your installation doesn't support the GSL!"));
 #endif
 
 	return 0;
