@@ -17,6 +17,8 @@
 RichTextWidget::RichTextWidget(QWidget *parent, Label *label, const char *name, bool qwtplot)
 	: QWidget(parent,name), l(label)
 {
+	greek = QFont(QString("Greek Times"));
+	
 	QGroupBox *gb = new QGroupBox(1,QGroupBox::Horizontal,QString(""),parent);
 
 	QHBox *hb = new QHBox(gb);
@@ -35,7 +37,11 @@ RichTextWidget::RichTextWidget(QWidget *parent, Label *label, const char *name,
 	if(qwtplot)
 		texcb->hide();
 
-	// if QWT3D Plot disable boxed and rotation
+	hb = new QHBox(gb);
+	transcb = new QCheckBox(i18n("Transparent"),hb);
+	transcb->setChecked(l->Transparent());
+	bgcolor = new KColorButton(l->Color(),hb);
+
 	hb = new QHBox(gb);
 	boxedcb = new QCheckBox(i18n("Boxed"),hb);
 	QObject::connect(boxedcb,SIGNAL(toggled(bool)),this,SLOT(boxedChanged(bool)));
@@ -102,7 +108,7 @@ RichTextWidget::RichTextWidget(QWidget *parent, Label *label, const char *name,
 	
 	KPushButton *smallgreekpb = new KPushButton( QString("\341"), hb );
 	sgletters = new KPopupMenu();
-	sgletters->setFont(QFont(QString("Greek Times")));
+	sgletters->setFont(greek);
 	QObject::connect(sgletters,SIGNAL(activated(int)),SLOT(insertGChar(int)));
 	smallgreekpb->setPopup(sgletters);
 	for (int i=0;i<25;i++) {
@@ -110,7 +116,7 @@ RichTextWidget::RichTextWidget(QWidget *parent, Label *label, const char *name,
 	}
 	KPushButton *biggreekpb = new KPushButton( QString("\303"), hb );
 	bgletters = new KPopupMenu();
-	bgletters->setFont(QFont(QString("Greek Times")));
+	bgletters->setFont(greek);
 	QObject::connect(bgletters,SIGNAL(activated(int)),SLOT(insertGChar(int)));
 	biggreekpb->setPopup(bgletters);
 	for (int i=0;i<24;i++) {
@@ -127,9 +133,9 @@ RichTextWidget::RichTextWidget(QWidget *parent, Label *label, const char *name,
 	smallgreekpb->setMaximumWidth(40);
 	biggreekpb->setMaximumWidth(40);
 	otherpb->setMaximumWidth(40);
-	smallgreekpb->setFont(QFont(QString("Greek Times")));
-	biggreekpb->setFont(QFont(QString("Greek Times")));
-	otherpb->setFont(QFont(QString("Greek Times")));
+	smallgreekpb->setFont(greek);
+	biggreekpb->setFont(greek);
+	otherpb->setFont(greek);
 
 	te = new QTextEdit(gb);
 	te->setTextFormat(Qt::RichText);
@@ -143,7 +149,11 @@ void RichTextWidget::update() {
 	yle->setText(QString::number(l->Y()));
 	
 	texcb->setChecked(l->isTeXLabel());
+	
 	boxedcb->setChecked(l->Boxed());
+	transcb->setChecked(l->Transparent());
+	bgcolor->setColor(l->BackgroundColor());
+	
 	rotle->setText(QString::number(l->Rotation()));
 	
 	te->setFont(l->Font());
@@ -158,7 +168,7 @@ void RichTextWidget::insertChar(int ch) {
 }
 
 void RichTextWidget::insertGChar(int ch) {
-	te->setFamily(QString("Greek Times"));
+	te->setFamily(greek.family());
 	te->insert(QString(QChar(ch)));
 }
 
@@ -265,4 +275,6 @@ void RichTextWidget::apply() {
 	l->setPosition(xle->text().toDouble(),yle->text().toDouble());
 	l->setBoxed(boxedcb->isChecked());
 	l->setRotation(rotle->text().toDouble());
+	l->setTransparent(transcb->isChecked());
+	l->setBackgroundColor(bgcolor->color());
 }
