@@ -20,7 +20,9 @@ public:
 	RichTextWidget(QWidget *parent, Label *label, const char *name, bool qwtplot=0);
 public slots:
 	void setLabel(Label *label) { l = label; update(); }
-	Label* label() { apply(); return l; }
+	Label* getLabel() { apply(); return l; }
+	Label* label() { return getLabel(); }
+	void setPostionReadOnly(bool r=true) {xle->setReadOnly(r); yle->setReadOnly(r); }
 	void update();
 private slots:
 	void selectFont();
@@ -36,12 +38,13 @@ private slots:
 private:
 	void apply();
 	Label *l;
+	QFont greek;
 	QTextEdit *te;
 	KLineEdit *xle, *yle, *titleFont, *rotle;
 	QToolButton *bold, *italic, *underline, *superscript, *subscript;
 	KPopupMenu *sgletters, *bgletters, *oletters;
-	KColorButton *kcb;
-	QCheckBox *boxedcb, *texcb;
+	KColorButton *kcb, *bgcolor;
+	QCheckBox *boxedcb, *texcb, *transcb;
 };
 
 #endif //RICHTEXTWIDGET_H
