@@ -11,10 +11,12 @@ class SmoothListDialog : public ListDialog
 public:
 	SmoothListDialog(MainWin *mw, const char *name);
 public slots:
-	void setNumber(int n) {nle->setText(QString::number(n)); }	//!< set number to smooth
+	void setNumber(int n) {nni->setValue(n); }	//!< set number to smooth
+	int Apply() { return apply_clicked(); }
 private:
-	KLineEdit *nle;
+	KIntNumInput *nni;
 private slots:
+	void saveSettings();
 	int apply_clicked();
 };
 
