@@ -37,6 +37,60 @@ void Symbol::open(QTextStream *t, int version) {
 		*t>>brush;
 }
 
+QDomElement Symbol::saveXML(QDomDocument doc) {
+	QDomElement symboltag = doc.createElement( "Symbol" );
+
+	QDomElement tag = doc.createElement( "Type" );
+	symboltag.appendChild( tag );
+	QDomText t = doc.createTextNode( QString::number(type) );
+	tag.appendChild( t );
+	tag = doc.createElement( "Color" );
+	symboltag.appendChild( tag );
+	t = doc.createTextNode( color.name() );
+	tag.appendChild( t );
+	tag = doc.createElement( "Size" );
+	symboltag.appendChild( tag );
+	t = doc.createTextNode( QString::number(size) );
+	tag.appendChild( t );
+	tag = doc.createElement( "Fill" );
+	symboltag.appendChild( tag );
+	t = doc.createTextNode( QString::number(fill) );
+	tag.appendChild( t );
+	tag = doc.createElement( "FillColor" );
+	symboltag.appendChild( tag );
+	t = doc.createTextNode( fillcolor.name() );
+	tag.appendChild( t );
+	tag = doc.createElement( "Brush" );
+	symboltag.appendChild( tag );
+	t = doc.createTextNode( QString::number(brush) );
+	tag.appendChild( t );
+
+	return symboltag;
+}
+
+void Symbol::openXML(QDomNode node) {
+	while(!node.isNull()) {
+		QDomElement e = node.toElement();
+//		kdDebug()<<"SYMBOL TAG = "<<e.tagName()<<endl;
+//		kdDebug()<<"SYMBOL TEXT = "<<e.text()<<endl;
+
+		if(e.tagName() == "Type")
+			type = (SType) e.text().toInt();
+		else if(e.tagName() == "Color")
+			color = QColor(e.text());
+		if(e.tagName() == "Size")
+			size = e.text().toInt();
+		if(e.tagName() == "Fill")
+			fill = (FType) e.text().toInt();
+		else if(e.tagName() == "FillColor")
+			fillcolor = QColor(e.text());
+		if(e.tagName() == "Brush")
+			brush = e.text().toInt();
+
+		node = node.nextSibling();
+	}
+}
+
 //! draw the Symbol to the specified QPainter at position X,Y
 void Symbol::draw(QPainter *p, int X, int Y) {
 	QPointArray a;
@@ -331,7 +385,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			a.setPoints(3,X,Y-size/2, X+size,Y-size, X+size,Y+size);
 			break;
 		case FDLEFT:
-			a.setPoints(3,X,Y-size/2, X-size,Y+size, X+size,Y+size);
+			a.setPoints(3,X,Y-size/2, X-size,Y, X+size,Y+size);
 			break;
 		case FDRIGHT:
 			a.setPoints(3,X,Y+size/2, X+size,Y-size, X+size,Y+size);
