@@ -4,6 +4,7 @@
 #define SYMBOL_H
 
 #include <qcolor.h>
+#include <qdom.h>
 #include "symbols.h"
 
 class Symbol {
@@ -11,6 +12,8 @@ public:
 	Symbol(SType t=SNONE, QColor c="blue", int s=5, FType f=FNONE, QColor fc="red", int b=1);
 	void save(QTextStream *t);
 	void open(QTextStream *t,int version);
+	QDomElement saveXML(QDomDocument doc);
+	void openXML(QDomNode node);
 	void draw(QPainter *p,int X, int Y);
 	SType Type() { return type; }
 	void setType(SType t) { type = t; }
