@@ -29,19 +29,31 @@ TitleDialog::TitleDialog(MainWin *mw, const char *name)
 
 	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
+	save->setEnabled(false);
 	
 	setMinimumWidth(2*vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
 	resize(minimumSize());
 }
 
-void TitleDialog::apply_clicked() {
+void TitleDialog::updateDialog() {
+	p = mw->activeWorksheet();
+	
+	if(p != 0) {
+		title = p->getPlot(p->API())->Title();
+		rtw->setLabel(title);
+	}
+}
+
+int TitleDialog::apply_clicked() {
 	kdDebug()<<"TitleDialog::apply_clicked()"<<endl;
 	
 	title = rtw->label();
 	
 	mw->updateSheetList();
 	p->updatePixmap();
+
+	return 0;
 }
 
 void TitleDialog::ok_clicked() {
