@@ -11,14 +11,17 @@ class WaveletListDialog : public ListDialog
 public:
 	WaveletListDialog(MainWin *mw, const char *name);
 public slots:
-	void setDirection(bool d=false) {	transform->setCurrentItem(d); }	//!< set direction forward/backward
+	void setDirection(int d=0) {	transform->setCurrentItem(d); }	//!< set direction forward/backward
+	void setTransform(int d=0) { setDirection(d); }
 	void setForm(bool t=false) { form->setCurrentItem(t); }			//!< set form of transformation
 	void setType(int t) { typecb->setCurrentItem(t); }					//!< set type of transform
-	void setK(int k) { kle->setText(QString::number(k)); }				//!< set k value
+	void setK(int k) { kni->setValue(k); }				//!< set k value
+	int Apply() { return apply_clicked(); }
 private:
 	KComboBox *transform, *form, *typecb;
-	KLineEdit *kle;
+	KIntNumInput *kni;
 private slots:
+	void saveSettings();
 	int apply_clicked();
 };
 
