@@ -14,6 +14,7 @@
 #include <qpicture.h>
 #include <qinputdialog.h>
 #include <qworkspace.h>
+#include <qstringlist.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kdebug.h>
@@ -37,6 +38,10 @@
 #include "PlotTernary.h"
 #include "PlotQWT3D.h"
 
+#ifdef HAVE_UNDO
+UNDO *wundo;
+#endif
+
 using namespace std;
 
 //! main worksheet class. (WNoAutoErase needed for flicker free redrawing)
@@ -49,22 +54,25 @@ Worksheet::Worksheet(QWidget *p, MainWin *mw, const char *name)
 {
 	kdDebug()<<"Worksheet()"<<endl;
 	widgettype=WWORKSHEET;
-	
-	// find free worksheet number
+
+	KConfig *config = mw->Config();
+	config->setGroup( "Worksheet" );
+	QString t = i18n("Worksheet");
+	title = config->readEntry("Title",t);
+
+	// check if name already used
 	QWidgetList list = mw->getWorkspace()->windowList();
-	int nr=0, sheets = mw->NrWorksheets()+mw->NrSpreadsheets();
-	bool found_free=false;
-	while(nr <= sheets && !found_free ) {
-		nr++;
-		found_free=true;
-		for(int i=0;i<sheets;i++) {
-			if(list.at(i)->caption() == QString(i18n("Worksheet")+QString(" ")+QString::number(nr)))
-				found_free=false;
-		}
+	int sheets = mw->NrWorksheets()+mw->NrSpreadsheets();
+	bool found_name=false;
+	for(int i=0;i<sheets;i++) {
+		if(list.at(i)->caption() == title )
+			found_name=true;
 	}
 
-	kdDebug()<<"	Using number "<<nr<<endl;
-	title = i18n("Worksheet")+QString(" ")+QString::number(nr);
+	if(found_name)
+		title += QString(" ") + QString::number(sheets);
+	title_enabled = config->readBoolEntry("TitleEnabled",true);
+
 	setCaption(title);
 
 #if QT_VERSION > 0x030007
@@ -72,14 +80,18 @@ Worksheet::Worksheet(QWidget *p, MainWin *mw, const char *name)
 #else
 	timestamp = QDateTime::currentDateTime();
 #endif
-	timestamp_enabled = true;
+	timestamp_enabled = config->readBoolEntry("TimeStampEnabled",true);
 
 	printer = new KPrinter;
-	pixmap = new QPixmap(600,400);
-	
-	setMinimumSize(600,400);
 
-	background=QColor(220,240,255);
+	// TODO : hardcoded :-(
+	setMinimumSize(300,200);
+	int w = config->readNumEntry("Width",600);
+	int h = config->readNumEntry("Height",400);
+	pixmap = new QPixmap(w,h);
+	resize(w,h);
+
+	background = config->readColorEntry("Background", &Qt::white);
 	for(int i=0;i<NR_OBJECTS;i++) {
 		label[i] = new Label();
 		line[i] = new Line();
@@ -99,6 +111,31 @@ Worksheet::Worksheet(QWidget *p, MainWin *mw, const char *name)
 	kdDebug()<<"Worksheet() DONE"<<endl;
 }
 
+#ifdef HAVE_UNDO
+UNDO *Worksheet::getUndo() { return wundo; }
+void Worksheet::setUndo(UNDO *u) { wundo=u; }
+#endif
+
+void* Worksheet::operator new(size_t size) {
+	kdDebug()<<"NEW WORKSHEET"<<endl;
+#ifdef HAVE_UNDO
+	wundo = undo_new();
+	undo_set_memory_limit(wundo,100000);
+	void *p = undo_malloc(wundo, size);
+#else
+	void *p = malloc(size);
+#endif
+	return p;
+}
+
+void Worksheet::operator delete (void *p) {
+#ifdef HAVE_UNDO
+	undo_free(wundo,p);
+#else
+	free(p);
+#endif
+}
+
 QStringList Worksheet::Info() {
 	kdDebug()<<"Worksheet::Info()"<<endl;
 	QStringList s;
@@ -111,16 +148,25 @@ QStringList Worksheet::Info() {
 	return s;
 }
 
+void Worksheet::closeNow() {
+	delete this;
+	
+	mw->updateSheetList();
+}
+
 void Worksheet::closeEvent(QCloseEvent *e) {
 	kdDebug()<<"Worksheet::closeEvent()"<<endl;
 	
-	int ok = KMessageBox::warningContinueCancel(this, i18n("Do you really want to close the worksheet ?"));
-	if(ok == KMessageBox::Cancel)
-		return;
-	e->accept();
+	KConfig *config = mw->Config();
+	config->setGroup( "General Options" );
+	if (config->readBoolEntry("AskCloseSheet",true)) {
+		int ok = KMessageBox::warningContinueCancel(this, i18n("Do you really want to close the worksheet ?"));
+		if(ok == KMessageBox::Cancel)
+			return;
+	}
 
-	mw->deleteActiveSheet();
-	mw->updateSheetList();
+	closeNow();
+	e->accept();
 }
 
 void Worksheet::New() {
@@ -194,32 +240,127 @@ void Worksheet::deleteActivePlot() {
 	updatePixmap();
 }
 
-Plot *Worksheet::newPlot(PType type) {
+Plot *Worksheet::newPlot(PType type, bool insert) {
 	kdDebug()<<"Worksheet::newPlot() : type="<<type<<endl;
+	Plot *newplot=0;
 	switch(type) {
 	case P2D:
-		plot[nr_plots] = new Plot2DSimple(this);break;
+		newplot = new Plot2DSimple(this);break;
 	case PSURFACE:
-		plot[nr_plots] = new Plot2DSurface(this);break;
+		newplot = new Plot2DSurface(this);break;
 	case P3D:
-		plot[nr_plots] = new Plot3D(this);break;
+		newplot = new Plot3D(this);break;
 	case PPIE:
-		plot[nr_plots] = new PlotPie(this);break;
+		newplot = new PlotPie(this);break;
 	case PPOLAR:
-		plot[nr_plots] = new PlotPolar(this);break;
+		newplot = new PlotPolar(this);break;
 	case PTERNARY:
-		plot[nr_plots] = new PlotTernary(this);break;
+		newplot = new PlotTernary(this);break;
 	case PQWT3D:
-		plot[nr_plots] = new PlotQWT3D(this);break;
+		newplot = new PlotQWT3D(this);break;
 	default: break;
 	}
-	plot[nr_plots]->setType(type);
+	newplot->setType(type);
 
-	api=nr_plots;
-	nr_plots++;
-	updatePixmap();
+	if(insert) {
+		api=nr_plots;
+		plot[nr_plots]=newplot;
+		nr_plots++;
+		updatePixmap();
+	}
 	
-	return plot[nr_plots-1];
+	return newplot;
+}
+
+Plot* Worksheet::clonePlot(int item,bool insert) {
+	Plot *p = getPlot(item);
+	Plot *newp = newPlot(p->Type(),insert);
+//	Plot *newp = getPlot(NrPlots()-1);
+		
+	// copy ranges
+	newp->setRanges(p->Ranges());
+	newp->setActRanges(p->ActRanges());
+		
+	// TODO : copy all settings
+	newp->setRegion(p->Region());
+	newp->setRegionEnabled(p->regionEnabled());
+	newp->setTransparent(p->Transparent());
+	newp->setClipOffset(p->ClipOffset());
+
+	// copy all axes ?
+/*	int nr_axes=0;
+	switch (p->Type()) {
+	case P2D: case PSURFACE : nr_axes=4; break;
+	case P3D: nr_axes=12; break;
+	case PPOLAR: nr_axes=2; break;
+	case PTERNARY: nr_axes=1; break;
+	default:break;
+	}
+	for(int i=0;i<nr_axes;i++) {
+		newp->enableBorder(i,p->BorderEnabled(i));
+		newp->enableGrid(2*i,p->GridEnabled(2*i));	// major
+		newp->enableGrid(2*i+1,p->GridEnabled(2*i+1));	// minor
+	}
+*/
+	newp->setBaselineEnabled(p->BaselineEnabled());
+	newp->setXBaselineEnabled(p->XBaselineEnabled());
+	newp->setBaseline(p->Baseline());
+	newp->setXBaseline(p->XBaseline());
+	newp->setMarksEnabled(p->marksEnabled());
+	newp->setMarkX(p->markX());
+	newp->setMarkY(p->markY());
+	newp->setBackground(p->Background());
+	newp->setGraphBackground(p->graphBackground());
+
+	// clone all graphs
+	GraphList *gl = p->getGraphList();
+	GraphList *newgl = newp->getGraphList();
+	for(unsigned int item=0;item<gl->Number();item++) {
+		// clone label
+		Label *l = new Label();
+		*l = *(gl->getGraph(item)->getLabel());
+		
+		switch(gl->getStruct(item)) {
+		case GRAPH2D: {
+			Graph2D g = *(gl->getGraph2D(item));
+			g.setLabel(l);
+			newgl->addGraph2D(&g);
+			}; break;
+		case GRAPH3D: {
+			Graph3D g = *(gl->getGraph3D(item));
+			g.setLabel(l);
+			newgl->addGraph3D(&g);
+		      }; break;
+		case GRAPH4D: {
+			Graph4D g = *(gl->getGraph4D(item));
+			g.setLabel(l);
+			newgl->addGraph4D(&g);
+		      }; break;
+		case GRAPHM: {
+			GraphM g = *(gl->getGraphM(item));
+			g.setLabel(l);
+			newgl->addGraphM(&g);
+		     }; break;
+		case GRAPHIMAGE: {
+			GraphIMAGE g = *(gl->getGraphIMAGE(item));
+			g.setLabel(l);
+			newgl->addGraphIMAGE(&g);
+			 }; break;
+		case GRAPHL: {
+			GraphL g = *(gl->getGraphL(item));
+			g.setLabel(l);
+			newgl->addGraphL(&g);
+			}; break;
+		default: break;
+		}
+	}
+	
+	if(insert) updatePixmap();
+#ifdef HAVE_UNDO
+	undo_snapshot(wundo);
+#endif
+
+	return newp;
 }
 
 void Worksheet::resizeEvent( QResizeEvent *e) {
@@ -228,13 +369,16 @@ void Worksheet::resizeEvent( QResizeEvent *e) {
 	X = width(); Y = height();
 	this->resize(e->size());
 	updatePixmap();
+#ifdef HAVE_UNDO
+	undo_snapshot(wundo);
+#endif
 } 
 
 //! update off screen pixmap (double buffering)
 void Worksheet::updatePixmap() {
 	kdDebug()<<"Worksheet::updatePixmap()"<<endl;
 	kdDebug()<<"	nr_plots="<<nr_plots<<endl;
-	if(pixmap)
+	if(pixmap && pixmap->size() != size())
 		pixmap->resize(size());
 
 	QPainter p(pixmap, this);
@@ -342,7 +486,9 @@ void Worksheet::mouseDoubleClickEvent(QMouseEvent *e) {
 		int redrecty = (int)(plot[i]->Position().Y()*Y)+5;
 		if(x>redrectx && x <redrectx+15 && y>redrecty && y<redrecty+15) {
 			api=i;
-			(new PlotSettingsDialog(mw,"PlotSettingsDialog"))->show();
+			if(mw->plotsettings_dialog == 0)
+				mw->plotsettings_dialog = new PlotSettingsDialog(mw,"PlotSettingsDialog");
+			mw->plotsettings_dialog->show();
 			return;
 		}
 	}
@@ -350,11 +496,15 @@ void Worksheet::mouseDoubleClickEvent(QMouseEvent *e) {
 	if (type == P2D || type == PSURFACE || type == PPIE || 
 		type == PPOLAR || type == PTERNARY) {
 		if (plot[api]->Title()->inside(x,y,pos,size,X,Y)) {
-			(new TitleDialog(mw,0))->show();
+			if(mw->title_dialog == 0)
+				mw->title_dialog = new TitleDialog(mw,0);
+			mw->title_dialog->show();
 			return;
 		}
 		if (plot[api]->insideLegend(x,y)) {
-			(new LegendDialog(mw,0))->show();
+			if(mw->legend_dialog == 0)
+				mw->legend_dialog = new LegendDialog(mw,0);
+			mw->legend_dialog->show();
 			return;
 		}
 		for (int i=0;i<NR_OBJECTS;i++) {
@@ -386,25 +536,40 @@ void Worksheet::mouseDoubleClickEvent(QMouseEvent *e) {
 		else {
 			// pie plot has no axes
 			if(type == PPOLAR || type == PTERNARY) {
-				(new AxesDialog(mw,0,0))->show();
+				if(mw->axes_dialog == 0)
+					mw->axes_dialog = new AxesDialog(mw,0,0);
+				mw->axes_dialog->show();
+				mw->updateAxesDialog(0);
 				return;	
 			}
 			else if(type !=PPIE) {
 				if(plot[api]->inside(x/(double)X,y/(double)Y)) {
 					if(y>ymax) {
-						(new AxesDialog(mw,0,0))->show();
+						if(mw->axes_dialog == 0)
+							mw->axes_dialog = new AxesDialog(mw,0,0);
+						mw->axes_dialog->show();
+						mw->updateAxesDialog(0);
 						return;
 					}
 					else if(x<xmin) {
-						(new AxesDialog(mw,0,1))->show();
+						if(mw->axes_dialog == 0)
+							mw->axes_dialog = new AxesDialog(mw,0,1);
+						mw->axes_dialog->show();
+						mw->updateAxesDialog(1);
 						return;
 					}
 					else if(x>xmax) {
-						(new AxesDialog(mw,0,2))->show();
+						if(mw->axes_dialog == 0)
+							mw->axes_dialog = new AxesDialog(mw,0,2);
+						mw->axes_dialog->show();
+						mw->updateAxesDialog(2);
 						return;
 					}
 					else if(y<ymin) {
-						(new AxesDialog(mw,0,3))->show();
+						if(mw->axes_dialog == 0)
+							mw->axes_dialog = new AxesDialog(mw,0,3);
+						mw->axes_dialog->show();
+						mw->updateAxesDialog(3);
 						return;
 					}
 				}
@@ -427,35 +592,87 @@ void Worksheet::mouseDoubleClickEvent(QMouseEvent *e) {
 		int dy4 = (y1*(x2-x)+y2*(x-x1)+y*(x1-x2))/(y2-y1);
 
 		if (plot[api]->insideLegend(x,y)) {
-			(new LegendDialog(mw,0))->show();
+			if(mw->legend_dialog == 0)
+				mw->legend_dialog = new LegendDialog(mw,0);
+			mw->legend_dialog->show();
 		}
 		else if (plot[api]->Title()->inside(x,y,pos,size,X,Y)) {
-			(new TitleDialog(mw,0))->show();
+			if(mw->title_dialog == 0)
+				mw->title_dialog = new TitleDialog(mw,0);
+			mw->title_dialog->show();
+		}
+		else if (x>(xmax+xmin)/2 && x<(3*xmax-xmin)/2 && y>=(ymax+ymin)/2 && y<(ymax+ymin)/2+20) {
+			if (mw->axes_dialog == 0)
+				mw->axes_dialog = new AxesDialog(mw,0,0);	// x
+			mw->axes_dialog->show();
+			mw->updateAxesDialog(0);
+		}
+		else if (x>xmin && x<xmax && y>=ymax && y<ymax+20) {
+			if (mw->axes_dialog == 0)
+				mw->axes_dialog = new AxesDialog(mw,0,3);	// x2
+			mw->axes_dialog->show();
+			mw->updateAxesDialog(3);
+		}
+		else if (x>xmin && x<xmax && y>ymin-20 && y<=ymin) {
+			if (mw->axes_dialog == 0)
+				mw->axes_dialog = new AxesDialog(mw,0,6);	// x3
+			mw->axes_dialog->show();
+			mw->updateAxesDialog(6);
+		}
+		else if (x>(xmax+xmin)/2 && x<(3*xmax-xmin)/2 && y>ymin-(ymax-ymin)/2-20 && y<=ymin-(ymax-ymin)/2) {
+			if (mw->axes_dialog == 0)
+				mw->axes_dialog = new AxesDialog(mw,0,9);	// x4
+			mw->axes_dialog->show();
+			mw->updateAxesDialog(9);
+		}
+		else if (x>(xmin+xmax)/2-20 && x<=(xmin+xmax)/2 && y>ymin-(ymax-ymin)/2 && y<(ymax+ymin)/2) {
+			if (mw->axes_dialog == 0)
+				mw->axes_dialog = new AxesDialog(mw,0,2);	// z
+			mw->axes_dialog->show();
+			mw->updateAxesDialog(2);
+		}
+		else if (x>xmin-20 && x<=xmin && y>ymin && y<ymax) {
+			if (mw->axes_dialog == 0)
+				mw->axes_dialog = new AxesDialog(mw,0,5);	// z2
+			mw->axes_dialog->show();
+			mw->updateAxesDialog(5);
+		}
+		else if (x>=xmax && x<xmax+20 && y>ymin && y<ymax) {
+			if (mw->axes_dialog == 0)
+				mw->axes_dialog = new AxesDialog(mw,0,8);	// z3
+			mw->axes_dialog->show();
+			mw->updateAxesDialog(8);
+		}
+		else if (x>=(3*xmax-xmin)/2 && x<(3*xmax-xmin)/2+20 && y>ymin-(ymax-ymin)/2 && y<(ymax+ymin)/2) {
+			if (mw->axes_dialog == 0)
+				mw->axes_dialog = new AxesDialog(mw,0,11);	// z4
+			mw->axes_dialog->show();
+			mw->updateAxesDialog(11);
+		}
+		else if (dy<=0 && dy >-20 ) {
+			if (mw->axes_dialog == 0)
+				mw->axes_dialog = new AxesDialog(mw,0,1);	// y
+			mw->axes_dialog->show();
+			mw->updateAxesDialog(1);
+		}
+		else if (dy2<20 && dy2 >=0 ) {
+			if (mw->axes_dialog == 0)
+				mw->axes_dialog = new AxesDialog(mw,0,4);	// y2
+			mw->axes_dialog->show();
+			mw->updateAxesDialog(4);
+		}
+		else if (dy3<20 && dy3 >=0 ) {
+			if (mw->axes_dialog == 0)
+				mw->axes_dialog = new AxesDialog(mw,0,7);	// y3
+			mw->axes_dialog->show();
+			mw->updateAxesDialog(7);
+		}
+		else if (dy4<=0 && dy4 >-20 ) {
+			if (mw->axes_dialog == 0)
+				mw->axes_dialog = new AxesDialog(mw,0,10);	// y4
+			mw->axes_dialog->show();
+			mw->updateAxesDialog(10);
 		}
-		else if (x>(xmax+xmin)/2 && x<(3*xmax-xmin)/2 && y>=(ymax+ymin)/2 && y<(ymax+ymin)/2+20)
-			(new AxesDialog(mw,0,0))->show();	// x
-		else if (x>xmin && x<xmax && y>=ymax && y<ymax+20)
-			(new AxesDialog(mw,0,3))->show();	// x2
-		else if (x>xmin && x<xmax && y>ymin-20 && y<=ymin)
-			(new AxesDialog(mw,0,6))->show();	// x3
-		else if (x>(xmax+xmin)/2 && x<(3*xmax-xmin)/2 && y>ymin-(ymax-ymin)/2-20 && y<=ymin-(ymax-ymin)/2)
-			(new AxesDialog(mw,0,9))->show();	// x4
-		else if (x>(xmin+xmax)/2-20 && x<=(xmin+xmax)/2 && y>ymin-(ymax-ymin)/2 && y<(ymax+ymin)/2)
-			(new AxesDialog(mw,0,2))->show();	// z
-		else if (x>xmin-20 && x<=xmin && y>ymin && y<ymax)
-			(new AxesDialog(mw,0,5))->show();	// z2
-		else if (x>=xmax && x<xmax+20 && y>ymin && y<ymax)
-			(new AxesDialog(mw,0,8))->show();	// z3
-		else if (x>=(3*xmax-xmin)/2 && x<(3*xmax-xmin)/2+20 && y>ymin-(ymax-ymin)/2 && y<(ymax+ymin)/2)
-			(new AxesDialog(mw,0,11))->show();	// z4
-		else if (dy<=0 && dy >-20 )
-			(new AxesDialog(mw,0,1))->show();	// y
-		else if (dy2<20 && dy2 >=0 )
-			(new AxesDialog(mw,0,4))->show();	// y2
-		else if (dy3<20 && dy3 >=0 )
-			(new AxesDialog(mw,0,7))->show();	// y3
-		else if (dy4<=0 && dy4 >-20 )
-			(new AxesDialog(mw,0,10))->show();	// y4
 		else {
 			if (plot[api]->inside(x,y))
 				(new GraphListDialog(mw,0))->show();
@@ -773,7 +990,6 @@ void Worksheet::mousePressEvent(QMouseEvent *e) {
 	}
 
 	if(mw->defining_baseline == true) {	// position
-		kdDebug()<<"DEFINING BASELINE"<<endl;
 		double yvalue=YCoordinate(y,ymin,ymax);
 		plot[api]->setBaselineEnabled(true);
 		plot[api]->setBaseline(yvalue);
@@ -781,16 +997,17 @@ void Worksheet::mousePressEvent(QMouseEvent *e) {
 		//mw->defining_baseline=false;
 	}
 	if(mw->defining_region == 1) {	// left position
-		double xvalue=XCoordinate(x,xmin,xmax);
+		double xvalue = XCoordinate(x,xmin,xmax);
 		plot[api]->setRegionMin(xvalue);
 		mw->message(i18n("Define Region : click on right position"));
-		mw->defining_region=2;
+		mw->defining_region = 2;
 		return;
 	}
 	else if (mw->defining_region == 2) {	// right position
-		double xvalue=XCoordinate(x,xmin,xmax);
+		double xvalue = XCoordinate(x,xmin,xmax);
+		plot[api]->enableRegion();
 		plot[api]->setRegionMax(xvalue);
-		mw->defining_region=0;
+		mw->defining_region = 0;
 		updatePixmap();
 		return;
 	}
@@ -820,7 +1037,7 @@ void Worksheet::mousePressEvent(QMouseEvent *e) {
 		double xvalue=x/(double)X;
 		double yvalue=y/(double)Y;
 		kdDebug()<<" label["<<tmp_object_index<<"]="<<label[tmp_object_index]->Title()<<endl;
-		while (label[tmp_object_index]->Title().length() != 0)
+		while (! label[tmp_object_index]->Title().isEmpty())
 			tmp_object_index++;
 		label[tmp_object_index]->setPosition(xvalue,yvalue);
 		mw->defining_label=0;
@@ -940,7 +1157,7 @@ void Worksheet::mousePressEvent(QMouseEvent *e) {
 		for (int i=0;i<4;i++) {
 			Label *label = 0;
 			if(plot[api])
-				label = plot[api]->getAxis(i)->label();
+				label = plot[api]->getAxis(i)->getLabel();
 
 			if (i==0 || i==3) {	// x,x2
 				if (label && label->inside(x,y,pos,size,X,Y)) {
@@ -963,7 +1180,7 @@ void Worksheet::mousePressEvent(QMouseEvent *e) {
 	else if (type == P3D) {
 		kdDebug()<<"type = P3D"<<endl;
 		for (int i=0;i<12;i++) {
-			Label *label = plot[api]->getAxis(i)->label();
+			Label *label = plot[api]->getAxis(i)->getLabel();
 			bool inside=false;
 
 			if (i==0 || i==3 || i==6 || i==9) {		// z,z2,z3,z4
@@ -1030,7 +1247,7 @@ void Worksheet::mousePressEvent(QMouseEvent *e) {
 		}
 	}
 	updatePixmap();	// update api mark
-//	kdDebug()<<"Worksheet::mousePressEvent OK"<<endl;
+	kdDebug()<<"Worksheet::mousePressEvent DONE"<<endl;
 }
 
 void Worksheet::mouseMoveEvent(QMouseEvent *e) {
@@ -1257,13 +1474,13 @@ void Worksheet::mouseMoveEvent(QMouseEvent *e) {
 		updatePixmap();
 	}
 	else if (ax!=0) {
-		Label *label = plot[api]->getAxis(anumber)->label();
+		Label *label = plot[api]->getAxis(anumber)->getLabel();
 		label->setPosition((x-ax)/tmpx,(y-ay)/tmpy);
 		updatePixmap();
 	}
 	else if (bx!=0) {
 		if (type == P2D || type == PSURFACE) {
-			Label *label = plot[api]->getAxis(anumber)->label();
+			Label *label = plot[api]->getAxis(anumber)->getLabel();
 			if (anumber==0) {	// x
 				int pos=by+y;
 				label->setPosition(label->X(),label->Y()+(pos-ymax)/(double)Y);
@@ -1284,12 +1501,12 @@ void Worksheet::mouseMoveEvent(QMouseEvent *e) {
 		}
 		else if (type == P3D) {
 			if (anumber==0) {	// x
-				Label *label = plot[api]->getAxis(3)->label();
+				Label *label = plot[api]->getAxis(3)->getLabel();
 				label->setPosition(label->X(),label->Y()+(y-ymax+by)/(double)Y);
 				plot[api]->setYMax(by+y,Y);
 			}
 			if (anumber==1) {	// z
-				Label *label = plot[api]->getAxis(5)->label();
+				Label *label = plot[api]->getAxis(5)->getLabel();
 				label->setPosition(label->X()+(x-xmin+bx)/(double)X,label->Y());
 				plot[api]->setXMin(bx+x,X);
 			}
@@ -1388,6 +1605,10 @@ void Worksheet::mouseReleaseEvent(QMouseEvent *) {
 	}
 	
 	mw->defining_baseline=false;
+	mw->updateLegendDialog();
+	mw->updateTitleDialog();
+	mw->updateAxesDialog();
+	mw->updatePlotSettingsDialog();
 }
 
 void Worksheet::Print(QString fn) {
@@ -1408,6 +1629,13 @@ void Worksheet::Print(QString fn) {
 	int h = metrics.height();
 	kdDebug()<<"	Metrics = "<<w<<' '<<h<<endl;
 
+	// keep original size
+	KConfig *config = mw->Config();
+	config->setGroup( "KPrinter Settings" );
+	if (config->readBoolEntry("UseOriginalSize",true)) {
+		w=X;
+		h=Y;
+	}
 
 	if(plot[api]->Type() == PQWT3D) {
 		kdDebug()<<"	PRINTING QWT3D plot"<<endl;
@@ -1422,10 +1650,13 @@ void Worksheet::Print(QString fn) {
 
 void Worksheet::ExportSVG(QString filename) {
 	kdDebug()<<"Worksheet::ExportSVG() : filename="<<filename<<endl;
-	if(filename.length()<1) {
-		filename = QFileDialog::getSaveFileName(i18n("out.svg"),QString("*.svg"),this);
+	if(filename.isEmpty()) {
+		QString tmpname = mw->Filename().replace( QRegExp(QString(".lpl.*$")), ".svg" );
+		if (tmpname.isEmpty())
+			tmpname=QString("out.svg");
+		filename = QFileDialog::getSaveFileName(tmpname,i18n("SVG Image (*.svg)"),this);
 
-		if(filename.length()==0)	// "Cancel"
+		if(filename.isEmpty())	// "Cancel"
 			return;
 
 		if(filename.find(QRegExp("\\.svg"))==-1)
@@ -1444,16 +1675,19 @@ void Worksheet::ExportSVG(QString filename) {
 	QPainter p;
 	p.begin( &pic ); 		// paint in picture
 	Draw(&p,X,Y);			// draw it
-	p.end();			 	// painting done
+	p.end();		 	// painting done
 	pic.save(filename,"svg");
 }
 
 void Worksheet::ExportPIC(QString filename) {
 	kdDebug()<<"Worksheet::ExportPIC() : filename="<<filename<<endl;
-	if(filename.length()<1) {
-		filename = QFileDialog::getSaveFileName(i18n("out.pic"),QString("*.pic"),this);
+	if(filename.isEmpty()) {
+		QString tmpname = mw->Filename().replace( QRegExp(QString(".lpl.*$")), ".pic" );
+		if (tmpname.isEmpty())
+			tmpname=QString("out.pic");
+		filename = QFileDialog::getSaveFileName(tmpname,i18n("PIC File (*.pic)"),this);
 
-		if(filename.length()==0)	// "Cancel"
+		if(filename.isEmpty())	// "Cancel"
 			return;
 
 		if(filename.find(QRegExp("\\.pic"))==-1)
@@ -1472,16 +1706,19 @@ void Worksheet::ExportPIC(QString filename) {
 	QPainter p;
 	p.begin( &pic ); 		// paint in picture
 	Draw(&p,X,Y);			// draw it
-	p.end();				// painting done
-	pic.save(filename);		 // save to native qpicture format
+	p.end();			// painting done
+	pic.save(filename);
 }
 
 void Worksheet::ExportPS(QString fn) {
 	kdDebug()<<"Worksheet::ExportPS() : filename="<<fn<<endl;
-	if(fn.length()<1) {
-		fn = QFileDialog::getSaveFileName(i18n("out.ps"),QString("*.ps"),this);
+	if(fn.isEmpty()) {
+		QString tmpname = mw->Filename().replace( QRegExp(QString(".lpl.*$")), ".ps" );
+		if (tmpname.isEmpty())
+			tmpname=QString("out.ps");
+		fn = QFileDialog::getSaveFileName(tmpname,i18n("Postscript (*.ps)"),this);
 
-		if(fn.length()==0)	// "Cancel"
+		if(fn.isEmpty())	// "Cancel"
 			return;
 
 		if(fn.find(QRegExp("\\.ps"))==-1)	// append extension
@@ -1501,10 +1738,14 @@ void Worksheet::ExportPS(QString fn) {
 
 void Worksheet::ExportEPS(QString fn) {
 	kdDebug()<<"Worksheet::ExportEPS() : filename="<<fn<<endl;
-	if(fn.length()<1) {
-		fn = QFileDialog::getSaveFileName(i18n("out.eps"),QString("*.eps"),this);
+	if(fn.isEmpty()) {
+		// use project filename with ".eps" as default
+		QString tmpname = mw->Filename().replace( QRegExp(QString(".lpl.*$")), ".eps" );
+		if (tmpname.isEmpty())
+			tmpname=QString("out.eps");
+		fn = QFileDialog::getSaveFileName(tmpname,i18n("Encapsulated Postscript (*.eps)"),this);
 
-		if(fn.length()==0)	// "Cancel"
+		if(fn.isEmpty())	// "Cancel"
 			return;
 
 		if(fn.find(QRegExp("\\.eps"))==-1)
@@ -1518,16 +1759,27 @@ void Worksheet::ExportEPS(QString fn) {
 			return;
 	}
 	
-#ifdef HAVE_PS2EPS
-	KTempFile *tmpfile = new KTempFile(QString::null,".ps");
-	Print(tmpfile->name());
+	KConfig *config = mw->Config();
+	config->setGroup( "KPrinter Settings" );
+
+	if (config->readBoolEntry("UsePS2EPS",true)) {
+		kdDebug()<<"Using ps2eps to create EPS"<<endl;
+		KTempFile *tmpfile = new KTempFile(QString::null,".ps");
+		Print(tmpfile->name());
+
+		KProcess *proc = new KProcess;
+		*proc << "ps2epsi";
+		*proc << tmpfile->name()<<fn;
+		delete tmpfile;
+
+		if( proc->start(KProcess::Block) == false)
+			kdDebug()<<"COULD NOT FIND ps2epsi! Continue with normal export."<<endl;
+		else
+			return;
+	}
 	
-	KProcess *proc = new KProcess;
-	*proc << "ps2epsi";
-	*proc << tmpfile->name()<<fn;
-	proc->start(KProcess::Block);
-#else
 	// use a clean KPrinter object
+	kdDebug()<<"Using ghostscript to create EPS"<<endl;
 	KPrinter printer(false);
 	setupPrinter(&printer,fn);
 
@@ -1537,7 +1789,13 @@ void Worksheet::ExportEPS(QString fn) {
 	int w = metrics.width();
 	int h = metrics.height();
 	kdDebug()<<"Metrics = "<<w<<' '<<h<<endl;
-	printer.setPrintProgram("gs -sDEVICE=epswrite -sPAPERSIZE=%psl -dBATCH -dNOPAUSE -sOutputFile=%out %in" );
+	printer.setPrintProgram("gs -sDEVICE=epswrite -dBATCH -dNOPAUSE -sOutputFile=%out %in" );
+
+	// keep original size
+	if (config->readBoolEntry("UseOriginalSize",true)) {
+		w=X;
+		h=Y;
+	}
 
 	if(plot[api]->Type() == PQWT3D) {
 		kdDebug()<<"	PRINTING QWT3D plot"<<endl;
@@ -1546,16 +1804,18 @@ void Worksheet::ExportEPS(QString fn) {
 	}
 	else
 		Draw(&p,w,h);
-#endif
 }
 
 void Worksheet::ExportPDF(QString fn) {
 	// TODO : use print like ps ?
 	kdDebug()<<"Worksheet::ExportPDF() : filename="<<fn<<endl;
-	if(fn.length()<1) {
-		fn = QFileDialog::getSaveFileName(i18n("out.pdf"),QString("*.pdf"),this);
+	if(fn.isEmpty()) {
+		QString tmpname = mw->Filename().replace( QRegExp(QString(".lpl.*$")), ".pdf" );
+		if (tmpname.isEmpty())
+			tmpname=QString("out.pdf");
+		fn = QFileDialog::getSaveFileName(tmpname,i18n("Portable Document Format (*.pdf)"),this);
 
-		if(fn.length()==0)	// "Cancel"
+		if(fn.isEmpty())	// "Cancel"
 			return;
 
 		if(fn.find(QRegExp("\\.pdf"))==-1)
@@ -1569,7 +1829,26 @@ void Worksheet::ExportPDF(QString fn) {
 			return;
 	}
 
+	KConfig *config = mw->Config();
+	config->setGroup( "KPrinter Settings" );
+	if (config->readBoolEntry("UsePS2PDF",true)) {
+		kdDebug()<<"Using ps2pdf to create PDF"<<endl;
+		KTempFile *tmpfile = new KTempFile(QString::null,".ps");
+		Print(tmpfile->name());
+
+		KProcess *proc = new KProcess;
+		*proc << "ps2pdf";
+		*proc << tmpfile->name()<<fn;
+		delete tmpfile;
+
+		if( proc->start(KProcess::Block) == false)
+			kdDebug()<<"COULD NOT FIND ps2pdf! Continue with normal export."<<endl;
+		else
+			return;
+	}
+	
 	// use a clean KPrinter object
+	kdDebug()<<"Using ghostscript to create PDF"<<endl;
 	KPrinter printer(false);
 	setupPrinter(&printer,fn);
 
@@ -1580,6 +1859,12 @@ void Worksheet::ExportPDF(QString fn) {
 	int h = metrics.height();
 	kdDebug()<<"Metrics = "<<w<<' '<<h<<endl;
 
+	// keep original size
+	if (config->readBoolEntry("UseOriginalSize",true)) {
+		w=X;
+		h=Y;
+	}
+
 	printer.setPrintProgram( "gs -sDEVICE=pdfwrite -sPAPERSIZE=%psl -dBATCH -dNOPAUSE -sOutputFile=%out %in" );
 
 	if(plot[api]->Type() == PQWT3D) {
@@ -1594,12 +1879,13 @@ void Worksheet::ExportPDF(QString fn) {
 void Worksheet::setupPrinter(KPrinter *pr, QString fn) {
 	kdDebug()<<"Worksheet::setupPrinter()"<<endl;
 	KConfig *config = mw->Config();
+	config->setGroup( "KPrinter Settings" );
 
 	pr->setCreator(QString("LabPlot ")+LVERSION);
 	pr->setOutputToFile( true );
 	pr->setOutputFileName( fn );
 	pr->setPageSize((KPrinter::PageSize)config->readNumEntry("PageSize",9));
-	if (config->readNumEntry("Landscape",1))
+	if (config->readNumEntry("Orientation",1))
 		pr->setOrientation(KPrinter::Landscape);
 	else
 		pr->setOrientation(KPrinter::Portrait);
@@ -1727,6 +2013,87 @@ void Worksheet::Export(QString fn, QString format) {
 		pm.save(fn,format,quality);
 	}
 	p.end();
+#ifdef HAVE_UNDO
+	undo_snapshot(wundo);
+#endif
+}
+
+QDomElement Worksheet::saveXML(QDomDocument doc) {
+	QDomElement wstag = doc.createElement( "Worksheet" );
+	wstag.setAttribute("api",QString::number(api));
+	wstag.setAttribute("nr_plots",QString::number(nr_plots));
+	
+	QDomElement tag = doc.createElement( "Position" );
+	tag.setAttribute("x",QString::number(parentWidget()->pos().x()));
+	tag.setAttribute("y",QString::number(parentWidget()->pos().y()));
+    	wstag.appendChild( tag );
+	tag = doc.createElement( "Size" );
+	tag.setAttribute("width",QString::number(X));
+	tag.setAttribute("height",QString::number(Y));
+   	wstag.appendChild( tag );
+	tag = doc.createElement( "Title" );
+   	wstag.appendChild( tag );
+  	QDomText t = doc.createTextNode( title );
+    	tag.appendChild( t );
+	tag = doc.createElement( "TitleEnabled" );
+   	wstag.appendChild( tag );
+  	t = doc.createTextNode( QString::number(title_enabled) );
+    	tag.appendChild( t );
+	tag = doc.createElement( "Background" );
+   	wstag.appendChild( tag );
+  	t = doc.createTextNode( background.name() );
+    	tag.appendChild( t );
+	tag = doc.createElement( "Timestamp" );
+   	wstag.appendChild( tag );
+#if QT_VERSION > 0x030007
+  	t = doc.createTextNode( QString::number(timestamp.toTime_t()) );
+#else
+	QDateTime stoneage(QDate(1970,1,1));
+  	t = doc.createTextNode( QString::number(stoneage.secsTo(timestamp)) );
+#endif
+    	tag.appendChild( t );
+	tag = doc.createElement( "TimestampEnabled" );
+   	wstag.appendChild( tag );
+  	t = doc.createTextNode( QString::number(timestamp_enabled) );
+    	tag.appendChild( t );
+
+	// drawing objects
+	for(int i=0;i<NR_OBJECTS;i++) {
+		// only save used objects
+		if(! label[i]->Title().isEmpty()) {
+			tag = label[i]->saveXML(doc);
+    			wstag.appendChild(tag);
+		}
+		Point start = line[i]->startPoint() ,end = line[i]->endPoint();
+		if(fabs(start.X()-end.X())>1.0e-6 || fabs(start.Y()-end.Y())>1.0e-6) {
+			tag = line[i]->saveXML(doc);
+    			wstag.appendChild(tag);
+		}
+		start = rect[i]->startPoint();
+		end = rect[i]->endPoint();
+		if(fabs(start.X()-end.X())>1.0e-6 || fabs(start.Y()-end.Y())>1.0e-6) {
+			tag = rect[i]->saveXML(doc);
+    			wstag.appendChild(tag);
+		}
+		start = rect[i]->startPoint();
+		end = rect[i]->endPoint();
+		if(fabs(start.X()-end.X())>1.0e-6 || fabs(start.Y()-end.Y())>1.0e-6) {
+			tag = ellipse[i]->saveXML(doc);
+    			wstag.appendChild(tag);
+		}
+		if(! image[i]->Name().isEmpty()) {
+			tag = image[i]->saveXML(doc);
+    			wstag.appendChild(tag);
+		}
+	}
+
+	// all plots
+	for (unsigned int i=0;i<nr_plots;i++) {
+		tag = plot[i]->savePlotXML(doc);
+    		wstag.appendChild(tag);
+	}
+
+	return wstag;
 }
 
 void Worksheet::save(QTextStream *t) {
@@ -1763,6 +2130,60 @@ void Worksheet::save(QTextStream *t) {
 	}
 }
 
+void Worksheet::openXML(QDomNode node) {
+	int nr_plots=0;
+	int nr_label=0, nr_line=0, nr_rect=0, nr_ellipse=0, nr_image=0;
+	while(!node.isNull()) {
+		QDomElement e = node.toElement();
+//		kdDebug()<<"WS TAG = "<<e.tagName()<<endl;
+//		kdDebug()<<"WS TEXT = "<<e.text()<<endl;
+
+		if(e.tagName() == "Position") {
+			int px = e.attribute("x").toInt();
+			int py = e.attribute("y").toInt();
+			parentWidget()->move(QPoint(px,py));
+			if(px<0 || py<0) {	// fullscreen
+				mw->getWorkspace()->tile();
+				showMaximized();
+			}
+		}
+		else if(e.tagName() == "Size") {
+			X = e.attribute("width").toInt();
+			Y = e.attribute("height").toInt();
+			resize(X,Y);
+			kdDebug()<<"Resizing to "<<X<<' '<<Y<<endl;
+		}
+		else if(e.tagName() == "Title")
+			title = e.text();
+		else if(e.tagName() == "TitleEnabled")
+			title_enabled = (bool) e.text().toInt();
+		else if(e.tagName() == "Background")
+			background = QColor(e.text());
+		else if(e.tagName() == "Timestamp")
+			timestamp.setTime_t(e.text().toInt());
+		else if(e.tagName() == "TimestampEnabled")
+			timestamp_enabled = (bool) e.text().toInt();
+	
+		else if(e.tagName() == "Label")
+			label[nr_label++]->openXML(e.firstChild());		
+		else if(e.tagName() == "Line")
+			line[nr_line++]->openXML(e.firstChild());		
+		else if(e.tagName() == "Rect")
+			rect[nr_rect++]->openXML(e.firstChild());		
+		else if(e.tagName() == "Ellipse")
+			ellipse[nr_ellipse++]->openXML(e.firstChild());		
+		else if(e.tagName() == "Image")
+			image[nr_image++]->openXML(e.firstChild());		
+		
+		else if(e.tagName() == "Plot") {
+			newPlot((PType) e.attribute("type").toInt());
+			plot[nr_plots++]->openPlotXML(e.firstChild());
+		}
+
+		node = node.nextSibling();
+	}
+}
+
 //! open worksheet : type : old type from version <11
 void Worksheet::open(QTextStream *t,int version,PType oldtype) {
 	kdDebug()<<"Worksheet::open() : version = "<<version<<endl;
@@ -1772,6 +2193,7 @@ void Worksheet::open(QTextStream *t,int version,PType oldtype) {
 	*t>>X>>Y;
 
 	kdDebug()<<"Dimension "<<X<<' '<<Y<<endl;
+	resize(X,Y);
 
 	// NEW : worksheet settings
 	if(version > 10) {
@@ -1805,14 +2227,18 @@ void Worksheet::open(QTextStream *t,int version,PType oldtype) {
 	}
 
 	// drawing objects
-	if (version > 7) {
-		for(int i=0;i<NR_OBJECTS;i++) {
-			label[i]->open(t,version);
-			line[i]->open(t,version);
-			rect[i]->open(t,version);
-			ellipse[i]->open(t,version);
-			image[i]->open(t,version);
-		}
+	int nr_objects=0;
+	if (version > 7)
+		nr_objects = 10;
+	if (version > 21)
+		nr_objects = 100;
+	
+	for(int i=0;i<nr_objects;i++) {
+		label[i]->open(t,version);
+		line[i]->open(t,version);
+		rect[i]->open(t,version);
+		ellipse[i]->open(t,version);
+		image[i]->open(t,version);
 	}
 
 	// open all plots
@@ -1831,10 +2257,7 @@ void Worksheet::open(QTextStream *t,int version,PType oldtype) {
 		plot[i]->open(t, version);
 	}
 
-	if (!mw->Config()->readBoolEntry("Cascade",false)) {
-		QSize mwsize=mw->size();
-		this->resize(mwsize.width()-20,mwsize.height()-75);
-	}
+	redraw();	// needed for empty plot
 }
 
 void Worksheet::addGraph2D(Graph2D *g, PType type) {
@@ -1851,15 +2274,11 @@ void Worksheet::addGraph2D(Graph2D *g, PType type) {
 	if(plot[api] !=0 && plot[api]->Type() != type)
 		newPlot(type);
 		
-	// ad to plot
-	if(plot[api] != 0) {
-		plot[api]->getGraphList()->addGraph2D(g);
-	}
-	else {
+	// add to plot
+	if(plot[api] == 0)
 		newPlot(type);
-		
-		plot[api]->getGraphList()->addGraph2D(g);
-	}
+
+	plot[api]->getGraphList()->addGraph2D(g);
 
 	resetRanges();
 
@@ -2000,17 +2419,58 @@ void Worksheet::addGraphIMAGE(GraphIMAGE *g) {
 	if(plot[api] !=0 && plot[api]->Type() != type)
 		newPlot(type);
 	
+	kdDebug()<<"OK"<<endl;
 	// add to plot
 	if(plot[api] != 0) {
 		plot[api]->getGraphList()->addGraphIMAGE(g);
+	kdDebug()<<"OK"<<endl;
 	}
 	else {
 		newPlot(type);
+	kdDebug()<<"OK"<<endl;
 		plot[api]->getGraphList()->addGraphIMAGE(g);
 	}
 
+	kdDebug()<<"OK"<<endl;
+	resetRanges();
+
+	kdDebug()<<"OK"<<endl;
+	LRange *actrange = plot[api]->ActRanges();
+	if (actrange[0].rMax()-actrange[0].rMin() == 0)
+		plot[api]->setActRanges(plot[api]->Ranges());
+
+	kdDebug()<<"OK"<<endl;
+	updatePixmap();
+	kdDebug()<<"Worksheet::addGraphIMAGE() DONE"<<endl;
+}
+
+void Worksheet::addGraphL(GraphL *g, PType type) {
+	kdDebug()<<"Worksheet::addGraphL() (Worksheet "<<caption()<<")"<<endl;
+	kdDebug()<<"	api = "<<api<<" of "<<nr_plots<<" / type = "<<type<<endl;
+	kdDebug()<<"	GraphL Name = "<<g->Name()<<endl;
+
+	if(plot[api] !=0 && plot[api]->Type() == PQWT3D ) {
+		KMessageBox::error(this,i18n("QWT 3D plot only supports one plot per worksheet!"));
+		return;
+	}
+
+	// add new plot if type mismatch
+	if(plot[api] !=0 && plot[api]->Type() != type)
+		newPlot(type);
+		
+	// ad to plot
+	if(plot[api] != 0) {
+		plot[api]->getGraphList()->addGraphL(g);
+	}
+	else {
+		newPlot(type);
+		
+		plot[api]->getGraphList()->addGraphL(g);
+	}
+
 	resetRanges();
 
+	// set actrange for new plots
 	LRange *actrange = plot[api]->ActRanges();
 	if (actrange[0].rMax()-actrange[0].rMin() == 0)
 		plot[api]->setActRanges(plot[api]->Ranges());
