@@ -19,8 +19,14 @@
 #include "widgettype.h"
 #include "scale.h"
 
+#ifdef HAVE_UNDO
+extern "C" {
+#include "undo.h"
+}
+#endif
+
 #define NR_PLOTS 16
-#define NR_OBJECTS 10
+#define NR_OBJECTS 100
 
 class MainWin;
 class Plot;
@@ -81,14 +87,24 @@ private:
 	unsigned int api, nr_plots;	// active plot index and number of plots
 public:
 	Worksheet(QWidget *parent, MainWin *mw, const char *name);
+	static void* operator new(size_t size);
+	static void operator delete(void *p);
+	void closeNow();
 	WidgetType getWidgetType() { return widgettype; }
 	QStringList Info();
 	MainWin *getMainWin() { return mw; }	// for project dialog
 	Plot *getPlot(int i) { return plot[i]; }	//!< get plot number i
+	void setPlot(int i,Plot *p) { plot[i] = p; }	//!< set plot number i
+#ifdef HAVE_UNDO
+	UNDO *getUndo();
+	void setUndo(UNDO *u);
+#endif
 	void updatePixmap();
 	void New();
 	void save(QTextStream *t);
 	void open(QTextStream *t,int version, PType oldtype);
+	QDomElement saveXML(QDomDocument doc);
+	void openXML(QDomNode node);
 
 	// TODO : add to which plot ? -> check this
 	void addGraph2D(Graph2D *g,PType type=P2D);
@@ -96,6 +112,7 @@ public:
 	void addGraphM(GraphM *g,PType type=PSURFACE);
 	void addGraph4D(Graph4D *g);
 	void addGraphIMAGE(GraphIMAGE *g);
+	void addGraphL(GraphL *g,PType type=PPIE);
 	
 	void resetRanges();
 	void checkRanges(TScale scale, double *min, double *max);
@@ -119,7 +136,8 @@ public slots:
 	PlotPolar* getPolarPlot(int i);  				//!< get polar plot number i
 	PlotTernary* getTernaryPlot(int i);  				//!< get ternary plot number i
 
-	Plot* newPlot(PType type=P2D);			// TODO
+	Plot* newPlot(PType type=P2D, bool insert=true);	// TODO, insert : insert new plot ?
+	Plot* clonePlot(int item, bool insert=true);	//!< clone plot item, insert new plot?
 	void deletePlot(int i);				//!< delete plot number i
 	void deleteActivePlot();				// TODO
 	
@@ -128,6 +146,7 @@ public slots:
 	void redraw() {updatePixmap();}			//!< repaint the worksheet
 	int API() { return api; }			//!< get active plot number
 	unsigned int NrPlots() { return nr_plots; }	//!< get number of plots
+	void setNrPlots(unsigned int i) { nr_plots=i; }	//!< set number of plots
 	
 	int NrObjects() { return NR_OBJECTS; }		//!< get number of drawing objects
 	Line* getLine(int i) { return line[i]; }	//!< get line number i
@@ -141,15 +160,16 @@ public slots:
 	LImage* getImage(int i) { return image[i]; }		//!< get image number i
 	void setImage(int i, LImage* im) { image[i]=im; }	//!< set image number i to im
 
-
 	QString Title() const { return title; }										//!< get title
 	void setTitle(QString t) { title = t.remove(QChar('&')); setCaption(title); updatePixmap(); }				//!< set title to t
 	bool TitleEnabled() const { return title_enabled; }							//!< title enabled ?
-	void setTitleEnabled(bool e=true) { title_enabled = e; updatePixmap(); }			//!< enable title	
+	void enableTitle(bool e=true) { title_enabled = e; updatePixmap(); }			//!< enable title	
+	void setTitleEnabled(bool e=true) { enableTitle(e); }
 	QDateTime TimeStamp() const { return timestamp; }								//!< get timestamp 
 	void setTimeStamp(QDateTime ts) { timestamp = ts; updatePixmap(); }			//!< set timestamp
-	bool TimeStampEnabled() const { return timestamp_enabled; }					//!< enable timestamp
-	void setTimeStampEnabled(bool e=true) { timestamp_enabled = e;updatePixmap(); }	//!< timestamp enabled ?
+	bool TimeStampEnabled() const { return timestamp_enabled; }				//!< timestamp enabled?
+	void enableTimeStamp(bool e=true) { timestamp_enabled = e;updatePixmap(); }	//!< enable timestamp
+	void setTimeStampEnabled(bool e=true) { enableTimeStamp(e); }
 	QColor Background() const { return background; }							//!< get background color
 	void setBackground(QColor c) { background = c; updatePixmap(); }				//!< set background color to c
 	void setBackground(QString c) { setBackground(QColor(c)); }				//!< set background color to c
