@@ -29,7 +29,9 @@ public:
 public slots:
 	void setPoint(double x, double y) { v->setPoint(x,y); }
 	double X() { return v->X(); }
+	void setX(double s) { v->setX(s); }
 	double Y() { return v->Y(); }
+	void setY(double s) { v->setY(s); }
 	void setMasked(bool m=true) { v->setMasked(m); }
 	bool Masked() { return v-Masked(); }
 private:
@@ -236,7 +238,7 @@ public slots:
 	QColor Color() { return v->Color(); }
 	void setFont(QFont font) { v->setFont(font); }
 	QFont Font() { return v->Font(); }
-	void setBoxed(bool b) { v->setBoxed(b); }
+	void setBoxed(bool b=true) { v->setBoxed(b); }
 	bool Boxed() { return v->Boxed(); }
 	double Rotation() { return v->Rotation(); }
 	void setRotation(double r) { v->setRotation(r); }
@@ -255,12 +257,17 @@ public slots:
 	void setFont(QFont font) { v->setFont(font); }
 	QFont Font() { return v->Font(); }
 	void enable(bool b=true) { v->enable(b); }
-	bool enabled() { return v->enabled(); }
+	bool Enabled() { return v->Enabled(); }
 	void setPosition(double X, double Y) { v->setPosition(X,Y); }
 	double X() { return v->X(); }
 	double Y() { return v->Y(); }
 	void enableBorder(bool b=true) { v->enableBorder(b); }
-	bool borderEnabled() { return v->borderEnabled(); }
+	bool BorderEnabled() { return v->BorderEnabled(); }
+	void setColor(QColor c) { v->setColor(c); }
+	void setColor(QString c) { v->setColor(c); }
+	QColor Color() { return v->Color(); }
+	void setTransparent(bool t=true) { v->setTransparent(t); }
+	bool Transparent() { return v->Transparent(); }
 	bool getOrientation() { return v->getOrientation(); }
 	void setOrientation(bool o) { v->setOrientation(o); }
 	int TicLabelLength() { return v->TicLabelLength(); }
@@ -275,8 +282,8 @@ class AxisWrapper : public QObject
 public:
 	AxisWrapper(Axis *v) : v(v) {}
 public slots:
-	void enable(bool b=true) { v->enable(b); }	
-	bool enabled() { return v->enabled(); }
+	void Enable(bool b=true) { v->Enable(b); }	
+	bool Enabled() { return v->Enabled(); }
 	void setScale(TScale s) { v->setScale(s); }
 	void setScale(int s) { v->setScale((TScale) s); }
 	int Scale() { return (int) v->Scale(); }
@@ -288,51 +295,65 @@ public slots:
 	Label *getLabel() { return v->getLabel(); }
 	Label *label() { return v->getLabel(); }
 
-	void setTicsLabelRotation(double r) { v->setTicsLabelRotation(r); }
-	double TicsLabelRotation() { return v->TicsLabelRotation(); }
-	void setTicsLabelPrefix(QString p) {v->setTicsLabelPrefix(p); }
-	QString TicsLabelPrefix() { return v->TicsLabelPrefix(); }
-	void setTicsLabelSuffix(QString s) { v->setTicsLabelSuffix(s); }
-	QString TicsLabelSuffix() { return v->TicsLabelSuffix(); }
-	void setTicsFont(QFont a) { v->setTicsFont(a); }
-	QFont TicsFont() { return v->TicsFont(); }
-	void setTicsColor(QColor col) { v->setTicsColor(col); }
-	void setTicsColor(QString col) { v->setTicsColor(QColor(col)); }
-	QColor TicsColor() { return v->TicsColor(); }
-	void setTicsLabelColor(QColor col) { v->setTicsLabelColor(col); }
-	void setTicsLabelColor(QString col) { v->setTicsLabelColor(QColor(col)); }
-	QColor TicsLabelColor() { return v->TicsLabelColor(); }
-	void setTicsLabelFormat(TFormat tmp) { v->setTicsLabelFormat(tmp); }
-	void setTicsLabelFormat(int tmp) { v->setTicsLabelFormat((TFormat) tmp); }
-	int TicsLabelFormat() { return  (int) v->TicsLabelFormat(); }
+	bool tickType() { return v->tickType(); }
+	void setTickType(bool t) { v->setTickType(t); } 
+	bool tickLabelEnabled() { return v->tickLabelEnabled(); }
+	void enableTickLabel(bool e=true) { v->enableTickLabel(e); } 
+	void setTickLabelRotation(double r) { v->setTickLabelRotation(r); }
+	double TickLabelRotation() { return v->TickLabelRotation(); }
+	void setTickLabelPrefix(QString p) {v->setTickLabelPrefix(p); }
+	QString TickLabelPrefix() { return v->TickLabelPrefix(); }
+	void setTickLabelSuffix(QString s) { v->setTickLabelSuffix(s); }
+	QString TickLabelSuffix() { return v->TickLabelSuffix(); }
+	void setTickLabelFont(QFont a) { v->setTickLabelFont(a); }
+	QFont TickLabelFont() { return v->TickLabelFont(); }
+	void setTickColor(QColor col) { v->setTickColor(col); }
+	void setTickColor(QString col) { v->setTickColor(QColor(col)); }
+	QColor TickColor() { return v->TickColor(); }
+	void setTickLabelColor(QColor col) { v->setTickLabelColor(col); }
+	void setTickLabelColor(QString col) { v->setTickLabelColor(QColor(col)); }
+	QColor TickLabelColor() { return v->TickLabelColor(); }
+	void setTickLabelFormat(TFormat tmp) { v->setTickLabelFormat(tmp); }
+	void setTickLabelFormat(int tmp) { v->setTickLabelFormat((TFormat) tmp); }
+	int TickLabelFormat() { return  (int) v->TickLabelFormat(); }
 	void setDateTimeFormat(QString f) { v->setDateTimeFormat(f); }
 	QString DateTimeFormat() { return v->DateTimeFormat(); }
-	void setTicsLabelPrecision(int tmp) { v->setTicsLabelPrecision(tmp); }
-	int TicsLabelPrecision() { return v->TicsLabelPrecision(); }
-	void setTicsLabelGap(int g) { v->setTicsLabelGap(g); }
-	int TicsLabelGap() { return v->TicsLabelGap(); }
+	void setTickLabelPrecision(int tmp) { v->setTickLabelPrecision(tmp); }
+	int TickLabelPrecision() { return v->TickLabelPrecision(); }
+	void setTickLabelPosition(int g) { v->setTickLabelPosition(g); }
+	int TickLabelPosition() { return v->TickLabelPosition(); }
 	
-	void setMajorTics(int t) { v->setMajorTics(t); }
-	int MajorTics() { return v->MajorTics(); }
-	void setMinorTics(int t) { v->setMinorTics(t); }
-	int MinorTics() { return v->MinorTics(); }
-	void enableMajorTics(bool b=true) { v->enableMajorTics(b); }
-	void enableMinorTics(bool b=true) { v->enableMinorTics(b); }
-	bool MajorTicsEnabled() { return v->MajorTicsEnabled(); }
-	bool MinorTicsEnabled() { return v->MinorTicsEnabled(); }
-	void setTicsPos(int tp) { v->setTicsPos(tp); }
-	int TicsPos() { return v->TicsPos(); }
-	void setMajorTicsWidth(int w) { v->setMajorTicsWidth(w); }
-	int majorTicsWidth() { return v->majorTicsWidth(); }
-	void setMinorTicsWidth(int w) { v->setMinorTicsWidth(w); }
-	int minorTicsWidth() { return v->minorTicsWidth(); }
+	void setMajorTicks(int t) { v->setMajorTicks(t); }
+	double MajorTicks() { return v->MajorTicks(); }
+	void setMinorTicks(int t) { v->setMinorTicks(t); }
+	double MinorTicks() { return v->MinorTicks(); }
+	void enableMajorTicks(bool b=true) { v->enableMajorTicks(b); }
+	void enableMinorTicks(bool b=true) { v->enableMinorTicks(b); }
+	bool MajorTicksEnabled() { return v->MajorTicksEnabled(); }
+	bool MinorTicksEnabled() { return v->MinorTicksEnabled(); }
+	void setTickPos(int tp) { v->setTickPos(tp); }
+	int TickPos() { return v->TickPos(); }
+	void setMajorTickWidth(int w) { v->setMajorTickWidth(w); }
+	int majorTickWidth() { return v->majorTickWidth(); }
+	void setMinorTickWidth(int w) { v->setMinorTickWidth(w); }
+	int minorTickWidth() { return v->minorTickWidth(); }
+	double majorTickLength() { return v->majorTickLength(); }
+	void setMajorTickLength(double l) { v->setMajorTickLength(l); }
+	double minorTickLength() { return v->minorTickLength(); }
+	void setMinorTickLength(double l) { v->setMinorTickLength(l); }
 	
+	bool BorderEnabled() { return v->BorderEnabled(); }
+	void enableBorder(bool b=true) { v->enableBorder(b); }
 	void setBorderColor(QColor col) { v->setBorderColor(col); }
 	void setBorderColor(QString col) { v->setBorderColor(QColor(col)); }
 	QColor BorderColor() { return v->BorderColor(); }
 	void setBorderWidth(int b) { v->setBorderWidth(b); }
 	int borderWidth() { return v->borderWidth(); }
 
+	bool MajorGridEnabled() { return v->MajorGridEnabled(); }
+	void enableMajorGrid(bool b=true) { v->enableMajorGrid(b); }
+	bool MinorGridEnabled() { return v->MinorGridEnabled(); }
+	void enableMinorGrid(bool b=true) { v->enableMinorGrid(b); }
 	void setMajorGridColor(QColor c) { v->setMajorGridColor(c); }
 	void setMajorGridColor(QString c) { v->setMajorGridColor(QColor(c)); }
 	QColor majorGridColor() { return v->majorGridColor(); }
@@ -372,20 +393,40 @@ public slots:
 	double RegionMax() {return v->RegionMax(); }
 	LRange *Region() { return v->Region(); }
 	bool regionEnabled() { return v->regionEnabled(); }
-	void setRegionEnabled(bool e=true) { v->setRegionEnabled(e); }
+	void enableRegion(bool e=true) { v->enableRegion(e); }
+	void setRegionEnabled(bool e=true) { v->enableRegion(e); }
 	
-	bool marksEnabled() { return v->marksEnabled(); }
-	void setMarksEnabled(bool m=true) { v->setMarksEnabled(m); }
+	bool marksEnabled() { return v->marksEnabled(); }		// marks
+	void enableMarks(bool m=true) { v->enableMarks(m); }
+	void setMarksEnabled(bool m=true) { v->enableMarks(m); }
 	LRange *markX() { return v->markX(); }
 	void setMarkX(LRange *l) { v->setMarkX(l); }
 	LRange *markY() { return v->markY(); }
 	void setMarkY(LRange *l) { v->setMarkY(l); }
+	bool Fill() { return v->Fill(); }							// fill
+	void setFill(bool f=true) { v->setFill(f); }
+	void setFillType(int t) { v->setFillType(t); }
+	int  FillType() { return v->FillType(); }
+	int FillG1() { return v->FillG1(); }
+	void setFillG1(int f) { v->setFillG1(f); }
+	int FillG2() { return v->FillG2(); }
+	void setFillG2(int f) { v->setFillG1(f); }
+	QBrush FillBrush() { return v->FillBrush(); }
+	void setFillBrush(QBrush b) { v->setFillBrush(b); }
 	
 	void setPosition(double x, double y) { v->setPosition(x,y);}
+	Point Position() { return v->Position(); }
 	void setSize(double x, double y) { v->setSize(x,y);}
+	Point Size() { return v->Size(); }
+	void enabledAspectRatio(bool a=true) { v->enableAspectRatio(a); }
+	bool AspectRatioEnabled() { return v->AspectRatioEnabled(); }
 	void autoScaleX() {v->autoScaleX();}
 	void autoScaleY() {v->autoScaleY();}
 	void autoScaleZ() {v->autoScaleZ();}
+	void autoScaleAll() {v->autoScaleAll();}
+	LRange *XRange() { return v->Range(0); }
+	LRange *YRange() { return v->Range(1); }
+	LRange *ZRange() { return v->Range(2); }
 	void setXRange(double x1, double x2) {v->setXRange(x1,x2); }
 	void setYRange(double y1, double y2) {v->setYRange(y1,y2); }
 	void setZRange(double z1, double z2) {v->setZRange(z1,z2); }
@@ -396,14 +437,20 @@ public slots:
 	void setGraphBackground(QColor c) { v->setGraphBackground(c);}
 	void setGraphBackground(QString c) { v->setGraphBackground(QColor(c));}
 	
+	bool Transparent() { return v->Transparent(); }
 	void setTransparent(bool t) { v->setTransparent(t); }
+	int ClipOffset() { return v->ClipOffset(); }
 	void setClipOffset(int c) { v->setClipOffset(c);}
-	void enableGrid(int index,bool b=true) { v->enableGrid(index,b);}
-	void enableBorder(int index,bool b=true) { v->enableBorder(index,b);}
+	double Baseline() { return v->Baseline(); }
 	void setBaseline(double b) { v->setBaseline(b); }
+	double XBaseline() { return v->XBaseline(); }
 	void setXBaseline(double b) { v->setXBaseline(b); }
-	void setBaselineEnabled(bool e=true) { v->setBaselineEnabled(e); }
-	void setXBaselineEnabled(bool e=true) { v->setXBaselineEnabled(e); }
+	bool BaselineEnabled() { return v->BaselineEnabled(); }
+	bool XBaselineEnabled() { return v->XBaselineEnabled(); }
+	void enableBaseline(bool e=true) { v->enableBaseline(e); }
+	void setBaselineEnabled(bool e=true) { v->enableBaseline(e); }
+	void enableXBaseline(bool e=true) { v->enableXBaseline(e); }
+	void setXBaselineEnabled(bool e=true) { v->enableXBaseline(e); }
 private:
 	Plot2DSimple *v;
 };
@@ -429,20 +476,30 @@ public slots:
 	double RegionMax() {return v->RegionMax(); }
 	LRange *Region() { return v->Region(); }
 	bool regionEnabled() { return v->regionEnabled(); }
-	void setRegionEnabled(bool e=true) { v->setRegionEnabled(e); }
+	void enableRegion(bool e=true) { v->enableRegion(e); }
+	void setRegionEnabled(bool e=true) { v->enableRegion(e); }
 	
 	bool marksEnabled() { return v->marksEnabled(); }
-	void setMarksEnabled(bool m=true) { v->setMarksEnabled(m); }
+	void enableMarks(bool m=true) { v->enableMarks(m); }
+	void setMarksEnabled(bool m=true) { v->enableMarks(m); }
 	LRange *markX() { return v->markX(); }
 	void setMarkX(LRange *l) { v->setMarkX(l); }
 	LRange *markY() { return v->markY(); }
 	void setMarkY(LRange *l) { v->setMarkY(l); }
 	
 	void setPosition(double x, double y) { v->setPosition(x,y);}
+	Point Position() { return v->Position(); }
 	void setSize(double x, double y) { v->setSize(x,y);}
+	Point Size() { return v->Size(); }
+	void enabledAspectRatio(bool a=true) { v->enableAspectRatio(a); }
+	bool AspectRatioEnabled() { return v->AspectRatioEnabled(); }
 	void autoScaleX() {v->autoScaleX();}
 	void autoScaleY() {v->autoScaleY();}
 	void autoScaleZ() {v->autoScaleZ();}
+	void autoScaleAll() {v->autoScaleAll();}
+	LRange *XRange() { return v->Range(0); }
+	LRange *YRange() { return v->Range(1); }
+	LRange *ZRange() { return v->Range(2); }
 	void setXRange(double x1, double x2) {v->setXRange(x1,x2); }
 	void setYRange(double y1, double y2) {v->setYRange(y1,y2); }
 	void setZRange(double z1, double z2) {v->setZRange(z1,z2); }
@@ -453,14 +510,20 @@ public slots:
 	void setGraphBackground(QColor c) { v->setGraphBackground(c);}
 	void setGraphBackground(QString c) { v->setGraphBackground(QColor(c));}
 	
+	void enableXBaseline(bool e=true) { v->enableXBaseline(e); }
+	void setXBaselineEnabled(bool e=true) { v->enableXBaseline(e); }
+	bool Transparent() { return v->Transparent(); }
 	void setTransparent(bool t) { v->setTransparent(t); }
+	int ClipOffset() { return v->ClipOffset(); }
 	void setClipOffset(int c) { v->setClipOffset(c);}
-	void enableGrid(int index,bool b=true) { v->enableGrid(index,b);}
-	void enableBorder(int index,bool b=true) { v->enableBorder(index,b);}
+	double Baseline() { return v->Baseline(); }
 	void setBaseline(double b) { v->setBaseline(b); }
+	double XBaseline() { return v->XBaseline(); }
 	void setXBaseline(double b) { v->setXBaseline(b); }
-	void setBaselineEnabled(bool e=true) { v->setBaselineEnabled(e); }
-	void setXBaselineEnabled(bool e=true) { v->setXBaselineEnabled(e); }
+	bool BaselineEnabled() { return v->BaselineEnabled(); }
+	bool XBaselineEnabled() { return v->XBaselineEnabled(); }
+	void enableBaseline(bool e=true) { v->enableBaseline(e); }
+	void setBaselineEnabled(bool e=true) { v->enableBaseline(e); }
 private:
 	Plot2DSurface *v;
 };
@@ -486,20 +549,30 @@ public slots:
 	double RegionMax() {return v->RegionMax(); }
 	LRange *Region() { return v->Region(); }
 	bool regionEnabled() { return v->regionEnabled(); }
-	void setRegionEnabled(bool e=true) { v->setRegionEnabled(e); }
+	void enableRegion(bool e=true) { v->enableRegion(e); }
+	void setRegionEnabled(bool e=true) { v->enableRegion(e); }
 	
 	bool marksEnabled() { return v->marksEnabled(); }
-	void setMarksEnabled(bool m=true) { v->setMarksEnabled(m); }
+	void enableMarks(bool m=true) { v->enableMarks(m); }
+	void setMarksEnabled(bool m=true) { v->enableMarks(m); }
 	LRange *markX() { return v->markX(); }
 	void setMarkX(LRange *l) { v->setMarkX(l); }
 	LRange *markY() { return v->markY(); }
 	void setMarkY(LRange *l) { v->setMarkY(l); }
 	
 	void setPosition(double x, double y) { v->setPosition(x,y);}
+	Point Position() { return v->Position(); }
 	void setSize(double x, double y) { v->setSize(x,y);}
+	Point Size() { return v->Size(); }
+	void enabledAspectRatio(bool a=true) { v->enableAspectRatio(a); }
+	bool AspectRatioEnabled() { return v->AspectRatioEnabled(); }
 	void autoScaleX() {v->autoScaleX();}
 	void autoScaleY() {v->autoScaleY();}
 	void autoScaleZ() {v->autoScaleZ();}
+	void autoScaleAll() {v->autoScaleAll();}
+	LRange *XRange() { return v->Range(0); }
+	LRange *YRange() { return v->Range(1); }
+	LRange *ZRange() { return v->Range(2); }
 	void setXRange(double x1, double x2) {v->setXRange(x1,x2); }
 	void setYRange(double y1, double y2) {v->setYRange(y1,y2); }
 	void setZRange(double z1, double z2) {v->setZRange(z1,z2); }
@@ -510,14 +583,20 @@ public slots:
 	void setGraphBackground(QColor c) { v->setGraphBackground(c);}
 	void setGraphBackground(QString c) { v->setGraphBackground(QColor(c));}
 	
+	bool Transparent() { return v->Transparent(); }
 	void setTransparent(bool t) { v->setTransparent(t); }
+	int ClipOffset() { return v->ClipOffset(); }
 	void setClipOffset(int c) { v->setClipOffset(c);}
-	void enableGrid(int index,bool b=true) { v->enableGrid(index,b);}
-	void enableBorder(int index,bool b=true) { v->enableBorder(index,b);}
+	double Baseline() { return v->Baseline(); }
 	void setBaseline(double b) { v->setBaseline(b); }
+	double XBaseline() { return v->XBaseline(); }
 	void setXBaseline(double b) { v->setXBaseline(b); }
-	void setBaselineEnabled(bool e=true) { v->setBaselineEnabled(e); }
-	void setXBaselineEnabled(bool e=true) { v->setXBaselineEnabled(e); }
+	bool BaselineEnabled() { return v->BaselineEnabled(); }
+	bool XBaselineEnabled() { return v->XBaselineEnabled(); }
+	void enableBaseline(bool e=true) { v->enableBaseline(e); }
+	void setBaselineEnabled(bool e=true) { v->enableBaseline(e); }
+	void enableXBaseline(bool e=true) { v->enableXBaseline(e); }
+	void setXBaselineEnabled(bool e=true) { v->enableXBaseline(e); }
 private:
 	Plot3D *v;
 };
@@ -543,20 +622,30 @@ public slots:
 	double RegionMax() {return v->RegionMax(); }
 	LRange *Region() { return v->Region(); }
 	bool regionEnabled() { return v->regionEnabled(); }
-	void setRegionEnabled(bool e=true) { v->setRegionEnabled(e); }
+	void enableRegion(bool e=true) { v->enableRegion(e); }
+	void setRegionEnabled(bool e=true) { v->enableRegion(e); }
 	
 	bool marksEnabled() { return v->marksEnabled(); }
-	void setMarksEnabled(bool m=true) { v->setMarksEnabled(m); }
+	void enableMarks(bool m=true) { v->enableMarks(m); }
+	void setMarksEnabled(bool m=true) { v->enableMarks(m); }
 	LRange *markX() { return v->markX(); }
 	void setMarkX(LRange *l) { v->setMarkX(l); }
 	LRange *markY() { return v->markY(); }
 	void setMarkY(LRange *l) { v->setMarkY(l); }
 	
 	void setPosition(double x, double y) { v->setPosition(x,y);}
+	Point Position() { return v->Position(); }
 	void setSize(double x, double y) { v->setSize(x,y);}
+	Point Size() { return v->Size(); }
+	void enabledAspectRatio(bool a=true) { v->enableAspectRatio(a); }
+	bool AspectRatioEnabled() { return v->AspectRatioEnabled(); }
 	void autoScaleX() {v->autoScaleX();}
 	void autoScaleY() {v->autoScaleY();}
 	void autoScaleZ() {v->autoScaleZ();}
+	void autoScaleAll() {v->autoScaleAll();}
+	LRange *XRange() { return v->Range(0); }
+	LRange *YRange() { return v->Range(1); }
+	LRange *ZRange() { return v->Range(2); }
 	void setXRange(double x1, double x2) {v->setXRange(x1,x2); }
 	void setYRange(double y1, double y2) {v->setYRange(y1,y2); }
 	void setZRange(double z1, double z2) {v->setZRange(z1,z2); }
@@ -567,14 +656,20 @@ public slots:
 	void setGraphBackground(QColor c) { v->setGraphBackground(c);}
 	void setGraphBackground(QString c) { v->setGraphBackground(QColor(c));}
 	
+	bool Transparent() { return v->Transparent(); }
 	void setTransparent(bool t) { v->setTransparent(t); }
+	int ClipOffset() { return v->ClipOffset(); }
 	void setClipOffset(int c) { v->setClipOffset(c);}
-	void enableGrid(int index,bool b=true) { v->enableGrid(index,b);}
-	void enableBorder(int index,bool b=true) { v->enableBorder(index,b);}
+	double Baseline() { return v->Baseline(); }
 	void setBaseline(double b) { v->setBaseline(b); }
+	double XBaseline() { return v->XBaseline(); }
 	void setXBaseline(double b) { v->setXBaseline(b); }
-	void setBaselineEnabled(bool e=true) { v->setBaselineEnabled(e); }
-	void setXBaselineEnabled(bool e=true) { v->setXBaselineEnabled(e); }
+	bool BaselineEnabled() { return v->BaselineEnabled(); }
+	bool XBaselineEnabled() { return v->XBaselineEnabled(); }
+	void enableBaseline(bool e=true) { v->enableBaseline(e); }
+	void setBaselineEnabled(bool e=true) { v->enableBaseline(e); }
+	void enableXBaseline(bool e=true) { v->enableXBaseline(e); }
+	void setXBaselineEnabled(bool e=true) { v->enableXBaseline(e); }
 private:
 	PlotQWT3D *v;
 };
@@ -600,20 +695,30 @@ public slots:
 	double RegionMax() {return v->RegionMax(); }
 	LRange *Region() { return v->Region(); }
 	bool regionEnabled() { return v->regionEnabled(); }
-	void setRegionEnabled(bool e=true) { v->setRegionEnabled(e); }
+	void enableRegion(bool e=true) { v->enableRegion(e); }
+	void setRegionEnabled(bool e=true) { v->enableRegion(e); }
 	
 	bool marksEnabled() { return v->marksEnabled(); }
-	void setMarksEnabled(bool m=true) { v->setMarksEnabled(m); }
+	void enableMarks(bool m=true) { v->enableMarks(m); }
+	void setMarksEnabled(bool m=true) { v->enableMarks(m); }
 	LRange *markX() { return v->markX(); }
 	void setMarkX(LRange *l) { v->setMarkX(l); }
 	LRange *markY() { return v->markY(); }
 	void setMarkY(LRange *l) { v->setMarkY(l); }
 	
 	void setPosition(double x, double y) { v->setPosition(x,y);}
+	Point Position() { return v->Position(); }
 	void setSize(double x, double y) { v->setSize(x,y);}
+	Point Size() { return v->Size(); }
+	void enabledAspectRatio(bool a=true) { v->enableAspectRatio(a); }
+	bool AspectRatioEnabled() { return v->AspectRatioEnabled(); }
 	void autoScaleX() {v->autoScaleX();}
 	void autoScaleY() {v->autoScaleY();}
 	void autoScaleZ() {v->autoScaleZ();}
+	void autoScaleAll() {v->autoScaleAll();}
+	LRange *XRange() { return v->Range(0); }
+	LRange *YRange() { return v->Range(1); }
+	LRange *ZRange() { return v->Range(2); }
 	void setXRange(double x1, double x2) {v->setXRange(x1,x2); }
 	void setYRange(double y1, double y2) {v->setYRange(y1,y2); }
 	void setZRange(double z1, double z2) {v->setZRange(z1,z2); }
@@ -624,14 +729,20 @@ public slots:
 	void setGraphBackground(QColor c) { v->setGraphBackground(c);}
 	void setGraphBackground(QString c) { v->setGraphBackground(QColor(c));}
 	
+	bool Transparent() { return v->Transparent(); }
 	void setTransparent(bool t) { v->setTransparent(t); }
+	int ClipOffset() { return v->ClipOffset(); }
 	void setClipOffset(int c) { v->setClipOffset(c);}
-	void enableGrid(int index,bool b=true) { v->enableGrid(index,b);}
-	void enableBorder(int index,bool b=true) { v->enableBorder(index,b);}
+	double Baseline() { return v->Baseline(); }
 	void setBaseline(double b) { v->setBaseline(b); }
+	double XBaseline() { return v->XBaseline(); }
 	void setXBaseline(double b) { v->setXBaseline(b); }
-	void setBaselineEnabled(bool e=true) { v->setBaselineEnabled(e); }
-	void setXBaselineEnabled(bool e=true) { v->setXBaselineEnabled(e); }
+	bool BaselineEnabled() { return v->BaselineEnabled(); }
+	bool XBaselineEnabled() { return v->XBaselineEnabled(); }
+	void enableBaseline(bool e=true) { v->enableBaseline(e); }
+	void setBaselineEnabled(bool e=true) { v->enableBaseline(e); }
+	void enableXBaseline(bool e=true) { v->enableXBaseline(e); }
+	void setXBaselineEnabled(bool e=true) { v->enableXBaseline(e); }
 private:
 	PlotPie *v;
 };
@@ -657,20 +768,30 @@ public slots:
 	double RegionMax() {return v->RegionMax(); }
 	LRange *Region() { return v->Region(); }
 	bool regionEnabled() { return v->regionEnabled(); }
-	void setRegionEnabled(bool e=true) { v->setRegionEnabled(e); }
+	void enableRegion(bool e=true) { v->enableRegion(e); }
+	void setRegionEnabled(bool e=true) { v->enableRegion(e); }
 	
 	bool marksEnabled() { return v->marksEnabled(); }
-	void setMarksEnabled(bool m=true) { v->setMarksEnabled(m); }
+	void enableMarks(bool m=true) { v->enableMarks(m); }
+	void setMarksEnabled(bool m=true) { v->enableMarks(m); }
 	LRange *markX() { return v->markX(); }
 	void setMarkX(LRange *l) { v->setMarkX(l); }
 	LRange *markY() { return v->markY(); }
 	void setMarkY(LRange *l) { v->setMarkY(l); }
 	
 	void setPosition(double x, double y) { v->setPosition(x,y);}
+	Point Position() { return v->Position(); }
 	void setSize(double x, double y) { v->setSize(x,y);}
+	Point Size() { return v->Size(); }
+	void enabledAspectRatio(bool a=true) { v->enableAspectRatio(a); }
+	bool AspectRatioEnabled() { return v->AspectRatioEnabled(); }
 	void autoScaleX() {v->autoScaleX();}
 	void autoScaleY() {v->autoScaleY();}
 	void autoScaleZ() {v->autoScaleZ();}
+	void autoScaleAll() {v->autoScaleAll();}
+	LRange *XRange() { return v->Range(0); }
+	LRange *YRange() { return v->Range(1); }
+	LRange *ZRange() { return v->Range(2); }
 	void setXRange(double x1, double x2) {v->setXRange(x1,x2); }
 	void setYRange(double y1, double y2) {v->setYRange(y1,y2); }
 	void setZRange(double z1, double z2) {v->setZRange(z1,z2); }
@@ -681,14 +802,20 @@ public slots:
 	void setGraphBackground(QColor c) { v->setGraphBackground(c);}
 	void setGraphBackground(QString c) { v->setGraphBackground(QColor(c));}
 	
+	bool Transparent() { return v->Transparent(); }
 	void setTransparent(bool t) { v->setTransparent(t); }
+	int ClipOffset() { return v->ClipOffset(); }
 	void setClipOffset(int c) { v->setClipOffset(c);}
-	void enableGrid(int index,bool b=true) { v->enableGrid(index,b);}
-	void enableBorder(int index,bool b=true) { v->enableBorder(index,b);}
+	double Baseline() { return v->Baseline(); }
 	void setBaseline(double b) { v->setBaseline(b); }
+	double XBaseline() { return v->XBaseline(); }
 	void setXBaseline(double b) { v->setXBaseline(b); }
-	void setBaselineEnabled(bool e=true) { v->setBaselineEnabled(e); }
-	void setXBaselineEnabled(bool e=true) { v->setXBaselineEnabled(e); }
+	bool BaselineEnabled() { return v->BaselineEnabled(); }
+	bool XBaselineEnabled() { return v->XBaselineEnabled(); }
+	void enableBaseline(bool e=true) { v->enableBaseline(e); }
+	void setBaselineEnabled(bool e=true) { v->enableBaseline(e); }
+	void enableXBaseline(bool e=true) { v->enableXBaseline(e); }
+	void setXBaselineEnabled(bool e=true) { v->enableXBaseline(e); }
 private:
 	PlotPolar *v;
 };
@@ -714,20 +841,30 @@ public slots:
 	double RegionMax() {return v->RegionMax(); }
 	LRange *Region() { return v->Region(); }
 	bool regionEnabled() { return v->regionEnabled(); }
-	void setRegionEnabled(bool e=true) { v->setRegionEnabled(e); }
+	void enableRegion(bool e=true) { v->enableRegion(e); }
+	void setRegionEnabled(bool e=true) { v->enableRegion(e); }
 	
 	bool marksEnabled() { return v->marksEnabled(); }
-	void setMarksEnabled(bool m=true) { v->setMarksEnabled(m); }
+	void enableMarks(bool m=true) { v->enableMarks(m); }
+	void setMarksEnabled(bool m=true) { v->enableMarks(m); }
 	LRange *markX() { return v->markX(); }
 	void setMarkX(LRange *l) { v->setMarkX(l); }
 	LRange *markY() { return v->markY(); }
 	void setMarkY(LRange *l) { v->setMarkY(l); }
 	
 	void setPosition(double x, double y) { v->setPosition(x,y);}
+	Point Position() { return v->Position(); }
 	void setSize(double x, double y) { v->setSize(x,y);}
+	Point Size() { return v->Size(); }
+	void enabledAspectRatio(bool a=true) { v->enableAspectRatio(a); }
+	bool AspectRatioEnabled() { return v->AspectRatioEnabled(); }
 	void autoScaleX() {v->autoScaleX();}
 	void autoScaleY() {v->autoScaleY();}
 	void autoScaleZ() {v->autoScaleZ();}
+	void autoScaleAll() {v->autoScaleAll();}
+	LRange *XRange() { return v->Range(0); }
+	LRange *YRange() { return v->Range(1); }
+	LRange *ZRange() { return v->Range(2); }
 	void setXRange(double x1, double x2) {v->setXRange(x1,x2); }
 	void setYRange(double y1, double y2) {v->setYRange(y1,y2); }
 	void setZRange(double z1, double z2) {v->setZRange(z1,z2); }
@@ -738,14 +875,20 @@ public slots:
 	void setGraphBackground(QColor c) { v->setGraphBackground(c);}
 	void setGraphBackground(QString c) { v->setGraphBackground(QColor(c));}
 	
+	bool Transparent() { return v->Transparent(); }
 	void setTransparent(bool t) { v->setTransparent(t); }
+	int ClipOffset() { return v->ClipOffset(); }
 	void setClipOffset(int c) { v->setClipOffset(c);}
-	void enableGrid(int index,bool b=true) { v->enableGrid(index,b);}
-	void enableBorder(int index,bool b=true) { v->enableBorder(index,b);}
+	double Baseline() { return v->Baseline(); }
 	void setBaseline(double b) { v->setBaseline(b); }
+	double XBaseline() { return v->XBaseline(); }
 	void setXBaseline(double b) { v->setXBaseline(b); }
-	void setBaselineEnabled(bool e=true) { v->setBaselineEnabled(e); }
-	void setXBaselineEnabled(bool e=true) { v->setXBaselineEnabled(e); }
+	bool BaselineEnabled() { return v->BaselineEnabled(); }
+	bool XBaselineEnabled() { return v->XBaselineEnabled(); }
+	void enableBaseline(bool e=true) { v->enableBaseline(e); }
+	void setBaselineEnabled(bool e=true) { v->enableBaseline(e); }
+	void enableXBaseline(bool e=true) { v->enableXBaseline(e); }
+	void setXBaselineEnabled(bool e=true) { v->enableXBaseline(e); }
 private:
 	PlotTernary *v;
 };
