@@ -1,11 +1,12 @@
 //LabPlot : manipulations.h
+// sync with labplot.qs
 
 #ifndef MANIPULATIONS_H
 #define MANIPULATIONS_H
 
 // TODO : annotate, convolve, frame, opaque, unsharpmask
-enum ManipulationType {ADAPTIVETHRESHOLD=0,ADDNOISE,BLUR,BORDER,CHARCOAL,CHOP,COLORIZE,CONTRAST,
-CYCLECOLORMAP,DESPECKLE,EDGE,EMBOSS, ENHANCE, EQUALIZE,ERASE,FLIP,FLOODFILLCOLOR,FLOP,GAMMA,
+enum ManipulationType {ADAPTIVETHRESHOLD,ADDNOISE,BLUR,BORDER,CHARCOAL,CHOP,COLORIZE,CONTRAST,
+CYCLECOLORMAP,DESPECKLE,EDGE,EMBOSS, ENHANCE, EQUALIZE,ERASE,FLIP,FLOODFILLCOLOR,FLOP,MGAMMA,
 GAUSSIANBLUR,IMPLODE,MAGNIFY,MEDIANFILTER,MINIFY,MODULATE,NEGATE,NORMALIZE,OILPAINT,OPACITY,
 QUANTIZE,RAISE,REDUCENOISE,ROLL,ROTATE,SAMPLE,SCALE,SEGMENT,SHADE,SHARPEN,SHAVE,SHEAR,SOLARIZE,
 SPREAD,SWIRL,THRESHOLD,TRANSFORM,TRANSPARENT,TRIM,WAVE,ZOOM};
