@@ -1,3 +1,8 @@
+//LabPlot : pixmap.h
+
+#ifndef PIXMAP_H
+#define PIXMAP_H
+
 #include "arrange.xpm"
 #include "arrow_down.xpm"
 #include "arrow_left.xpm"
@@ -10,9 +15,13 @@
 #include "average.xpm"
 #include "axes.xpm"
 #include "baseline.xpm"
+#include "capability.xpm"
 #include "clear.xpm"
+#include "clone.xpm"
+#include "columnstat.xpm"
 #include "compress.xpm"
 #include "convolution.xpm"
+#include "correlation.xpm"
 #include "crosshair.xpm"
 #include "deletePlot.xpm"
 #include "differences.xpm"
@@ -46,6 +55,7 @@
 #include "new3DFunction.xpm"
 #include "newData.xpm"
 #include "newFunction.xpm"
+#include "noise.xpm"
 #include "objects.xpm"
 #include "operations.xpm"
 #include "overlay.xpm"
@@ -63,8 +73,10 @@
 #include "prune.xpm"
 #include "qsa.xpm"
 #include "rect.xpm"
+#include "redo.xpm"
 #include "region.xpm"
 #include "regression.xpm"
+#include "rowstat.xpm"
 #include "saveAs.xpm"
 #include "scalexdown.xpm"
 #include "scalexup.xpm"
@@ -77,7 +89,10 @@
 #include "smooth.xpm"
 #include "spreadsheet.xpm"
 #include "title.xpm"
+#include "undo.xpm"
 #include "wavelet.xpm"
 #include "worksheet.xpm"
 #include "zoomin.xpm"
 #include "zoomout.xpm"
+
+#endif // PIXMAP_H
